@@ -1,4 +1,5 @@
 <?php
+
 /*
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -35,23 +36,21 @@ use Doctrine\ORM\Mapping\Driver\AnnotationDriver;
 use Doctrine\ORM\Mapping\EntityListenerResolver;
 use Doctrine\ORM\Mapping\NamingStrategy;
 use Doctrine\ORM\Mapping\QuoteStrategy;
+use Doctrine\ORM\Query\ResultSetMapping;
 use Doctrine\ORM\Repository\DefaultRepositoryFactory;
 use Doctrine\ORM\Repository\RepositoryFactory;
 use Doctrine\Persistence\Mapping\Driver\MappingDriver;
 use Doctrine\Persistence\ObjectRepository;
-use function interface_exists;
+use ReflectionClass;
+
+use function strtolower;
+use function trim;
 
 /**
  * Configuration container for all configuration options of Doctrine.
  * It combines all configuration options from DBAL & ORM.
  *
  * Internal note: When adding a new configuration option just write a getter/setter pair.
- *
- * @since 2.0
- * @author  Benjamin Eberlei <kontakt@beberlei.de>
- * @author  Guilherme Blanco <guilhermeblanco@hotmail.com>
- * @author  Jonathan Wage <jonwage@gmail.com>
- * @author  Roman Borschel <roman@code-factory.org>
  */
 class Configuration extends \Doctrine\DBAL\Configuration
 {
@@ -70,38 +69,36 @@ class Configuration extends \Doctrine\DBAL\Configuration
     /**
      * Gets the directory where Doctrine generates any necessary proxy class files.
      *
-     * @return string|null
-     *
      * @deprecated 2.7 We're switch to `ocramius/proxy-manager` and this method isn't applicable any longer
+     *
      * @see https://github.com/Ocramius/ProxyManager
+     *
+     * @return string|null
      */
     public function getProxyDir()
     {
-        return isset($this->_attributes['proxyDir'])
-            ? $this->_attributes['proxyDir']
-            : null;
+        return $this->_attributes['proxyDir'] ?? null;
     }
 
     /**
      * Gets the strategy for automatically generating proxy classes.
      *
-     * @return int Possible values are constants of Doctrine\Common\Proxy\AbstractProxyFactory.
-     *
      * @deprecated 2.7 We're switch to `ocramius/proxy-manager` and this method isn't applicable any longer
+     *
      * @see https://github.com/Ocramius/ProxyManager
+     *
+     * @return int Possible values are constants of Doctrine\Common\Proxy\AbstractProxyFactory.
      */
     public function getAutoGenerateProxyClasses()
     {
-        return isset($this->_attributes['autoGenerateProxyClasses'])
-            ? $this->_attributes['autoGenerateProxyClasses']
-            : AbstractProxyFactory::AUTOGENERATE_ALWAYS;
+        return $this->_attributes['autoGenerateProxyClasses'] ?? AbstractProxyFactory::AUTOGENERATE_ALWAYS;
     }
 
     /**
      * Sets the strategy for automatically generating proxy classes.
      *
-     * @param boolean|int $autoGenerate Possible values are constants of Doctrine\Common\Proxy\AbstractProxyFactory.
-     *                                  True is converted to AUTOGENERATE_ALWAYS, false to AUTOGENERATE_NEVER.
+     * @param bool|int $autoGenerate Possible values are constants of Doctrine\Common\Proxy\AbstractProxyFactory.
+     * True is converted to AUTOGENERATE_ALWAYS, false to AUTOGENERATE_NEVER.
      *
      * @return void
      */
@@ -113,16 +110,15 @@ class Configuration extends \Doctrine\DBAL\Configuration
     /**
      * Gets the namespace where proxy classes reside.
      *
-     * @return string|null
-     *
      * @deprecated 2.7 We're switch to `ocramius/proxy-manager` and this method isn't applicable any longer
+     *
      * @see https://github.com/Ocramius/ProxyManager
+     *
+     * @return string|null
      */
     public function getProxyNamespace()
     {
-        return isset($this->_attributes['proxyNamespace'])
-            ? $this->_attributes['proxyNamespace']
-            : null;
+        return $this->_attributes['proxyNamespace'] ?? null;
     }
 
     /**
@@ -140,8 +136,6 @@ class Configuration extends \Doctrine\DBAL\Configuration
     /**
      * Sets the cache driver implementation that is used for metadata caching.
      *
-     * @param MappingDriver $driverImpl
-     *
      * @return void
      *
      * @todo Force parameter to be a Closure to ensure lazy evaluation
@@ -156,10 +150,11 @@ class Configuration extends \Doctrine\DBAL\Configuration
      * Adds a new default annotation driver with a correctly configured annotation reader. If $useSimpleAnnotationReader
      * is true, the notation `@Entity` will work, otherwise, the notation `@ORM\Entity` will be supported.
      *
-     * @param array $paths
-     * @param bool  $useSimpleAnnotationReader
+     * @param bool $useSimpleAnnotationReader
      *
      * @return AnnotationDriver
+     *
+     * @psalm-param string|list<string> $paths
      */
     public function newDefaultAnnotationDriver($paths = [], $useSimpleAnnotationReader = true)
     {
@@ -204,7 +199,7 @@ class Configuration extends \Doctrine\DBAL\Configuration
      */
     public function getEntityNamespace($entityNamespaceAlias)
     {
-        if ( ! isset($this->_attributes['entityNamespaces'][$entityNamespaceAlias])) {
+        if (! isset($this->_attributes['entityNamespaces'][$entityNamespaceAlias])) {
             throw ORMException::unknownEntityNamespace($entityNamespaceAlias);
         }
 
@@ -214,9 +209,9 @@ class Configuration extends \Doctrine\DBAL\Configuration
     /**
      * Sets the entity alias map.
      *
-     * @param array $entityNamespaces
-     *
      * @return void
+     *
+     * @psalm-param array<string, string> $entityNamespaces
      */
     public function setEntityNamespaces(array $entityNamespaces)
     {
@@ -226,7 +221,7 @@ class Configuration extends \Doctrine\DBAL\Configuration
     /**
      * Retrieves the list of registered entity namespace aliases.
      *
-     * @return array
+     * @psalm-return array<string, string>
      */
     public function getEntityNamespaces()
     {
@@ -242,28 +237,22 @@ class Configuration extends \Doctrine\DBAL\Configuration
      */
     public function getMetadataDriverImpl()
     {
-        return isset($this->_attributes['metadataDriverImpl'])
-            ? $this->_attributes['metadataDriverImpl']
-            : null;
+        return $this->_attributes['metadataDriverImpl'] ?? null;
     }
 
     /**
      * Gets the cache driver implementation that is used for the query cache (SQL cache).
      *
-     * @return \Doctrine\Common\Cache\Cache|null
+     * @return CacheDriver|null
      */
     public function getQueryCacheImpl()
     {
-        return isset($this->_attributes['queryCacheImpl'])
-            ? $this->_attributes['queryCacheImpl']
-            : null;
+        return $this->_attributes['queryCacheImpl'] ?? null;
     }
 
     /**
      * Sets the cache driver implementation that is used for the query cache (SQL cache).
      *
-     * @param \Doctrine\Common\Cache\Cache $cacheImpl
-     *
      * @return void
      */
     public function setQueryCacheImpl(CacheDriver $cacheImpl)
@@ -274,20 +263,16 @@ class Configuration extends \Doctrine\DBAL\Configuration
     /**
      * Gets the cache driver implementation that is used for the hydration cache (SQL cache).
      *
-     * @return \Doctrine\Common\Cache\Cache|null
+     * @return CacheDriver|null
      */
     public function getHydrationCacheImpl()
     {
-        return isset($this->_attributes['hydrationCacheImpl'])
-            ? $this->_attributes['hydrationCacheImpl']
-            : null;
+        return $this->_attributes['hydrationCacheImpl'] ?? null;
     }
 
     /**
      * Sets the cache driver implementation that is used for the hydration cache (SQL cache).
      *
-     * @param \Doctrine\Common\Cache\Cache $cacheImpl
-     *
      * @return void
      */
     public function setHydrationCacheImpl(CacheDriver $cacheImpl)
@@ -298,20 +283,16 @@ class Configuration extends \Doctrine\DBAL\Configuration
     /**
      * Gets the cache driver implementation that is used for metadata caching.
      *
-     * @return \Doctrine\Common\Cache\Cache|null
+     * @return CacheDriver|null
      */
     public function getMetadataCacheImpl()
     {
-        return isset($this->_attributes['metadataCacheImpl'])
-            ? $this->_attributes['metadataCacheImpl']
-            : null;
+        return $this->_attributes['metadataCacheImpl'] ?? null;
     }
 
     /**
      * Sets the cache driver implementation that is used for metadata caching.
      *
-     * @param \Doctrine\Common\Cache\Cache $cacheImpl
-     *
      * @return void
      */
     public function setMetadataCacheImpl(CacheDriver $cacheImpl)
@@ -343,7 +324,7 @@ class Configuration extends \Doctrine\DBAL\Configuration
      */
     public function getNamedQuery($name)
     {
-        if ( ! isset($this->_attributes['namedQueries'][$name])) {
+        if (! isset($this->_attributes['namedQueries'][$name])) {
             throw ORMException::namedQueryNotFound($name);
         }
 
@@ -369,14 +350,17 @@ class Configuration extends \Doctrine\DBAL\Configuration
      *
      * @param string $name The name of the query.
      *
-     * @return array A tuple with the first element being the SQL string and the second
-     *               element being the ResultSetMapping.
-     *
      * @throws ORMException
+     *
+     * @psalm-return array{string, ResultSetMapping} A tuple with the first
+     *                                               element being the SQL
+     *                                               string and the second
+     *                                               element being the
+     *                                               ResultSetMapping.
      */
     public function getNamedNativeQuery($name)
     {
-        if ( ! isset($this->_attributes['namedNativeQueries'][$name])) {
+        if (! isset($this->_attributes['namedNativeQueries'][$name])) {
             throw ORMException::namedNativeQueryNotFound($name);
         }
 
@@ -396,7 +380,7 @@ class Configuration extends \Doctrine\DBAL\Configuration
     {
         $queryCacheImpl = $this->getQueryCacheImpl();
 
-        if ( ! $queryCacheImpl) {
+        if (! $queryCacheImpl) {
             throw ORMException::queryCacheNotConfigured();
         }
 
@@ -406,7 +390,7 @@ class Configuration extends \Doctrine\DBAL\Configuration
 
         $metadataCacheImpl = $this->getMetadataCacheImpl();
 
-        if ( ! $metadataCacheImpl) {
+        if (! $metadataCacheImpl) {
             throw ORMException::metadataCacheNotConfigured();
         }
 
@@ -442,15 +426,14 @@ class Configuration extends \Doctrine\DBAL\Configuration
      * @param string $name
      *
      * @return string|null
+     *
      * @psalm-return ?class-string
      */
     public function getCustomStringFunction($name)
     {
         $name = strtolower($name);
 
-        return isset($this->_attributes['customStringFunctions'][$name])
-            ? $this->_attributes['customStringFunctions'][$name]
-            : null;
+        return $this->_attributes['customStringFunctions'][$name] ?? null;
     }
 
     /**
@@ -461,9 +444,10 @@ class Configuration extends \Doctrine\DBAL\Configuration
      *
      * Any previously added string functions are discarded.
      *
-     * @param array $functions The map of custom DQL string functions.
-     *
      * @return void
+     *
+     * @psalm-param array<string, class-string> $functions The map of custom
+     *                                                     DQL string functions.
      */
     public function setCustomStringFunctions(array $functions)
     {
@@ -495,15 +479,14 @@ class Configuration extends \Doctrine\DBAL\Configuration
      * @param string $name
      *
      * @return string|null
+     *
      * @psalm-return ?class-string
      */
     public function getCustomNumericFunction($name)
     {
         $name = strtolower($name);
 
-        return isset($this->_attributes['customNumericFunctions'][$name])
-            ? $this->_attributes['customNumericFunctions'][$name]
-            : null;
+        return $this->_attributes['customNumericFunctions'][$name] ?? null;
     }
 
     /**
@@ -514,9 +497,10 @@ class Configuration extends \Doctrine\DBAL\Configuration
      *
      * Any previously added numeric functions are discarded.
      *
-     * @param array $functions The map of custom DQL numeric functions.
-     *
      * @return void
+     *
+     * @psalm-param array<string, class-string> $functions The map of custom
+     *                                                     DQL numeric functions.
      */
     public function setCustomNumericFunctions(array $functions)
     {
@@ -557,9 +541,7 @@ class Configuration extends \Doctrine\DBAL\Configuration
     {
         $name = strtolower($name);
 
-        return isset($this->_attributes['customDatetimeFunctions'][$name])
-            ? $this->_attributes['customDatetimeFunctions'][$name]
-            : null;
+        return $this->_attributes['customDatetimeFunctions'][$name] ?? null;
     }
 
     /**
@@ -586,7 +568,7 @@ class Configuration extends \Doctrine\DBAL\Configuration
     /**
      * Sets the custom hydrator modes in one pass.
      *
-     * @param array $modes An array of ($modeName => $hydrator).
+     * @param array<string, class-string> $modes An array of ($modeName => $hydrator).
      *
      * @return void
      */
@@ -610,18 +592,17 @@ class Configuration extends \Doctrine\DBAL\Configuration
      */
     public function getCustomHydrationMode($modeName)
     {
-        return isset($this->_attributes['customHydrationModes'][$modeName])
-            ? $this->_attributes['customHydrationModes'][$modeName]
-            : null;
+        return $this->_attributes['customHydrationModes'][$modeName] ?? null;
     }
 
     /**
      * Adds a custom hydration mode.
      *
      * @param string $modeName The hydration mode name.
-     * @param string $hydrator The hydrator class name.
      *
      * @return void
+     *
+     * @psalm-param class-string $hydrator The hydrator class name.
      */
     public function addCustomHydrationMode($modeName, $hydrator)
     {
@@ -649,7 +630,7 @@ class Configuration extends \Doctrine\DBAL\Configuration
      */
     public function getClassMetadataFactoryName()
     {
-        if ( ! isset($this->_attributes['classMetadataFactoryName'])) {
+        if (! isset($this->_attributes['classMetadataFactoryName'])) {
             $this->_attributes['classMetadataFactoryName'] = ClassMetadataFactory::class;
         }
 
@@ -679,16 +660,12 @@ class Configuration extends \Doctrine\DBAL\Configuration
      */
     public function getFilterClassName($name)
     {
-        return isset($this->_attributes['filters'][$name])
-            ? $this->_attributes['filters'][$name]
-            : null;
+        return $this->_attributes['filters'][$name] ?? null;
     }
 
     /**
      * Sets default repository class.
      *
-     * @since 2.2
-     *
      * @param string $className
      *
      * @return void
@@ -697,9 +674,9 @@ class Configuration extends \Doctrine\DBAL\Configuration
      */
     public function setDefaultRepositoryClassName($className)
     {
-        $reflectionClass = new \ReflectionClass($className);
+        $reflectionClass = new ReflectionClass($className);
 
-        if ( ! $reflectionClass->implementsInterface(ObjectRepository::class)) {
+        if (! $reflectionClass->implementsInterface(ObjectRepository::class)) {
             throw ORMException::invalidEntityRepository($className);
         }
 
@@ -709,26 +686,18 @@ class Configuration extends \Doctrine\DBAL\Configuration
     /**
      * Get default repository class.
      *
-     * @since 2.2
-     *
      * @return string
      *
      * @psalm-return class-string
      */
     public function getDefaultRepositoryClassName()
     {
-        return isset($this->_attributes['defaultRepositoryClassName'])
-            ? $this->_attributes['defaultRepositoryClassName']
-            : EntityRepository::class;
+        return $this->_attributes['defaultRepositoryClassName'] ?? EntityRepository::class;
     }
 
     /**
      * Sets naming strategy.
      *
-     * @since 2.3
-     *
-     * @param NamingStrategy $namingStrategy
-     *
      * @return void
      */
     public function setNamingStrategy(NamingStrategy $namingStrategy)
@@ -739,13 +708,11 @@ class Configuration extends \Doctrine\DBAL\Configuration
     /**
      * Gets naming strategy..
      *
-     * @since 2.3
-     *
      * @return NamingStrategy
      */
     public function getNamingStrategy()
     {
-        if ( ! isset($this->_attributes['namingStrategy'])) {
+        if (! isset($this->_attributes['namingStrategy'])) {
             $this->_attributes['namingStrategy'] = new DefaultNamingStrategy();
         }
 
@@ -755,10 +722,6 @@ class Configuration extends \Doctrine\DBAL\Configuration
     /**
      * Sets quote strategy.
      *
-     * @since 2.3
-     *
-     * @param \Doctrine\ORM\Mapping\QuoteStrategy $quoteStrategy
-     *
      * @return void
      */
     public function setQuoteStrategy(QuoteStrategy $quoteStrategy)
@@ -769,13 +732,11 @@ class Configuration extends \Doctrine\DBAL\Configuration
     /**
      * Gets quote strategy.
      *
-     * @since 2.3
-     *
-     * @return \Doctrine\ORM\Mapping\QuoteStrategy
+     * @return QuoteStrategy
      */
     public function getQuoteStrategy()
     {
-        if ( ! isset($this->_attributes['quoteStrategy'])) {
+        if (! isset($this->_attributes['quoteStrategy'])) {
             $this->_attributes['quoteStrategy'] = new DefaultQuoteStrategy();
         }
 
@@ -784,9 +745,6 @@ class Configuration extends \Doctrine\DBAL\Configuration
 
     /**
      * Set the entity listener resolver.
-     *
-     * @since 2.4
-     * @param \Doctrine\ORM\Mapping\EntityListenerResolver $resolver
      */
     public function setEntityListenerResolver(EntityListenerResolver $resolver)
     {
@@ -796,12 +754,11 @@ class Configuration extends \Doctrine\DBAL\Configuration
     /**
      * Get the entity listener resolver.
      *
-     * @since 2.4
-     * @return \Doctrine\ORM\Mapping\EntityListenerResolver
+     * @return EntityListenerResolver
      */
     public function getEntityListenerResolver()
     {
-        if ( ! isset($this->_attributes['entityListenerResolver'])) {
+        if (! isset($this->_attributes['entityListenerResolver'])) {
             $this->_attributes['entityListenerResolver'] = new DefaultEntityListenerResolver();
         }
 
@@ -810,9 +767,6 @@ class Configuration extends \Doctrine\DBAL\Configuration
 
     /**
      * Set the entity repository factory.
-     *
-     * @since 2.4
-     * @param \Doctrine\ORM\Repository\RepositoryFactory $repositoryFactory
      */
     public function setRepositoryFactory(RepositoryFactory $repositoryFactory)
     {
@@ -822,45 +776,32 @@ class Configuration extends \Doctrine\DBAL\Configuration
     /**
      * Get the entity repository factory.
      *
-     * @since 2.4
-     * @return \Doctrine\ORM\Repository\RepositoryFactory
+     * @return RepositoryFactory
      */
     public function getRepositoryFactory()
     {
-        return isset($this->_attributes['repositoryFactory'])
-            ? $this->_attributes['repositoryFactory']
-            : new DefaultRepositoryFactory();
+        return $this->_attributes['repositoryFactory'] ?? new DefaultRepositoryFactory();
     }
 
     /**
-     * @since 2.5
-     *
-     * @return boolean
+     * @return bool
      */
     public function isSecondLevelCacheEnabled()
     {
-        return isset($this->_attributes['isSecondLevelCacheEnabled'])
-            ? $this->_attributes['isSecondLevelCacheEnabled']
-            : false;
+        return $this->_attributes['isSecondLevelCacheEnabled'] ?? false;
     }
 
     /**
-     * @since 2.5
-     *
-     * @param boolean $flag
+     * @param bool $flag
      *
      * @return void
      */
     public function setSecondLevelCacheEnabled($flag = true)
     {
-        $this->_attributes['isSecondLevelCacheEnabled'] = (boolean) $flag;
+        $this->_attributes['isSecondLevelCacheEnabled'] = (bool) $flag;
     }
 
     /**
-     * @since 2.5
-     *
-     * @param \Doctrine\ORM\Cache\CacheConfiguration $cacheConfig
-     *
      * @return void
      */
     public function setSecondLevelCacheConfiguration(CacheConfiguration $cacheConfig)
@@ -869,39 +810,31 @@ class Configuration extends \Doctrine\DBAL\Configuration
     }
 
     /**
-     * @since 2.5
-     *
-     * @return  \Doctrine\ORM\Cache\CacheConfiguration|null
+     * @return CacheConfiguration|null
      */
     public function getSecondLevelCacheConfiguration()
     {
-        if ( ! isset($this->_attributes['secondLevelCacheConfiguration']) && $this->isSecondLevelCacheEnabled()) {
+        if (! isset($this->_attributes['secondLevelCacheConfiguration']) && $this->isSecondLevelCacheEnabled()) {
             $this->_attributes['secondLevelCacheConfiguration'] = new CacheConfiguration();
         }
 
-        return isset($this->_attributes['secondLevelCacheConfiguration'])
-            ? $this->_attributes['secondLevelCacheConfiguration']
-            : null;
+        return $this->_attributes['secondLevelCacheConfiguration'] ?? null;
     }
 
     /**
      * Returns query hints, which will be applied to every query in application
      *
-     * @since 2.5
-     *
-     * @return array
+     * @psalm-return array<string, mixed>
      */
     public function getDefaultQueryHints()
     {
-        return isset($this->_attributes['defaultQueryHints']) ? $this->_attributes['defaultQueryHints'] : [];
+        return $this->_attributes['defaultQueryHints'] ?? [];
     }
 
     /**
      * Sets array of query hints, which will be applied to every query in application
      *
-     * @since 2.5
-     *
-     * @param array $defaultQueryHints
+     * @psalm-param array<string, mixed> $defaultQueryHints
      */
     public function setDefaultQueryHints(array $defaultQueryHints)
     {
@@ -911,24 +844,18 @@ class Configuration extends \Doctrine\DBAL\Configuration
     /**
      * Gets the value of a default query hint. If the hint name is not recognized, FALSE is returned.
      *
-     * @since 2.5
-     *
      * @param string $name The name of the hint.
      *
      * @return mixed The value of the hint or FALSE, if the hint name is not recognized.
      */
     public function getDefaultQueryHint($name)
     {
-        return isset($this->_attributes['defaultQueryHints'][$name])
-            ? $this->_attributes['defaultQueryHints'][$name]
-            : false;
+        return $this->_attributes['defaultQueryHints'][$name] ?? false;
     }
 
     /**
      * Sets a default query hint. If the hint name is not recognized, it is silently ignored.
      *
-     * @since 2.5
-     *
      * @param string $name  The name of the hint.
      * @param mixed  $value The value of the hint.
      */
