@@ -1,4 +1,5 @@
 <?php
+
 /*
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -19,16 +20,25 @@
 
 namespace Doctrine\ORM;
 
+use BadMethodCallException;
+use Doctrine\Common\Collections\Collection;
 use Doctrine\Common\Collections\Criteria;
 use Doctrine\Common\Collections\Selectable;
 use Doctrine\Inflector\Inflector;
 use Doctrine\Inflector\InflectorFactory;
+use Doctrine\ORM\Mapping\ClassMetadata;
 use Doctrine\ORM\Query\ResultSetMappingBuilder;
 use Doctrine\Persistence\ObjectRepository;
-use const E_USER_DEPRECATED;
+
+use function array_slice;
 use function lcfirst;
+use function sprintf;
+use function strpos;
+use function substr;
 use function trigger_error;
 
+use const E_USER_DEPRECATED;
+
 /**
  * An EntityRepository serves as a repository for entities with generic as well as
  * business specific methods for retrieving entities.
@@ -36,31 +46,19 @@ use function trigger_error;
  * This class is designed for inheritance and users can subclass this class to
  * write their own repositories with business-specific methods to locate entities.
  *
- * @since   2.0
- * @author  Benjamin Eberlei <kontakt@beberlei.de>
- * @author  Guilherme Blanco <guilhermeblanco@hotmail.com>
- * @author  Jonathan Wage <jonwage@gmail.com>
- * @author  Roman Borschel <roman@code-factory.org>
- *
  * @template T
  * @template-implements Selectable<int,T>
  * @template-implements ObjectRepository<T>
  */
 class EntityRepository implements ObjectRepository, Selectable
 {
-    /**
-     * @var string
-     */
+    /** @var string */
     protected $_entityName;
 
-    /**
-     * @var EntityManager
-     */
+    /** @var EntityManager */
     protected $_em;
 
-    /**
-     * @var \Doctrine\ORM\Mapping\ClassMetadata
-     */
+    /** @var ClassMetadata */
     protected $_class;
 
     /** @var Inflector */
@@ -69,7 +67,7 @@ class EntityRepository implements ObjectRepository, Selectable
     /**
      * Initializes a new <tt>EntityRepository</tt>.
      *
-     * @psalm-param Mapping\ClassMetadata<T>
+     * @psalm-param Mapping\ClassMetadata $class
      */
     public function __construct(EntityManagerInterface $em, Mapping\ClassMetadata $class)
     {
@@ -131,8 +129,8 @@ class EntityRepository implements ObjectRepository, Selectable
      */
     public function createNativeNamedQuery($queryName)
     {
-        $queryMapping   = $this->_class->getNamedNativeQuery($queryName);
-        $rsm            = new Query\ResultSetMappingBuilder($this->_em);
+        $queryMapping = $this->_class->getNamedNativeQuery($queryName);
+        $rsm          = new Query\ResultSetMappingBuilder($this->_em);
         $rsm->addNamedNativeQueryMapping($this->_class, $queryMapping);
 
         return $this->_em->createNativeQuery($queryMapping['query'], $rsm);
@@ -141,9 +139,9 @@ class EntityRepository implements ObjectRepository, Selectable
     /**
      * Clears the repository, causing all managed entities to become detached.
      *
-     * @return void
-     *
      * @deprecated 2.8 This method is being removed from the ORM and won't have any replacement
+     *
+     * @return void
      */
     public function clear()
     {
@@ -173,9 +171,7 @@ class EntityRepository implements ObjectRepository, Selectable
     /**
      * Finds all entities in the repository.
      *
-     * @return array The entities.
-     *
-     * @psalm-return list<T>
+     * @psalm-return list<T> The entities.
      */
     public function findAll()
     {
@@ -185,16 +181,14 @@ class EntityRepository implements ObjectRepository, Selectable
     /**
      * Finds entities by a set of criteria.
      *
-     * @param array      $criteria
-     * @param array|null $orderBy
-     * @param int|null   $limit
-     * @param int|null   $offset
+     * @param int|null $limit
+     * @param int|null $offset
      *
-     * @return array The objects.
-     *
-     * @psalm-return list<T>
+     * @psalm-param array<string, mixed> $criteria
+     * @psalm-param array<string, string>|null $orderBy
+     * @psalm-return list<T> The objects.
      */
-    public function findBy(array $criteria, array $orderBy = null, $limit = null, $offset = null)
+    public function findBy(array $criteria, ?array $orderBy = null, $limit = null, $offset = null)
     {
         $persister = $this->_em->getUnitOfWork()->getEntityPersister($this->_entityName);
 
@@ -204,14 +198,13 @@ class EntityRepository implements ObjectRepository, Selectable
     /**
      * Finds a single entity by a set of criteria.
      *
-     * @param array      $criteria
-     * @param array|null $orderBy
-     *
      * @return object|null The entity instance or NULL if the entity can not be found.
      *
+     * @psalm-param array<string, mixed> $criteria
+     * @psalm-param array<string, string>|null $orderBy
      * @psalm-return ?T
      */
-    public function findOneBy(array $criteria, array $orderBy = null)
+    public function findOneBy(array $criteria, ?array $orderBy = null)
     {
         $persister = $this->_em->getUnitOfWork()->getEntityPersister($this->_entityName);
 
@@ -221,11 +214,10 @@ class EntityRepository implements ObjectRepository, Selectable
     /**
      * Counts entities by a set of criteria.
      *
-     * @todo Add this method to `ObjectRepository` interface in the next major release
-     *
-     * @param array $criteria
-     *
      * @return int The cardinality of the objects that match the given criteria.
+     *
+     * @psalm-param array<string, mixed> $criteria
+     * @todo Add this method to `ObjectRepository` interface in the next major release
      */
     public function count(array $criteria)
     {
@@ -236,31 +228,33 @@ class EntityRepository implements ObjectRepository, Selectable
      * Adds support for magic method calls.
      *
      * @param string $method
-     * @param array  $arguments
      *
      * @return mixed The returned value from the resolved method.
      *
      * @throws ORMException
-     * @throws \BadMethodCallException If the method called is invalid
+     * @throws BadMethodCallException If the method called is invalid.
+     *
+     * @psalm-param list<mixed> $arguments
      */
     public function __call($method, $arguments)
     {
-        if (0 === strpos($method, 'findBy')) {
+        if (strpos($method, 'findBy') === 0) {
             return $this->resolveMagicCall('findBy', substr($method, 6), $arguments);
         }
 
-        if (0 === strpos($method, 'findOneBy')) {
+        if (strpos($method, 'findOneBy') === 0) {
             return $this->resolveMagicCall('findOneBy', substr($method, 9), $arguments);
         }
 
-        if (0 === strpos($method, 'countBy')) {
+        if (strpos($method, 'countBy') === 0) {
             return $this->resolveMagicCall('count', substr($method, 7), $arguments);
         }
 
-        throw new \BadMethodCallException(
-            "Undefined method '$method'. The method name must start with ".
-            "either findBy, findOneBy or countBy!"
-        );
+        throw new BadMethodCallException(sprintf(
+            'Undefined method "%s". The method name must start with ' .
+            'either findBy, findOneBy or countBy!',
+            $method
+        ));
     }
 
     /**
@@ -299,11 +293,7 @@ class EntityRepository implements ObjectRepository, Selectable
      * Select all elements from a selectable that match the expression and
      * return a new collection containing these elements.
      *
-     * @param \Doctrine\Common\Collections\Criteria $criteria
-     *
-     * @return \Doctrine\Common\Collections\Collection
-     *
-     * @psalm-return \Doctrine\Common\Collections\Collection<int, T>
+     * @psalm-return Collection<int, T>
      */
     public function matching(Criteria $criteria)
     {
@@ -315,15 +305,16 @@ class EntityRepository implements ObjectRepository, Selectable
     /**
      * Resolves a magic method call to the proper existent method at `EntityRepository`.
      *
-     * @param string $method    The method to call
-     * @param string $by        The property name used as condition
-     * @param array  $arguments The arguments to pass at method call
-     *
-     * @throws ORMException If the method called is invalid or the requested field/association does not exist
+     * @param string $method The method to call
+     * @param string $by     The property name used as condition
      *
      * @return mixed
+     *
+     * @throws ORMException If the method called is invalid or the requested field/association does not exist.
+     *
+     * @psalm-param list<mixed> $arguments The arguments to pass at method call
      */
-    private function resolveMagicCall($method, $by, array $arguments)
+    private function resolveMagicCall(string $method, string $by, array $arguments)
     {
         if (! $arguments) {
             throw ORMException::findByRequiresParameter($method . $by);
