@@ -1,4 +1,5 @@
 <?php
+
 /*
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -23,14 +24,10 @@ use Doctrine\Persistence\Mapping\Driver\SymfonyFileLocator;
 
 /**
  * XmlDriver that additionally looks for mapping information in a global file.
- *
- * @author Fabien Potencier <fabien@symfony.com>
- * @author Benjamin Eberlei <kontakt@beberlei.de>
- * @license MIT
  */
 class SimplifiedXmlDriver extends XmlDriver
 {
-    const DEFAULT_FILE_EXTENSION = '.orm.xml';
+    public const DEFAULT_FILE_EXTENSION = '.orm.xml';
 
     /**
      * {@inheritDoc}
