@@ -1,4 +1,5 @@
 <?php
+
 /*
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -24,24 +25,32 @@ use Doctrine\ORM\Mapping\ClassMetadata as Metadata;
 use Doctrine\ORM\Mapping\MappingException;
 use Doctrine\Persistence\Mapping\ClassMetadata;
 use Doctrine\Persistence\Mapping\Driver\FileDriver;
+use InvalidArgumentException;
 use Symfony\Component\Yaml\Yaml;
-use function interface_exists;
+
+use function array_map;
+use function constant;
+use function defined;
+use function explode;
+use function file_get_contents;
+use function is_array;
+use function is_string;
+use function sprintf;
+use function strlen;
+use function strtoupper;
+use function substr;
 use function trigger_error;
 
+use const E_USER_DEPRECATED;
+
 /**
  * The YamlDriver reads the mapping metadata from yaml schema files.
  *
- * @since 2.0
- * @author Benjamin Eberlei <kontakt@beberlei.de>
- * @author Guilherme Blanco <guilhermeblanco@hotmail.com>
- * @author Jonathan H. Wage <jonwage@gmail.com>
- * @author Roman Borschel <roman@code-factory.org>
- *
  * @deprecated 2.7 This class is being removed from the ORM and won't have any replacement
  */
 class YamlDriver extends FileDriver
 {
-    const DEFAULT_FILE_EXTENSION = '.dcm.yml';
+    public const DEFAULT_FILE_EXTENSION = '.dcm.yml';
 
     /**
      * {@inheritDoc}
@@ -61,22 +70,22 @@ class YamlDriver extends FileDriver
      */
     public function loadMetadataForClass($className, ClassMetadata $metadata)
     {
-        /* @var $metadata \Doctrine\ORM\Mapping\ClassMetadataInfo */
         $element = $this->getElement($className);
 
-        if ($element['type'] == 'entity') {
+        if ($element['type'] === 'entity') {
             if (isset($element['repositoryClass'])) {
                 $metadata->setCustomRepositoryClass($element['repositoryClass']);
             }
-            if (isset($element['readOnly']) && $element['readOnly'] == true) {
+
+            if (isset($element['readOnly']) && $element['readOnly'] === true) {
                 $metadata->markReadOnly();
             }
-        } else if ($element['type'] == 'mappedSuperclass') {
+        } elseif ($element['type'] === 'mappedSuperclass') {
             $metadata->setCustomRepositoryClass(
                 $element['repositoryClass'] ?? null
             );
             $metadata->isMappedSuperclass = true;
-        } else if ($element['type'] == 'embeddable') {
+        } elseif ($element['type'] === 'embeddable') {
             $metadata->isEmbeddedClass = true;
         } else {
             throw MappingException::classIsNotAValidEntityOrMappedSuperClass($className);
@@ -107,7 +116,7 @@ class YamlDriver extends FileDriver
                     $queryMapping = ['query' => $queryMapping];
                 }
 
-                if ( ! isset($queryMapping['name'])) {
+                if (! isset($queryMapping['name'])) {
                     $queryMapping['name'] = $name;
                 }
 
@@ -118,9 +127,10 @@ class YamlDriver extends FileDriver
         // Evaluate named native queries
         if (isset($element['namedNativeQueries'])) {
             foreach ($element['namedNativeQueries'] as $name => $mappingElement) {
-                if (!isset($mappingElement['name'])) {
+                if (! isset($mappingElement['name'])) {
                     $mappingElement['name'] = $name;
                 }
+
                 $metadata->addNamedNativeQuery(
                     [
                         'name'              => $mappingElement['name'],
@@ -135,7 +145,7 @@ class YamlDriver extends FileDriver
         // Evaluate sql result set mappings
         if (isset($element['sqlResultSetMappings'])) {
             foreach ($element['sqlResultSetMappings'] as $name => $resultSetMapping) {
-                if (!isset($resultSetMapping['name'])) {
+                if (! isset($resultSetMapping['name'])) {
                     $resultSetMapping['name'] = $name;
                 }
 
@@ -162,7 +172,6 @@ class YamlDriver extends FileDriver
                     }
                 }
 
-
                 if (isset($resultSetMapping['columnResult'])) {
                     foreach ($resultSetMapping['columnResult'] as $columnResultAnnot) {
                         $columns[] = [
@@ -175,7 +184,7 @@ class YamlDriver extends FileDriver
                     [
                         'name'          => $resultSetMapping['name'],
                         'entities'      => $entities,
-                        'columns'       => $columns
+                        'columns'       => $columns,
                     ]
                 );
             }
@@ -184,7 +193,7 @@ class YamlDriver extends FileDriver
         if (isset($element['inheritanceType'])) {
             $metadata->setInheritanceType(constant('Doctrine\ORM\Mapping\ClassMetadata::INHERITANCE_TYPE_' . strtoupper($element['inheritanceType'])));
 
-            if ($metadata->inheritanceType != Metadata::INHERITANCE_TYPE_NONE) {
+            if ($metadata->inheritanceType !== Metadata::INHERITANCE_TYPE_NONE) {
                 // Evaluate discriminatorColumn
                 if (isset($element['discriminatorColumn'])) {
                     $discrColumn = $element['discriminatorColumn'];
@@ -193,7 +202,7 @@ class YamlDriver extends FileDriver
                             'name' => isset($discrColumn['name']) ? (string) $discrColumn['name'] : null,
                             'type' => isset($discrColumn['type']) ? (string) $discrColumn['type'] : 'string',
                             'length' => isset($discrColumn['length']) ? (string) $discrColumn['length'] : 255,
-                            'columnDefinition' => isset($discrColumn['columnDefinition']) ? (string) $discrColumn['columnDefinition'] : null
+                            'columnDefinition' => isset($discrColumn['columnDefinition']) ? (string) $discrColumn['columnDefinition'] : null,
                         ]
                     );
                 } else {
@@ -207,7 +216,6 @@ class YamlDriver extends FileDriver
             }
         }
 
-
         // Evaluate changeTrackingPolicy
         if (isset($element['changeTrackingPolicy'])) {
             $metadata->setChangeTrackingPolicy(constant('Doctrine\ORM\Mapping\ClassMetadata::CHANGETRACKING_'
@@ -217,7 +225,7 @@ class YamlDriver extends FileDriver
         // Evaluate indexes
         if (isset($element['indexes'])) {
             foreach ($element['indexes'] as $name => $indexYml) {
-                if ( ! isset($indexYml['name'])) {
+                if (! isset($indexYml['name'])) {
                     $indexYml['name'] = $name;
                 }
 
@@ -246,7 +254,7 @@ class YamlDriver extends FileDriver
         // Evaluate uniqueConstraints
         if (isset($element['uniqueConstraints'])) {
             foreach ($element['uniqueConstraints'] as $name => $uniqueYml) {
-                if ( ! isset($uniqueYml['name'])) {
+                if (! isset($uniqueYml['name'])) {
                     $uniqueYml['name'] = $name;
                 }
 
@@ -272,14 +280,14 @@ class YamlDriver extends FileDriver
         if (isset($element['id'])) {
             // Evaluate identifier settings
             foreach ($element['id'] as $name => $idElement) {
-                if (isset($idElement['associationKey']) && $idElement['associationKey'] == true) {
+                if (isset($idElement['associationKey']) && $idElement['associationKey'] === true) {
                     $associationIds[$name] = true;
                     continue;
                 }
 
                 $mapping = [
                     'id' => true,
-                    'fieldName' => $name
+                    'fieldName' => $name,
                 ];
 
                 if (isset($idElement['type'])) {
@@ -308,17 +316,18 @@ class YamlDriver extends FileDriver
                     $metadata->setIdGeneratorType(constant('Doctrine\ORM\Mapping\ClassMetadata::GENERATOR_TYPE_'
                         . strtoupper($idElement['generator']['strategy'])));
                 }
+
                 // Check for SequenceGenerator/TableGenerator definition
                 if (isset($idElement['sequenceGenerator'])) {
                     $metadata->setSequenceGeneratorDefinition($idElement['sequenceGenerator']);
-                } else if (isset($idElement['customIdGenerator'])) {
+                } elseif (isset($idElement['customIdGenerator'])) {
                     $customGenerator = $idElement['customIdGenerator'];
                     $metadata->setCustomGeneratorDefinition(
                         [
-                            'class' => (string) $customGenerator['class']
+                            'class' => (string) $customGenerator['class'],
                         ]
                     );
-                } else if (isset($idElement['tableGenerator'])) {
+                } elseif (isset($idElement['tableGenerator'])) {
                     throw MappingException::tableIdGeneratorNotImplemented($className);
                 }
             }
@@ -327,7 +336,6 @@ class YamlDriver extends FileDriver
         // Evaluate fields
         if (isset($element['fields'])) {
             foreach ($element['fields'] as $name => $fieldMapping) {
-
                 $mapping = $this->columnToArray($name, $fieldMapping);
 
                 if (isset($fieldMapping['id'])) {
@@ -363,7 +371,7 @@ class YamlDriver extends FileDriver
             foreach ($element['oneToOne'] as $name => $oneToOneElement) {
                 $mapping = [
                     'fieldName' => $name,
-                    'targetEntity' => $oneToOneElement['targetEntity']
+                    'targetEntity' => $oneToOneElement['targetEntity'],
                 ];
 
                 if (isset($associationIds[$mapping['fieldName']])) {
@@ -385,9 +393,9 @@ class YamlDriver extends FileDriver
 
                     if (isset($oneToOneElement['joinColumn'])) {
                         $joinColumns[] = $this->joinColumnToArray($oneToOneElement['joinColumn']);
-                    } else if (isset($oneToOneElement['joinColumns'])) {
+                    } elseif (isset($oneToOneElement['joinColumns'])) {
                         foreach ($oneToOneElement['joinColumns'] as $joinColumnName => $joinColumnElement) {
-                            if ( ! isset($joinColumnElement['name'])) {
+                            if (! isset($joinColumnElement['name'])) {
                                 $joinColumnElement['name'] = $joinColumnName;
                             }
 
@@ -421,7 +429,7 @@ class YamlDriver extends FileDriver
                 $mapping = [
                     'fieldName' => $name,
                     'targetEntity' => $oneToManyElement['targetEntity'],
-                    'mappedBy' => $oneToManyElement['mappedBy']
+                    'mappedBy' => $oneToManyElement['mappedBy'],
                 ];
 
                 if (isset($oneToManyElement['fetch'])) {
@@ -444,7 +452,6 @@ class YamlDriver extends FileDriver
                     $mapping['indexBy'] = $oneToManyElement['indexBy'];
                 }
 
-
                 // Evaluate second level cache
                 if (isset($oneToManyElement['cache'])) {
                     $mapping['cache'] = $metadata->getAssociationCacheDefaults($mapping['fieldName'], $this->cacheToArray($oneToManyElement['cache']));
@@ -459,7 +466,7 @@ class YamlDriver extends FileDriver
             foreach ($element['manyToOne'] as $name => $manyToOneElement) {
                 $mapping = [
                     'fieldName' => $name,
-                    'targetEntity' => $manyToOneElement['targetEntity']
+                    'targetEntity' => $manyToOneElement['targetEntity'],
                 ];
 
                 if (isset($associationIds[$mapping['fieldName']])) {
@@ -478,9 +485,9 @@ class YamlDriver extends FileDriver
 
                 if (isset($manyToOneElement['joinColumn'])) {
                     $joinColumns[] = $this->joinColumnToArray($manyToOneElement['joinColumn']);
-                } else if (isset($manyToOneElement['joinColumns'])) {
+                } elseif (isset($manyToOneElement['joinColumns'])) {
                     foreach ($manyToOneElement['joinColumns'] as $joinColumnName => $joinColumnElement) {
-                        if ( ! isset($joinColumnElement['name'])) {
+                        if (! isset($joinColumnElement['name'])) {
                             $joinColumnElement['name'] = $joinColumnName;
                         }
 
@@ -508,7 +515,7 @@ class YamlDriver extends FileDriver
             foreach ($element['manyToMany'] as $name => $manyToManyElement) {
                 $mapping = [
                     'fieldName' => $name,
-                    'targetEntity' => $manyToManyElement['targetEntity']
+                    'targetEntity' => $manyToManyElement['targetEntity'],
                 ];
 
                 if (isset($manyToManyElement['fetch'])) {
@@ -517,11 +524,10 @@ class YamlDriver extends FileDriver
 
                 if (isset($manyToManyElement['mappedBy'])) {
                     $mapping['mappedBy'] = $manyToManyElement['mappedBy'];
-                } else if (isset($manyToManyElement['joinTable'])) {
-
+                } elseif (isset($manyToManyElement['joinTable'])) {
                     $joinTableElement = $manyToManyElement['joinTable'];
-                    $joinTable = [
-                        'name' => $joinTableElement['name']
+                    $joinTable        = [
+                        'name' => $joinTableElement['name'],
                     ];
 
                     if (isset($joinTableElement['schema'])) {
@@ -530,18 +536,20 @@ class YamlDriver extends FileDriver
 
                     if (isset($joinTableElement['joinColumns'])) {
                         foreach ($joinTableElement['joinColumns'] as $joinColumnName => $joinColumnElement) {
-                            if ( ! isset($joinColumnElement['name'])) {
+                            if (! isset($joinColumnElement['name'])) {
                                 $joinColumnElement['name'] = $joinColumnName;
                             }
+
                             $joinTable['joinColumns'][] = $this->joinColumnToArray($joinColumnElement);
                         }
                     }
 
                     if (isset($joinTableElement['inverseJoinColumns'])) {
                         foreach ($joinTableElement['inverseJoinColumns'] as $joinColumnName => $joinColumnElement) {
-                            if ( ! isset($joinColumnElement['name'])) {
+                            if (! isset($joinColumnElement['name'])) {
                                 $joinColumnElement['name'] = $joinColumnName;
                             }
+
                             $joinTable['inverseJoinColumns'][] = $this->joinColumnToArray($joinColumnElement);
                         }
                     }
@@ -580,28 +588,28 @@ class YamlDriver extends FileDriver
 
         // Evaluate associationOverride
         if (isset($element['associationOverride']) && is_array($element['associationOverride'])) {
-
             foreach ($element['associationOverride'] as $fieldName => $associationOverrideElement) {
-                $override   = [];
+                $override = [];
 
                 // Check for joinColumn
                 if (isset($associationOverrideElement['joinColumn'])) {
                     $joinColumns = [];
                     foreach ($associationOverrideElement['joinColumn'] as $name => $joinColumnElement) {
-                        if ( ! isset($joinColumnElement['name'])) {
+                        if (! isset($joinColumnElement['name'])) {
                             $joinColumnElement['name'] = $name;
                         }
+
                         $joinColumns[] = $this->joinColumnToArray($joinColumnElement);
                     }
+
                     $override['joinColumns'] = $joinColumns;
                 }
 
                 // Check for joinTable
                 if (isset($associationOverrideElement['joinTable'])) {
-
-                    $joinTableElement   = $associationOverrideElement['joinTable'];
-                    $joinTable          =  [
-                        'name' => $joinTableElement['name']
+                    $joinTableElement = $associationOverrideElement['joinTable'];
+                    $joinTable        =  [
+                        'name' => $joinTableElement['name'],
                     ];
 
                     if (isset($joinTableElement['schema'])) {
@@ -609,7 +617,7 @@ class YamlDriver extends FileDriver
                     }
 
                     foreach ($joinTableElement['joinColumns'] as $name => $joinColumnElement) {
-                        if ( ! isset($joinColumnElement['name'])) {
+                        if (! isset($joinColumnElement['name'])) {
                             $joinColumnElement['name'] = $name;
                         }
 
@@ -617,7 +625,7 @@ class YamlDriver extends FileDriver
                     }
 
                     foreach ($joinTableElement['inverseJoinColumns'] as $name => $joinColumnElement) {
-                        if ( ! isset($joinColumnElement['name'])) {
+                        if (! isset($joinColumnElement['name'])) {
                             $joinColumnElement['name'] = $name;
                         }
 
@@ -643,7 +651,6 @@ class YamlDriver extends FileDriver
 
         // Evaluate associationOverride
         if (isset($element['attributeOverride']) && is_array($element['attributeOverride'])) {
-
             foreach ($element['attributeOverride'] as $fieldName => $attributeOverrideElement) {
                 $mapping = $this->columnToArray($fieldName, $attributeOverrideElement);
                 $metadata->setAttributeOverride($fieldName, $mapping);
@@ -682,10 +689,17 @@ class YamlDriver extends FileDriver
      * Constructs a joinColumn mapping array based on the information
      * found in the given join column element.
      *
-     * @param array $joinColumnElement The array join column element.
-     *
      * @return mixed[] The mapping array.
      *
+     * @psalm-param array{
+     *                   referencedColumnName?: mixed,
+     *                   name?: mixed,
+     *                   fieldName?: mixed,
+     *                   unique?: mixed,
+     *                   nullable?: mixed,
+     *                   onDelete?: mixed,
+     *                   columnDefinition?: mixed
+     *              } $joinColumnElement The array join column element.
      * @psalm-return array{
      *                   referencedColumnName?: string,
      *                   name?: string,
@@ -696,7 +710,7 @@ class YamlDriver extends FileDriver
      *                   columnDefinition?: mixed
      *               }
      */
-    private function joinColumnToArray($joinColumnElement)
+    private function joinColumnToArray(array $joinColumnElement): array
     {
         $joinColumn = [];
         if (isset($joinColumnElement['referencedColumnName'])) {
@@ -733,11 +747,19 @@ class YamlDriver extends FileDriver
     /**
      * Parses the given column as array.
      *
-     * @param string $fieldName
-     * @param array  $column
-     *
      * @return mixed[]
      *
+     * @psalm-param array{
+     *                   type?: string,
+     *                   column?: string,
+     *                   precision?: mixed,
+     *                   scale?: mixed,
+     *                   unique?: mixed,
+     *                   options?: mixed,
+     *                   nullable?: mixed,
+     *                   version?: mixed,
+     *                   columnDefinition?: mixed
+     *              }|null $column
      * @psalm-return array{
      *                   fieldName: string,
      *                   type?: string,
@@ -752,11 +774,9 @@ class YamlDriver extends FileDriver
      *                   columnDefinition?: mixed
      *               }
      */
-    private function columnToArray($fieldName, $column)
+    private function columnToArray(string $fieldName, ?array $column): array
     {
-        $mapping = [
-            'fieldName' => $fieldName
-        ];
+        $mapping = ['fieldName' => $fieldName];
 
         if (isset($column['type'])) {
             $params = explode('(', $column['type']);
@@ -765,7 +785,7 @@ class YamlDriver extends FileDriver
             $mapping['type'] = $column['type'];
 
             if (isset($params[1])) {
-                $column['length'] = (integer) substr($params[1], 0, strlen($params[1]) - 1);
+                $column['length'] = (int) substr($params[1], 0, strlen($params[1]) - 1);
             }
         }
 
@@ -815,8 +835,8 @@ class YamlDriver extends FileDriver
      *
      * @return mixed[]
      *
-     * @psalm-param array{usage: mixed, region: null|string} $cacheMapping
-     * @psalm-return array{usage: mixed, region: null|string}
+     * @psalm-param array{usage: mixed, region: (string|null)} $cacheMapping
+     * @psalm-return array{usage: mixed, region: (string|null)}
      */
     private function cacheToArray($cacheMapping)
     {
@@ -824,7 +844,7 @@ class YamlDriver extends FileDriver
         $usage  = isset($cacheMapping['usage']) ? strtoupper($cacheMapping['usage']) : null;
 
         if ($usage && ! defined('Doctrine\ORM\Mapping\ClassMetadata::CACHE_USAGE_' . $usage)) {
-            throw new \InvalidArgumentException(sprintf('Invalid cache usage "%s"', $usage));
+            throw new InvalidArgumentException(sprintf('Invalid cache usage "%s"', $usage));
         }
 
         if ($usage) {
