@@ -1,4 +1,5 @@
 <?php
+
 /*
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -19,22 +20,28 @@
 
 namespace Doctrine\ORM\Mapping;
 
+use Doctrine\ORM\ORMException;
+use ReflectionException;
+
+use function array_keys;
+use function array_map;
+use function array_values;
+use function get_parent_class;
+use function implode;
 use function sprintf;
 
 /**
  * A MappingException indicates that something is wrong with the mapping setup.
- *
- * @since 2.0
  */
-class MappingException extends \Doctrine\ORM\ORMException
+class MappingException extends ORMException
 {
     /**
      * @return MappingException
      */
     public static function pathRequired()
     {
-        return new self("Specifying the paths to your entities is required ".
-            "in the AnnotationDriver to retrieve all class names.");
+        return new self('Specifying the paths to your entities is required ' .
+            'in the AnnotationDriver to retrieve all class names.');
     }
 
     /**
@@ -44,10 +51,12 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function identifierRequired($entityName)
     {
-        if (false !== ($parent = get_parent_class($entityName))) {
+        $parent = get_parent_class($entityName);
+        if ($parent !== false) {
             return new self(sprintf(
                 'No identifier/primary key specified for Entity "%s" sub class of "%s". Every Entity must have an identifier/primary key.',
-                $entityName, $parent
+                $entityName,
+                $parent
             ));
         }
 
@@ -55,7 +64,6 @@ class MappingException extends \Doctrine\ORM\ORMException
             'No identifier/primary key specified for Entity "%s". Every Entity must have an identifier/primary key.',
             $entityName
         ));
-
     }
 
     /**
@@ -66,7 +74,7 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function invalidInheritanceType($entityName, $type)
     {
-        return new self("The inheritance type '$type' specified for '$entityName' does not exist.");
+        return new self(sprintf("The inheritance type '%s' specified for '%s' does not exist.", $type, $entityName));
     }
 
     /**
@@ -84,7 +92,10 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function missingFieldName($entity)
     {
-        return new self("The field or association mapping misses the 'fieldName' attribute in entity '$entity'.");
+        return new self(sprintf(
+            "The field or association mapping misses the 'fieldName' attribute in entity '%s'.",
+            $entity
+        ));
     }
 
     /**
@@ -94,7 +105,7 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function missingTargetEntity($fieldName)
     {
-        return new self("The association mapping '$fieldName' misses the 'targetEntity' attribute.");
+        return new self(sprintf("The association mapping '%s' misses the 'targetEntity' attribute.", $fieldName));
     }
 
     /**
@@ -104,7 +115,7 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function missingSourceEntity($fieldName)
     {
-        return new self("The association mapping '$fieldName' misses the 'sourceEntity' attribute.");
+        return new self(sprintf("The association mapping '%s' misses the 'sourceEntity' attribute.", $fieldName));
     }
 
     /**
@@ -114,7 +125,7 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function missingEmbeddedClass($fieldName)
     {
-        return new self("The embed mapping '$fieldName' misses the 'class' attribute.");
+        return new self(sprintf("The embed mapping '%s' misses the 'class' attribute.", $fieldName));
     }
 
     /**
@@ -125,7 +136,7 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function mappingFileNotFound($entityName, $fileName)
     {
-        return new self("No mapping file found named '$fileName' for class '$entityName'.");
+        return new self(sprintf("No mapping file found named '%s' for class '%s'.", $fileName, $entityName));
     }
 
     /**
@@ -138,7 +149,7 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function invalidOverrideFieldName($className, $fieldName)
     {
-        return new self("Invalid field override named '$fieldName' for class '$className'.");
+        return new self(sprintf("Invalid field override named '%s' for class '%s'.", $fieldName, $className));
     }
 
     /**
@@ -151,7 +162,11 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function invalidOverrideFieldType($className, $fieldName)
     {
-        return new self("The column type of attribute '$fieldName' on class '$className' could not be changed.");
+        return new self(sprintf(
+            "The column type of attribute '%s' on class '%s' could not be changed.",
+            $fieldName,
+            $className
+        ));
     }
 
     /**
@@ -162,7 +177,7 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function mappingNotFound($className, $fieldName)
     {
-        return new self("No mapping found for field '$fieldName' on class '$className'.");
+        return new self(sprintf("No mapping found for field '%s' on class '%s'.", $fieldName, $className));
     }
 
     /**
@@ -173,7 +188,7 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function queryNotFound($className, $queryName)
     {
-        return new self("No query found named '$queryName' on class '$className'.");
+        return new self(sprintf("No query found named '%s' on class '%s'.", $queryName, $className));
     }
 
     /**
@@ -184,7 +199,7 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function resultMappingNotFound($className, $resultName)
     {
-        return new self("No result set mapping found named '$resultName' on class '$className'.");
+        return new self(sprintf("No result set mapping found named '%s' on class '%s'.", $resultName, $className));
     }
 
     /**
@@ -195,7 +210,7 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function emptyQueryMapping($entity, $queryName)
     {
-        return new self('Query named "'.$queryName.'" in "'.$entity.'" could not be empty.');
+        return new self(sprintf('Query named "%s" in "%s" could not be empty.', $queryName, $entity));
     }
 
     /**
@@ -205,7 +220,7 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function nameIsMandatoryForQueryMapping($className)
     {
-        return new self("Query name on entity class '$className' is not defined.");
+        return new self(sprintf("Query name on entity class '%s' is not defined.", $className));
     }
 
     /**
@@ -216,7 +231,11 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function missingQueryMapping($entity, $queryName)
     {
-        return new self('Query named "'.$queryName.'" in "'.$entity.' requires a result class or result set mapping.');
+        return new self(sprintf(
+            'Query named "%s" in "%s requires a result class or result set mapping.',
+            $queryName,
+            $entity
+        ));
     }
 
     /**
@@ -227,7 +246,11 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function missingResultSetMappingEntity($entity, $resultName)
     {
-        return new self('Result set mapping named "'.$resultName.'" in "'.$entity.' requires a entity class name.');
+        return new self(sprintf(
+            'Result set mapping named "%s" in "%s requires a entity class name.',
+            $resultName,
+            $entity
+        ));
     }
 
     /**
@@ -238,7 +261,11 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function missingResultSetMappingFieldName($entity, $resultName)
     {
-        return new self('Result set mapping named "'.$resultName.'" in "'.$entity.' requires a field name.');
+        return new self(sprintf(
+            'Result set mapping named "%s" in "%s requires a field name.',
+            $resultName,
+            $entity
+        ));
     }
 
     /**
@@ -248,7 +275,7 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function nameIsMandatoryForSqlResultSetMapping($className)
     {
-        return new self("Result set mapping name on entity class '$className' is not defined.");
+        return new self(sprintf("Result set mapping name on entity class '%s' is not defined.", $className));
     }
 
     /**
@@ -258,7 +285,7 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function oneToManyRequiresMappedBy($fieldName)
     {
-        return new self("OneToMany mapping on field '$fieldName' requires the 'mappedBy' attribute.");
+        return new self(sprintf("OneToMany mapping on field '%s' requires the 'mappedBy' attribute.", $fieldName));
     }
 
     /**
@@ -268,7 +295,7 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function joinTableRequired($fieldName)
     {
-        return new self("The mapping of field '$fieldName' requires an the 'joinTable' attribute.");
+        return new self(sprintf("The mapping of field '%s' requires an the 'joinTable' attribute.", $fieldName));
     }
 
     /**
@@ -281,11 +308,11 @@ class MappingException extends \Doctrine\ORM\ORMException
      *
      * @return MappingException
      */
-    static function missingRequiredOption($field, $expectedOption, $hint = '')
+    public static function missingRequiredOption($field, $expectedOption, $hint = '')
     {
-        $message = "The mapping of field '{$field}' is invalid: The option '{$expectedOption}' is required.";
+        $message = "The mapping of field '" . $field . "' is invalid: The option '" . $expectedOption . "' is required.";
 
-        if ( ! empty($hint)) {
+        if (! empty($hint)) {
             $message .= ' (Hint: ' . $hint . ')';
         }
 
@@ -301,7 +328,7 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function invalidMapping($fieldName)
     {
-        return new self("The mapping of field '$fieldName' is invalid.");
+        return new self(sprintf("The mapping of field '%s' is invalid.", $fieldName));
     }
 
     /**
@@ -309,14 +336,13 @@ class MappingException extends \Doctrine\ORM\ORMException
      * because there might be long classnames that will be shortened
      * within the stacktrace
      *
-     * @param string               $entity            The entity's name
-     * @param \ReflectionException $previousException
+     * @param string $entity The entity's name
      *
      * @return MappingException
      */
-    public static function reflectionFailure($entity, \ReflectionException $previousException)
+    public static function reflectionFailure($entity, ReflectionException $previousException)
     {
-        return new self('An error occurred in ' . $entity, 0, $previousException);
+        return new self(sprintf('An error occurred in %s', $entity), 0, $previousException);
     }
 
     /**
@@ -327,8 +353,11 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function joinColumnMustPointToMappedField($className, $joinColumn)
     {
-        return new self('The column ' . $joinColumn . ' must be mapped to a field in class '
-            . $className . ' since it is referenced by a join column of another class.');
+        return new self(sprintf(
+            'The column %s must be mapped to a field in class %s since it is referenced by a join column of another class.',
+            $joinColumn,
+            $className
+        ));
     }
 
     /**
@@ -338,10 +367,12 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function classIsNotAValidEntityOrMappedSuperClass($className)
     {
-        if (false !== ($parent = get_parent_class($className))) {
+        $parent = get_parent_class($className);
+        if ($parent !== false) {
             return new self(sprintf(
                 'Class "%s" sub class of "%s" is not a valid entity or mapped super class.',
-                $className, $parent
+                $className,
+                $parent
             ));
         }
 
@@ -359,7 +390,11 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function propertyTypeIsRequired($className, $propertyName)
     {
-        return new self("The attribute 'type' is required for the column description of property ".$className."::\$".$propertyName.".");
+        return new self(sprintf(
+            "The attribute 'type' is required for the column description of property %s::\$%s.",
+            $className,
+            $propertyName
+        ));
     }
 
     /**
@@ -369,7 +404,7 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function tableIdGeneratorNotImplemented($className)
     {
-        return new self("TableIdGenerator is not yet implemented for use with class ".$className);
+        return new self(sprintf('TableIdGenerator is not yet implemented for use with class %s', $className));
     }
 
     /**
@@ -380,7 +415,11 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function duplicateFieldMapping($entity, $fieldName)
     {
-        return new self('Property "'.$fieldName.'" in "'.$entity.'" was already declared, but it must be declared only once');
+        return new self(sprintf(
+            'Property "%s" in "%s" was already declared, but it must be declared only once',
+            $fieldName,
+            $entity
+        ));
     }
 
     /**
@@ -391,7 +430,11 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function duplicateAssociationMapping($entity, $fieldName)
     {
-        return new self('Property "'.$fieldName.'" in "'.$entity.'" was already declared, but it must be declared only once');
+        return new self(sprintf(
+            'Property "%s" in "%s" was already declared, but it must be declared only once',
+            $fieldName,
+            $entity
+        ));
     }
 
     /**
@@ -402,7 +445,11 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function duplicateQueryMapping($entity, $queryName)
     {
-        return new self('Query named "'.$queryName.'" in "'.$entity.'" was already declared, but it must be declared only once');
+        return new self(sprintf(
+            'Query named "%s" in "%s" was already declared, but it must be declared only once',
+            $queryName,
+            $entity
+        ));
     }
 
     /**
@@ -413,7 +460,11 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function duplicateResultSetMapping($entity, $resultName)
     {
-        return new self('Result set mapping named "'.$resultName.'" in "'.$entity.'" was already declared, but it must be declared only once');
+        return new self(sprintf(
+            'Result set mapping named "%s" in "%s" was already declared, but it must be declared only once',
+            $resultName,
+            $entity
+        ));
     }
 
     /**
@@ -423,7 +474,7 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function singleIdNotAllowedOnCompositePrimaryKey($entity)
     {
-        return new self('Single id is not allowed on composite primary key in entity '.$entity);
+        return new self('Single id is not allowed on composite primary key in entity ' . $entity);
     }
 
     /**
@@ -445,9 +496,12 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function unsupportedOptimisticLockingType($entity, $fieldName, $unsupportedType)
     {
-        return new self('Locking type "'.$unsupportedType.'" (specified in "'.$entity.'", field "'.$fieldName.'") '
-            .'is not supported by Doctrine.'
-        );
+        return new self(sprintf(
+            'Locking type "%s" (specified in "%s", field "%s") is not supported by Doctrine.',
+            $unsupportedType,
+            $entity,
+            $fieldName
+        ));
     }
 
     /**
@@ -457,7 +511,7 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function fileMappingDriversRequireConfiguredDirectoryPath($path = null)
     {
-        if ( ! empty($path)) {
+        if (! empty($path)) {
             $path = '[' . $path . ']';
         }
 
@@ -478,27 +532,33 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function invalidClassInDiscriminatorMap($className, $owningClass)
     {
-        return new self(
-            "Entity class '$className' used in the discriminator map of class '$owningClass' ".
-            "does not exist."
-        );
+        return new self(sprintf(
+            "Entity class '%s' used in the discriminator map of class '%s' " .
+            'does not exist.',
+            $className,
+            $owningClass
+        ));
     }
 
     /**
-     * @param string $className
-     * @param array  $entries
-     * @param array  $map
+     * @param string               $className
+     * @param string[]             $entries
+     * @param array<string,string> $map
      *
      * @return MappingException
      */
     public static function duplicateDiscriminatorEntry($className, array $entries, array $map)
     {
         return new self(
-            "The entries " . implode(', ', $entries) . " in discriminator map of class '" . $className . "' is duplicated. " .
-            "If the discriminator map is automatically generated you have to convert it to an explicit discriminator map now. " .
-            "The entries of the current map are: @DiscriminatorMap({" . implode(', ', array_map(
-                function($a, $b) { return "'$a': '$b'"; }, array_keys($map), array_values($map)
-            )) . "})"
+            'The entries ' . implode(', ', $entries) . " in discriminator map of class '" . $className . "' is duplicated. " .
+            'If the discriminator map is automatically generated you have to convert it to an explicit discriminator map now. ' .
+            'The entries of the current map are: @DiscriminatorMap({' . implode(', ', array_map(
+                static function ($a, $b) {
+                    return sprintf("'%s': '%s'", $a, $b);
+                },
+                array_keys($map),
+                array_values($map)
+            )) . '})'
         );
     }
 
@@ -509,7 +569,10 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function missingDiscriminatorMap($className)
     {
-        return new self("Entity class '$className' is using inheritance but no discriminator map was defined.");
+        return new self(sprintf(
+            "Entity class '%s' is using inheritance but no discriminator map was defined.",
+            $className
+        ));
     }
 
     /**
@@ -519,7 +582,10 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function missingDiscriminatorColumn($className)
     {
-        return new self("Entity class '$className' is using inheritance but no discriminator column was defined.");
+        return new self(sprintf(
+            "Entity class '%s' is using inheritance but no discriminator column was defined.",
+            $className
+        ));
     }
 
     /**
@@ -530,7 +596,11 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function invalidDiscriminatorColumnType($className, $type)
     {
-        return new self("Discriminator column type on entity class '$className' is not allowed to be '$type'. 'string' or 'integer' type variables are suggested!");
+        return new self(sprintf(
+            "Discriminator column type on entity class '%s' is not allowed to be '%s'. 'string' or 'integer' type variables are suggested!",
+            $className,
+            $type
+        ));
     }
 
     /**
@@ -540,7 +610,7 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function nameIsMandatoryForDiscriminatorColumns($className)
     {
-        return new self("Discriminator column name on entity class '$className' is not defined.");
+        return new self(sprintf("Discriminator column name on entity class '%s' is not defined.", $className));
     }
 
     /**
@@ -551,7 +621,11 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function cannotVersionIdField($className, $fieldName)
     {
-        return new self("Setting Id field '$fieldName' as versionable in entity class '$className' is not supported.");
+        return new self(sprintf(
+            "Setting Id field '%s' as versionable in entity class '%s' is not supported.",
+            $fieldName,
+            $className
+        ));
     }
 
     /**
@@ -563,7 +637,13 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function sqlConversionNotAllowedForIdentifiers($className, $fieldName, $type)
     {
-        return new self("It is not possible to set id field '$fieldName' to type '$type' in entity class '$className'. The type '$type' requires conversion SQL which is not allowed for identifiers.");
+        return new self(sprintf(
+            "It is not possible to set id field '%s' to type '%s' in entity class '%s'. The type '%s' requires conversion SQL which is not allowed for identifiers.",
+            $fieldName,
+            $type,
+            $className,
+            $type
+        ));
     }
 
     /**
@@ -574,7 +654,7 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function duplicateColumnName($className, $columnName)
     {
-        return new self("Duplicate definition of column '".$columnName."' on entity '".$className."' in a field or discriminator column mapping.");
+        return new self("Duplicate definition of column '" . $columnName . "' on entity '" . $className . "' in a field or discriminator column mapping.");
     }
 
     /**
@@ -585,7 +665,7 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function illegalToManyAssociationOnMappedSuperclass($className, $field)
     {
-        return new self("It is illegal to put an inverse side one-to-many or many-to-many association on mapped superclass '".$className."#".$field."'.");
+        return new self("It is illegal to put an inverse side one-to-many or many-to-many association on mapped superclass '" . $className . '#' . $field . "'.");
     }
 
     /**
@@ -597,8 +677,8 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function cannotMapCompositePrimaryKeyEntitiesAsForeignId($className, $targetEntity, $targetField)
     {
-        return new self("It is not possible to map entity '".$className."' with a composite primary key ".
-            "as part of the primary key of another entity '".$targetEntity."#".$targetField."'.");
+        return new self("It is not possible to map entity '" . $className . "' with a composite primary key " .
+            "as part of the primary key of another entity '" . $targetEntity . '#' . $targetField . "'.");
     }
 
     /**
@@ -609,7 +689,7 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function noSingleAssociationJoinColumnFound($className, $field)
     {
-        return new self("'$className#$field' is not an association with a single join column.");
+        return new self(sprintf("'%s#%s' is not an association with a single join column.", $className, $field));
     }
 
     /**
@@ -620,8 +700,12 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function noFieldNameFoundForColumn($className, $column)
     {
-        return new self("Cannot find a field on '$className' that is mapped to column '$column'. Either the ".
-            "field does not exist or an association exists but it has multiple join columns.");
+        return new self(sprintf(
+            "Cannot find a field on '%s' that is mapped to column '%s'. Either the " .
+            'field does not exist or an association exists but it has multiple join columns.',
+            $className,
+            $column
+        ));
     }
 
     /**
@@ -632,8 +716,11 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function illegalOrphanRemovalOnIdentifierAssociation($className, $field)
     {
-        return new self("The orphan removal option is not allowed on an association that is ".
-            "part of the identifier in '$className#$field'.");
+        return new self(sprintf(
+            "The orphan removal option is not allowed on an association that is part of the identifier in '%s#%s'.",
+            $className,
+            $field
+        ));
     }
 
     /**
@@ -644,8 +731,8 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function illegalOrphanRemoval($className, $field)
     {
-        return new self("Orphan removal is only allowed on one-to-one and one-to-many ".
-            "associations, but " . $className."#" .$field . " is not.");
+        return new self('Orphan removal is only allowed on one-to-one and one-to-many ' .
+            'associations, but ' . $className . '#' . $field . ' is not.');
     }
 
     /**
@@ -656,7 +743,11 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function illegalInverseIdentifierAssociation($className, $field)
     {
-        return new self("An inverse association is not allowed to be identifier in '$className#$field'.");
+        return new self(sprintf(
+            "An inverse association is not allowed to be identifier in '%s#%s'.",
+            $className,
+            $field
+        ));
     }
 
     /**
@@ -667,7 +758,11 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function illegalToManyIdentifierAssociation($className, $field)
     {
-        return new self("Many-to-many or one-to-many associations are not allowed to be identifier in '$className#$field'.");
+        return new self(sprintf(
+            "Many-to-many or one-to-many associations are not allowed to be identifier in '%s#%s'.",
+            $className,
+            $field
+        ));
     }
 
     /**
@@ -690,8 +785,8 @@ class MappingException extends \Doctrine\ORM\ORMException
     {
         return new self(
             "Entity '" . $className . "' has to be part of the discriminator map of '" . $rootClassName . "' " .
-            "to be properly mapped in the inheritance hierarchy. Alternatively you can make '".$className."' an abstract class " .
-            "to avoid this exception from occurring."
+            "to be properly mapped in the inheritance hierarchy. Alternatively you can make '" . $className . "' an abstract class " .
+            'to avoid this exception from occurring.'
         );
     }
 
@@ -710,7 +805,7 @@ class MappingException extends \Doctrine\ORM\ORMException
      * @param string $listenerName
      * @param string $className
      *
-     * @return \Doctrine\ORM\Mapping\MappingException
+     * @return MappingException
      */
     public static function entityListenerClassNotFound($listenerName, $className)
     {
@@ -722,7 +817,7 @@ class MappingException extends \Doctrine\ORM\ORMException
      * @param string $methodName
      * @param string $className
      *
-     * @return \Doctrine\ORM\Mapping\MappingException
+     * @return MappingException
      */
     public static function entityListenerMethodNotFound($listenerName, $methodName, $className)
     {
@@ -734,7 +829,7 @@ class MappingException extends \Doctrine\ORM\ORMException
      * @param string $methodName
      * @param string $className
      *
-     * @return \Doctrine\ORM\Mapping\MappingException
+     * @return MappingException
      */
     public static function duplicateEntityListener($listenerName, $methodName, $className)
     {
@@ -759,7 +854,7 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function compositeKeyAssignedIdGeneratorRequired($className)
     {
-        return new self("Entity '". $className . "' has a composite identifier but uses an ID generator other than manually assigning (Identity, Sequence). This is not supported.");
+        return new self("Entity '" . $className . "' has a composite identifier but uses an ID generator other than manually assigning (Identity, Sequence). This is not supported.");
     }
 
     /**
@@ -771,19 +866,21 @@ class MappingException extends \Doctrine\ORM\ORMException
      */
     public static function invalidTargetEntityClass($targetEntity, $sourceEntity, $associationName)
     {
-        return new self("The target-entity " . $targetEntity . " cannot be found in '" . $sourceEntity."#".$associationName."'.");
+        return new self('The target-entity ' . $targetEntity . " cannot be found in '" . $sourceEntity . '#' . $associationName . "'.");
     }
 
     /**
-     * @param array  $cascades
-     * @param string $className
-     * @param string $propertyName
+     * @param string[] $cascades
+     * @param string   $className
+     * @param string   $propertyName
      *
      * @return MappingException
      */
     public static function invalidCascadeOption(array $cascades, $className, $propertyName)
     {
-        $cascades = implode(", ", array_map(function ($e) { return "'" . $e . "'"; }, $cascades));
+        $cascades = implode(', ', array_map(static function ($e) {
+            return "'" . $e . "'";
+        }, $cascades));
 
         return new self(sprintf(
             "You have specified invalid cascade options for %s::$%s: %s; available options: 'remove', 'persist', 'refresh', 'merge', and 'detach'",
@@ -823,6 +920,9 @@ class MappingException extends \Doctrine\ORM\ORMException
         );
     }
 
+    /**
+     * @return MappingException
+     */
     public static function illegalOverrideOfInheritedProperty($className, $propertyName)
     {
         return new self(
