@@ -1,4 +1,5 @@
 <?php
+
 /*
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -19,8 +20,11 @@
 
 namespace Doctrine\ORM;
 
+use Doctrine\Common\Cache\Cache;
 use Doctrine\Common\Collections\ArrayCollection;
 use Doctrine\DBAL\LockMode;
+use Doctrine\DBAL\Types\Type;
+use Doctrine\ORM\Internal\Hydration\IterableResult;
 use Doctrine\ORM\Mapping\ClassMetadata;
 use Doctrine\ORM\Query\AST\DeleteStatement;
 use Doctrine\ORM\Query\AST\SelectStatement;
@@ -32,174 +36,156 @@ use Doctrine\ORM\Query\Parser;
 use Doctrine\ORM\Query\ParserResult;
 use Doctrine\ORM\Query\QueryException;
 use Doctrine\ORM\Utility\HierarchyDiscriminatorResolver;
+
 use function array_keys;
+use function array_values;
 use function assert;
+use function count;
+use function in_array;
+use function ksort;
+use function md5;
+use function reset;
+use function serialize;
+use function sha1;
+use function stripos;
 
 /**
  * A Query object represents a DQL query.
- *
- * @since   1.0
- * @author  Guilherme Blanco <guilhermeblanco@hotmail.com>
- * @author  Konsta Vesterinen <kvesteri@cc.hut.fi>
- * @author  Roman Borschel <roman@code-factory.org>
  */
 final class Query extends AbstractQuery
 {
     /**
      * A query object is in CLEAN state when it has NO unparsed/unprocessed DQL parts.
      */
-    const STATE_CLEAN  = 1;
+    public const STATE_CLEAN = 1;
 
     /**
      * A query object is in state DIRTY when it has DQL parts that have not yet been
      * parsed/processed. This is automatically defined as DIRTY when addDqlQueryPart
      * is called.
      */
-    const STATE_DIRTY = 2;
+    public const STATE_DIRTY = 2;
 
     /* Query HINTS */
 
     /**
      * The refresh hint turns any query into a refresh query with the result that
      * any local changes in entities are overridden with the fetched values.
-     *
-     * @var string
      */
-    const HINT_REFRESH = 'doctrine.refresh';
+    public const HINT_REFRESH = 'doctrine.refresh';
 
-    /**
-     * @var string
-     */
-    const HINT_CACHE_ENABLED = 'doctrine.cache.enabled';
+    public const HINT_CACHE_ENABLED = 'doctrine.cache.enabled';
 
-    /**
-     * @var string
-     */
-    const HINT_CACHE_EVICT = 'doctrine.cache.evict';
+    public const HINT_CACHE_EVICT = 'doctrine.cache.evict';
 
     /**
      * Internal hint: is set to the proxy entity that is currently triggered for loading
-     *
-     * @var string
      */
-    const HINT_REFRESH_ENTITY = 'doctrine.refresh.entity';
+    public const HINT_REFRESH_ENTITY = 'doctrine.refresh.entity';
 
     /**
      * The forcePartialLoad query hint forces a particular query to return
      * partial objects.
      *
-     * @var string
      * @todo Rename: HINT_OPTIMIZE
      */
-    const HINT_FORCE_PARTIAL_LOAD = 'doctrine.forcePartialLoad';
+    public const HINT_FORCE_PARTIAL_LOAD = 'doctrine.forcePartialLoad';
 
     /**
      * The includeMetaColumns query hint causes meta columns like foreign keys and
      * discriminator columns to be selected and returned as part of the query result.
      *
      * This hint does only apply to non-object queries.
-     *
-     * @var string
      */
-    const HINT_INCLUDE_META_COLUMNS = 'doctrine.includeMetaColumns';
+    public const HINT_INCLUDE_META_COLUMNS = 'doctrine.includeMetaColumns';
 
     /**
      * An array of class names that implement \Doctrine\ORM\Query\TreeWalker and
      * are iterated and executed after the DQL has been parsed into an AST.
-     *
-     * @var string
      */
-    const HINT_CUSTOM_TREE_WALKERS = 'doctrine.customTreeWalkers';
+    public const HINT_CUSTOM_TREE_WALKERS = 'doctrine.customTreeWalkers';
 
     /**
      * A string with a class name that implements \Doctrine\ORM\Query\TreeWalker
      * and is used for generating the target SQL from any DQL AST tree.
-     *
-     * @var string
      */
-    const HINT_CUSTOM_OUTPUT_WALKER = 'doctrine.customOutputWalker';
+    public const HINT_CUSTOM_OUTPUT_WALKER = 'doctrine.customOutputWalker';
 
     //const HINT_READ_ONLY = 'doctrine.readOnly';
 
-    /**
-     * @var string
-     */
-    const HINT_INTERNAL_ITERATION = 'doctrine.internal.iteration';
+    public const HINT_INTERNAL_ITERATION = 'doctrine.internal.iteration';
 
-    /**
-     * @var string
-     */
-    const HINT_LOCK_MODE = 'doctrine.lockMode';
+    public const HINT_LOCK_MODE = 'doctrine.lockMode';
 
     /**
      * The current state of this query.
      *
-     * @var integer
+     * @var int
      */
     private $_state = self::STATE_DIRTY;
 
     /**
      * A snapshot of the parameter types the query was parsed with.
      *
-     * @var array
+     * @var array<string,Type>
      */
-    private $_parsedTypes = [];
+    private $parsedTypes = [];
 
     /**
      * Cached DQL query.
      *
      * @var string|null
      */
-    private $_dql = null;
+    private $dql = null;
 
     /**
      * The parser result that holds DQL => SQL information.
      *
-     * @var \Doctrine\ORM\Query\ParserResult
+     * @var ParserResult
      */
-    private $_parserResult;
+    private $parserResult;
 
     /**
      * The first result to return (the "offset").
      *
      * @var int|null
      */
-    private $_firstResult = null;
+    private $firstResult = null;
 
     /**
      * The maximum number of results to return (the "limit").
      *
-     * @var integer|null
+     * @var int|null
      */
-    private $_maxResults = null;
+    private $maxResults = null;
 
     /**
      * The cache driver used for caching queries.
      *
-     * @var \Doctrine\Common\Cache\Cache|null
+     * @var Cache|null
      */
-    private $_queryCache;
+    private $queryCache;
 
     /**
      * Whether or not expire the query cache.
      *
-     * @var boolean
+     * @var bool
      */
-    private $_expireQueryCache = false;
+    private $expireQueryCache = false;
 
     /**
      * The query cache lifetime.
      *
      * @var int
      */
-    private $_queryCacheTTL;
+    private $queryCacheTTL;
 
     /**
      * Whether to use a query cache, if available. Defaults to TRUE.
      *
-     * @var boolean
+     * @var bool
      */
-    private $_useQueryCache = true;
+    private $useQueryCache = true;
 
     /**
      * Gets the SQL query/queries that correspond to this DQL query.
@@ -210,7 +196,7 @@ final class Query extends AbstractQuery
      */
     public function getSQL()
     {
-        return $this->_parse()->getSqlExecutor()->getSqlStatements();
+        return $this->parse()->getSqlExecutor()->getSqlStatements();
     }
 
     /**
@@ -232,7 +218,7 @@ final class Query extends AbstractQuery
     {
         // parse query or load from cache
         if ($this->_resultSetMapping === null) {
-            $this->_resultSetMapping = $this->_parse()->getResultSetMapping();
+            $this->_resultSetMapping = $this->parse()->getResultSetMapping();
         }
 
         return $this->_resultSetMapping;
@@ -243,9 +229,9 @@ final class Query extends AbstractQuery
      *
      * Note: Populates $this->_parserResult as a side-effect.
      *
-     * @return \Doctrine\ORM\Query\ParserResult
+     * @return ParserResult
      */
-    private function _parse()
+    private function parse()
     {
         $types = [];
 
@@ -255,40 +241,41 @@ final class Query extends AbstractQuery
         }
 
         // Return previous parser result if the query and the filter collection are both clean
-        if ($this->_state === self::STATE_CLEAN && $this->_parsedTypes === $types && $this->_em->isFiltersStateClean()) {
-            return $this->_parserResult;
+        if ($this->_state === self::STATE_CLEAN && $this->parsedTypes === $types && $this->_em->isFiltersStateClean()) {
+            return $this->parserResult;
         }
 
-        $this->_state = self::STATE_CLEAN;
-        $this->_parsedTypes = $types;
+        $this->_state      = self::STATE_CLEAN;
+        $this->parsedTypes = $types;
 
+        $queryCache = $this->getQueryCacheDriver();
         // Check query cache.
-        if ( ! ($this->_useQueryCache && ($queryCache = $this->getQueryCacheDriver()))) {
+        if (! ($this->useQueryCache && $queryCache)) {
             $parser = new Parser($this);
 
-            $this->_parserResult = $parser->parse();
+            $this->parserResult = $parser->parse();
 
-            return $this->_parserResult;
+            return $this->parserResult;
         }
 
-        $hash   = $this->_getQueryCacheId();
-        $cached = $this->_expireQueryCache ? false : $queryCache->fetch($hash);
+        $hash   = $this->getQueryCacheId();
+        $cached = $this->expireQueryCache ? false : $queryCache->fetch($hash);
 
         if ($cached instanceof ParserResult) {
             // Cache hit.
-            $this->_parserResult = $cached;
+            $this->parserResult = $cached;
 
-            return $this->_parserResult;
+            return $this->parserResult;
         }
 
         // Cache miss.
         $parser = new Parser($this);
 
-        $this->_parserResult = $parser->parse();
+        $this->parserResult = $parser->parse();
 
-        $queryCache->save($hash, $this->_parserResult, $this->_queryCacheTTL);
+        $queryCache->save($hash, $this->parserResult, $this->queryCacheTTL);
 
-        return $this->_parserResult;
+        return $this->parserResult;
     }
 
     /**
@@ -296,7 +283,7 @@ final class Query extends AbstractQuery
      */
     protected function _doExecute()
     {
-        $executor = $this->_parse()->getSqlExecutor();
+        $executor = $this->parse()->getSqlExecutor();
 
         if ($this->_queryCacheProfile) {
             $executor->setQueryCacheProfile($this->_queryCacheProfile);
@@ -305,13 +292,13 @@ final class Query extends AbstractQuery
         }
 
         if ($this->_resultSetMapping === null) {
-            $this->_resultSetMapping = $this->_parserResult->getResultSetMapping();
+            $this->_resultSetMapping = $this->parserResult->getResultSetMapping();
         }
 
         // Prepare parameters
-        $paramMappings = $this->_parserResult->getParameterMappings();
-        $paramCount = count($this->parameters);
-        $mappingCount = count($paramMappings);
+        $paramMappings = $this->parserResult->getParameterMappings();
+        $paramCount    = count($this->parameters);
+        $mappingCount  = count($paramMappings);
 
         if ($paramCount > $mappingCount) {
             throw QueryException::tooManyParameters($mappingCount, $paramCount);
@@ -338,13 +325,18 @@ final class Query extends AbstractQuery
         return $executor->execute($this->_em->getConnection(), $sqlParams, $types);
     }
 
+    /**
+     * @param array<string,mixed> $sqlParams
+     * @param array<string,Type>  $types
+     * @param array<string,mixed> $connectionParams
+     */
     private function evictResultSetCache(
         AbstractSqlExecutor $executor,
         array $sqlParams,
         array $types,
         array $connectionParams
     ) {
-        if (null === $this->_queryCacheProfile || ! $this->getExpireResultCache()) {
+        if ($this->_queryCacheProfile === null || ! $this->getExpireResultCache()) {
             return;
         }
 
@@ -379,7 +371,7 @@ final class Query extends AbstractQuery
     /**
      * Processes query parameter mappings.
      *
-     * @param array $paramMappings
+     * @param Parameter[] $paramMappings
      *
      * @return mixed[][]
      *
@@ -387,7 +379,7 @@ final class Query extends AbstractQuery
      *
      * @psalm-return array{0: list<mixed>, 1: array}
      */
-    private function processParameterMappings($paramMappings) : array
+    private function processParameterMappings(array $paramMappings): array
     {
         $sqlParams = [];
         $types     = [];
@@ -395,7 +387,7 @@ final class Query extends AbstractQuery
         foreach ($this->parameters as $parameter) {
             $key = $parameter->getName();
 
-            if ( ! isset($paramMappings[$key])) {
+            if (! isset($paramMappings[$key])) {
                 throw QueryException::unknownParameter($key);
             }
 
@@ -409,15 +401,15 @@ final class Query extends AbstractQuery
 
             // optimized multi value sql positions away for now,
             // they are not allowed in DQL anyways.
-            $value = [$value];
+            $value      = [$value];
             $countValue = count($value);
 
             for ($i = 0, $l = count($sqlPositions); $i < $l; $i++) {
-                $sqlParams[$sqlPositions[$i]] = $value[($i % $countValue)];
+                $sqlParams[$sqlPositions[$i]] = $value[$i % $countValue];
             }
         }
 
-        if (count($sqlParams) != count($types)) {
+        if (count($sqlParams) !== count($types)) {
             throw QueryException::parameterTypeMismatch();
         }
 
@@ -437,7 +429,7 @@ final class Query extends AbstractQuery
      *
      * @psalm-return array{0: mixed, 1: mixed}
      */
-    private function resolveParameterValue(Parameter $parameter) : array
+    private function resolveParameterValue(Parameter $parameter): array
     {
         if ($parameter->typeWasSpecified()) {
             return [$parameter->getValue(), $parameter->getType()];
@@ -471,13 +463,13 @@ final class Query extends AbstractQuery
     /**
      * Defines a cache driver to be used for caching queries.
      *
-     * @param \Doctrine\Common\Cache\Cache|null $queryCache Cache driver.
+     * @param Cache|null $queryCache Cache driver.
      *
      * @return self This query instance.
      */
-    public function setQueryCacheDriver($queryCache) : self
+    public function setQueryCacheDriver($queryCache): self
     {
-        $this->_queryCache = $queryCache;
+        $this->queryCache = $queryCache;
 
         return $this;
     }
@@ -485,13 +477,13 @@ final class Query extends AbstractQuery
     /**
      * Defines whether the query should make use of a query cache, if available.
      *
-     * @param boolean $bool
+     * @param bool $bool
      *
      * @return self This query instance.
      */
-    public function useQueryCache($bool) : self
+    public function useQueryCache($bool): self
     {
-        $this->_useQueryCache = $bool;
+        $this->useQueryCache = $bool;
 
         return $this;
     }
@@ -499,13 +491,13 @@ final class Query extends AbstractQuery
     /**
      * Returns the cache driver used for query caching.
      *
-     * @return \Doctrine\Common\Cache\Cache|null The cache driver used for query caching or NULL, if
-     *                                           this Query does not use query caching.
+     * @return Cache|null The cache driver used for query caching or NULL, if
+     * this Query does not use query caching.
      */
     public function getQueryCacheDriver()
     {
-        if ($this->_queryCache) {
-            return $this->_queryCache;
+        if ($this->queryCache) {
+            return $this->queryCache;
         }
 
         return $this->_em->getConfiguration()->getQueryCacheImpl();
@@ -514,17 +506,17 @@ final class Query extends AbstractQuery
     /**
      * Defines how long the query cache will be active before expire.
      *
-     * @param integer $timeToLive How long the cache entry is valid.
+     * @param int $timeToLive How long the cache entry is valid.
      *
      * @return self This query instance.
      */
-    public function setQueryCacheLifetime($timeToLive) : self
+    public function setQueryCacheLifetime($timeToLive): self
     {
         if ($timeToLive !== null) {
             $timeToLive = (int) $timeToLive;
         }
 
-        $this->_queryCacheTTL = $timeToLive;
+        $this->queryCacheTTL = $timeToLive;
 
         return $this;
     }
@@ -536,19 +528,19 @@ final class Query extends AbstractQuery
      */
     public function getQueryCacheLifetime()
     {
-        return $this->_queryCacheTTL;
+        return $this->queryCacheTTL;
     }
 
     /**
      * Defines if the query cache is active or not.
      *
-     * @param boolean $expire Whether or not to force query cache expiration.
+     * @param bool $expire Whether or not to force query cache expiration.
      *
      * @return self This query instance.
      */
-    public function expireQueryCache($expire = true) : self
+    public function expireQueryCache($expire = true): self
     {
-        $this->_expireQueryCache = $expire;
+        $this->expireQueryCache = $expire;
 
         return $this;
     }
@@ -560,7 +552,7 @@ final class Query extends AbstractQuery
      */
     public function getExpireQueryCache()
     {
-        return $this->_expireQueryCache;
+        return $this->expireQueryCache;
     }
 
     /**
@@ -570,7 +562,7 @@ final class Query extends AbstractQuery
     {
         parent::free();
 
-        $this->_dql = null;
+        $this->dql    = null;
         $this->_state = self::STATE_CLEAN;
     }
 
@@ -579,10 +571,10 @@ final class Query extends AbstractQuery
      *
      * @param string $dqlQuery DQL Query.
      */
-    public function setDQL($dqlQuery) : self
+    public function setDQL($dqlQuery): self
     {
         if ($dqlQuery !== null) {
-            $this->_dql = $dqlQuery;
+            $this->dql    = $dqlQuery;
             $this->_state = self::STATE_DIRTY;
         }
 
@@ -596,7 +588,7 @@ final class Query extends AbstractQuery
      */
     public function getDQL()
     {
-        return $this->_dql;
+        return $this->dql;
     }
 
     /**
@@ -607,7 +599,7 @@ final class Query extends AbstractQuery
      * @see AbstractQuery::STATE_CLEAN
      * @see AbstractQuery::STATE_DIRTY
      *
-     * @return integer The query state.
+     * @return int The query state.
      */
     public function getState()
     {
@@ -619,7 +611,7 @@ final class Query extends AbstractQuery
      *
      * @param string $dql Arbitrary piece of DQL to check for.
      *
-     * @return boolean
+     * @return bool
      */
     public function contains($dql)
     {
@@ -633,10 +625,10 @@ final class Query extends AbstractQuery
      *
      * @return self This query object.
      */
-    public function setFirstResult($firstResult) : self
+    public function setFirstResult($firstResult): self
     {
-        $this->_firstResult = $firstResult;
-        $this->_state       = self::STATE_DIRTY;
+        $this->firstResult = $firstResult;
+        $this->_state      = self::STATE_DIRTY;
 
         return $this;
     }
@@ -649,20 +641,20 @@ final class Query extends AbstractQuery
      */
     public function getFirstResult()
     {
-        return $this->_firstResult;
+        return $this->firstResult;
     }
 
     /**
      * Sets the maximum number of results to retrieve (the "limit").
      *
-     * @param integer|null $maxResults
+     * @param int|null $maxResults
      *
      * @return self This query object.
      */
-    public function setMaxResults($maxResults) : self
+    public function setMaxResults($maxResults): self
     {
-        $this->_maxResults = $maxResults;
-        $this->_state      = self::STATE_DIRTY;
+        $this->maxResults = $maxResults;
+        $this->_state     = self::STATE_DIRTY;
 
         return $this;
     }
@@ -671,21 +663,23 @@ final class Query extends AbstractQuery
      * Gets the maximum number of results the query object was set to retrieve (the "limit").
      * Returns NULL if {@link setMaxResults} was not applied to this query.
      *
-     * @return integer|null Maximum number of results.
+     * @return int|null Maximum number of results.
      */
     public function getMaxResults()
     {
-        return $this->_maxResults;
+        return $this->maxResults;
     }
 
     /**
      * Executes the query and returns an IterableResult that can be used to incrementally
      * iterated over the result.
      *
-     * @param ArrayCollection|array|null $parameters    The query parameters.
-     * @param string|int                 $hydrationMode The hydration mode to use.
+     * @deprecated
      *
-     * @return \Doctrine\ORM\Internal\Hydration\IterableResult
+     * @param ArrayCollection|mixed[]|null $parameters    The query parameters.
+     * @param string|int                   $hydrationMode The hydration mode to use.
+     *
+     * @return IterableResult
      */
     public function iterate($parameters = null, $hydrationMode = self::HYDRATE_OBJECT)
     {
@@ -695,7 +689,7 @@ final class Query extends AbstractQuery
     }
 
     /** {@inheritDoc} */
-    public function toIterable(iterable $parameters = [], $hydrationMode = self::HYDRATE_OBJECT) : iterable
+    public function toIterable(iterable $parameters = [], $hydrationMode = self::HYDRATE_OBJECT): iterable
     {
         $this->setHint(self::HINT_INTERNAL_ITERATION, true);
 
@@ -731,10 +725,10 @@ final class Query extends AbstractQuery
      *
      * @throws TransactionRequiredException
      */
-    public function setLockMode($lockMode) : self
+    public function setLockMode($lockMode): self
     {
         if (in_array($lockMode, [LockMode::NONE, LockMode::PESSIMISTIC_READ, LockMode::PESSIMISTIC_WRITE], true)) {
-            if ( ! $this->_em->getConnection()->isTransactionActive()) {
+            if (! $this->_em->getConnection()->isTransactionActive()) {
                 throw TransactionRequiredException::transactionRequired();
             }
         }
@@ -753,7 +747,7 @@ final class Query extends AbstractQuery
     {
         $lockMode = $this->getHint(self::HINT_LOCK_MODE);
 
-        if (false === $lockMode) {
+        if ($lockMode === false) {
             return null;
         }
 
@@ -762,10 +756,8 @@ final class Query extends AbstractQuery
 
     /**
      * Generate a cache id for the query cache - reusing the Result-Cache-Id generator.
-     *
-     * @return string
      */
-    protected function _getQueryCacheId()
+    protected function getQueryCacheId(): string
     {
         ksort($this->_hints);
 
@@ -778,17 +770,17 @@ final class Query extends AbstractQuery
             $this->getDQL() . serialize($this->_hints) .
             '&platform=' . $platform .
             ($this->_em->hasFilters() ? $this->_em->getFilters()->getHash() : '') .
-            '&firstResult=' . $this->_firstResult . '&maxResult=' . $this->_maxResults .
-            '&hydrationMode=' . $this->_hydrationMode . '&types=' . serialize($this->_parsedTypes) . 'DOCTRINE_QUERY_CACHE_SALT'
+            '&firstResult=' . $this->firstResult . '&maxResult=' . $this->maxResults .
+            '&hydrationMode=' . $this->_hydrationMode . '&types=' . serialize($this->parsedTypes) . 'DOCTRINE_QUERY_CACHE_SALT'
         );
     }
 
      /**
-     * {@inheritdoc}
-     */
+      * {@inheritdoc}
+      */
     protected function getHash()
     {
-        return sha1(parent::getHash(). '-'. $this->_firstResult . '-' . $this->_maxResults);
+        return sha1(parent::getHash() . '-' . $this->firstResult . '-' . $this->maxResults);
     }
 
     /**
