@@ -1,4 +1,5 @@
 <?php
+
 /*
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -19,13 +20,17 @@
 
 namespace Doctrine\ORM\Query;
 
+use Doctrine\ORM\Configuration;
+use Doctrine\ORM\EntityManager;
 use Doctrine\ORM\EntityManagerInterface;
+use Doctrine\ORM\Query\Filter\SQLFilter;
+use InvalidArgumentException;
+
 use function assert;
+use function ksort;
 
 /**
  * Collection class for all the query filters.
- *
- * @author Alexander <iam.asm89@gmail.com>
  */
 class FilterCollection
 {
@@ -34,59 +39,50 @@ class FilterCollection
     /**
      * A filter object is in CLEAN state when it has no changed parameters.
      */
-    const FILTERS_STATE_CLEAN  = 1;
+    public const FILTERS_STATE_CLEAN = 1;
 
     /**
      * A filter object is in DIRTY state when it has changed parameters.
      */
-    const FILTERS_STATE_DIRTY = 2;
+    public const FILTERS_STATE_DIRTY = 2;
 
     /**
      * The used Configuration.
      *
-     * @var \Doctrine\ORM\Configuration
+     * @var Configuration
      */
     private $config;
 
     /**
      * The EntityManager that "owns" this FilterCollection instance.
      *
-     * @var \Doctrine\ORM\EntityManager
+     * @var EntityManager
      */
     private $em;
 
     /**
      * Instances of enabled filters.
      *
-     * @var \Doctrine\ORM\Query\Filter\SQLFilter[]
+     * @var SQLFilter[]
      */
     private $enabledFilters = [];
 
-    /**
-     * @var string The filter hash from the last time the query was parsed.
-     */
+    /** @var string The filter hash from the last time the query was parsed. */
     private $filterHash;
 
-    /**
-     * @var integer The current state of this filter.
-     */
+    /** @var int The current state of this filter. */
     private $filtersState = self::FILTERS_STATE_CLEAN;
 
-    /**
-     * Constructor.
-     *
-     * @param EntityManagerInterface $em
-     */
     public function __construct(EntityManagerInterface $em)
     {
-        $this->em = $em;
+        $this->em     = $em;
         $this->config = $em->getConfiguration();
     }
 
     /**
      * Gets all the enabled filters.
      *
-     * @return \Doctrine\ORM\Query\Filter\SQLFilter[] The enabled filters.
+     * @return SQLFilter[] The enabled filters.
      */
     public function getEnabledFilters()
     {
@@ -98,17 +94,17 @@ class FilterCollection
      *
      * @param string $name Name of the filter.
      *
-     * @return \Doctrine\ORM\Query\Filter\SQLFilter The enabled filter.
+     * @return SQLFilter The enabled filter.
      *
-     * @throws \InvalidArgumentException If the filter does not exist.
+     * @throws InvalidArgumentException If the filter does not exist.
      */
     public function enable($name)
     {
-        if ( ! $this->has($name)) {
-            throw new \InvalidArgumentException("Filter '" . $name . "' does not exist.");
+        if (! $this->has($name)) {
+            throw new InvalidArgumentException("Filter '" . $name . "' does not exist.");
         }
 
-        if ( ! $this->isEnabled($name)) {
+        if (! $this->isEnabled($name)) {
             $filterClass = $this->config->getFilterClassName($name);
 
             assert($filterClass !== null);
@@ -130,9 +126,9 @@ class FilterCollection
      *
      * @param string $name Name of the filter.
      *
-     * @return \Doctrine\ORM\Query\Filter\SQLFilter The disabled filter.
+     * @return SQLFilter The disabled filter.
      *
-     * @throws \InvalidArgumentException If the filter does not exist.
+     * @throws InvalidArgumentException If the filter does not exist.
      */
     public function disable($name)
     {
@@ -152,14 +148,14 @@ class FilterCollection
      *
      * @param string $name Name of the filter.
      *
-     * @return \Doctrine\ORM\Query\Filter\SQLFilter The filter.
+     * @return SQLFilter The filter.
      *
-     * @throws \InvalidArgumentException If the filter is not enabled.
+     * @throws InvalidArgumentException If the filter is not enabled.
      */
     public function getFilter($name)
     {
-        if ( ! $this->isEnabled($name)) {
-            throw new \InvalidArgumentException("Filter '" . $name . "' is not enabled.");
+        if (! $this->isEnabled($name)) {
+            throw new InvalidArgumentException("Filter '" . $name . "' is not enabled.");
         }
 
         return $this->enabledFilters[$name];
@@ -174,7 +170,7 @@ class FilterCollection
      */
     public function has($name)
     {
-        return null !== $this->config->getFilterClassName($name);
+        return $this->config->getFilterClassName($name) !== null;
     }
 
     /**
@@ -182,7 +178,7 @@ class FilterCollection
      *
      * @param string $name Name of the filter.
      *
-     * @return boolean True if the filter is enabled, false otherwise.
+     * @return bool True if the filter is enabled, false otherwise.
      */
     public function isEnabled($name)
     {
@@ -190,11 +186,11 @@ class FilterCollection
     }
 
     /**
-     * @return boolean True, if the filter collection is clean.
+     * @return bool True, if the filter collection is clean.
      */
     public function isClean()
     {
-        return self::FILTERS_STATE_CLEAN === $this->filtersState;
+        return $this->filtersState === self::FILTERS_STATE_CLEAN;
     }
 
     /**
@@ -205,7 +201,7 @@ class FilterCollection
     public function getHash()
     {
         // If there are only clean filters, the previous hash can be returned
-        if (self::FILTERS_STATE_CLEAN === $this->filtersState) {
+        if ($this->filtersState === self::FILTERS_STATE_CLEAN) {
             return $this->filterHash;
         }
 
