@@ -1,4 +1,5 @@
 <?php
+
 /*
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -20,22 +21,26 @@
 namespace Doctrine\ORM\Tools\Export\Driver;
 
 use Doctrine\ORM\Mapping\ClassMetadataInfo;
+use DOMDocument;
 use SimpleXMLElement;
 
+use function array_search;
+use function count;
+use function implode;
+use function is_array;
+use function strcmp;
+use function uasort;
+
 /**
  * ClassMetadata exporter for Doctrine XML mapping files.
  *
- * @link    www.doctrine-project.org
- * @since   2.0
- * @author  Jonathan Wage <jonwage@gmail.com>
- *
  * @deprecated 2.7 This class is being removed from the ORM and won't have any replacement
+ *
+ * @link    www.doctrine-project.org
  */
 class XmlExporter extends AbstractExporter
 {
-    /**
-     * @var string
-     */
+    /** @var string */
     protected $_extension = '.dcm.xml';
 
     /**
@@ -43,7 +48,7 @@ class XmlExporter extends AbstractExporter
      */
     public function exportClassMetadata(ClassMetadataInfo $metadata)
     {
-        $xml = new SimpleXmlElement('<?xml version="1.0" encoding="utf-8"?><doctrine-mapping ' .
+        $xml = new SimpleXMLElement('<?xml version="1.0" encoding="utf-8"?><doctrine-mapping ' .
             'xmlns="http://doctrine-project.org/schemas/orm/doctrine-mapping" ' .
             'xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" ' .
             'xsi:schemaLocation="http://doctrine-project.org/schemas/orm/doctrine-mapping https://www.doctrine-project.org/schemas/orm/doctrine-mapping.xsd" />');
@@ -100,7 +105,7 @@ class XmlExporter extends AbstractExporter
 
         $trackingPolicy = $this->_getChangeTrackingPolicyString($metadata->changeTrackingPolicy);
 
-        if ( $trackingPolicy != 'DEFERRED_IMPLICIT') {
+        if ($trackingPolicy !== 'DEFERRED_IMPLICIT') {
             $root->addChild('change-tracking-policy', $trackingPolicy);
         }
 
@@ -141,13 +146,16 @@ class XmlExporter extends AbstractExporter
             if (isset($assoc['id']) && $assoc['id']) {
                 $id[$name] = [
                     'fieldName' => $name,
-                    'associationKey' => true
+                    'associationKey' => true,
                 ];
             }
         }
 
-        if ( ! $metadata->isIdentifierComposite && $idGeneratorType = $this->_getIdGeneratorTypeString($metadata->generatorType)) {
-            $id[$metadata->getSingleIdentifierFieldName()]['generator']['strategy'] = $idGeneratorType;
+        if (! $metadata->isIdentifierComposite) {
+            $idGeneratorType = $this->_getIdGeneratorTypeString($metadata->generatorType);
+            if ($idGeneratorType) {
+                $id[$metadata->getSingleIdentifierFieldName()]['generator']['strategy'] = $idGeneratorType;
+            }
         }
 
         if ($id) {
@@ -171,7 +179,8 @@ class XmlExporter extends AbstractExporter
                     $idXml->addAttribute('association-key', 'true');
                 }
 
-                if ($idGeneratorType = $this->_getIdGeneratorTypeString($metadata->generatorType)) {
+                $idGeneratorType = $this->_getIdGeneratorTypeString($metadata->generatorType);
+                if ($idGeneratorType) {
                     $generatorXml = $idXml->addChild('generator');
                     $generatorXml->addAttribute('strategy', $idGeneratorType);
 
@@ -203,7 +212,7 @@ class XmlExporter extends AbstractExporter
                 }
 
                 if (isset($field['unique']) && $field['unique']) {
-                    $fieldXml->addAttribute('unique', $field['unique'] ? 'true' : 'false');
+                    $fieldXml->addAttribute('unique', 'true');
                 }
 
                 if (isset($field['options'])) {
@@ -235,7 +244,7 @@ class XmlExporter extends AbstractExporter
             ClassMetadataInfo::MANY_TO_MANY,
         ];
 
-        uasort($metadata->associationMappings, function($m1, $m2) use (&$orderMap){
+        uasort($metadata->associationMappings, static function ($m1, $m2) use (&$orderMap) {
             $a1 = array_search($m1['type'], $orderMap);
             $a2 = array_search($m2['type'], $orderMap);
 
@@ -244,13 +253,13 @@ class XmlExporter extends AbstractExporter
 
         foreach ($metadata->associationMappings as $associationMapping) {
             $associationMappingXml = null;
-            if ($associationMapping['type'] == ClassMetadataInfo::ONE_TO_ONE) {
+            if ($associationMapping['type'] === ClassMetadataInfo::ONE_TO_ONE) {
                 $associationMappingXml = $root->addChild('one-to-one');
-            } elseif ($associationMapping['type'] == ClassMetadataInfo::MANY_TO_ONE) {
+            } elseif ($associationMapping['type'] === ClassMetadataInfo::MANY_TO_ONE) {
                 $associationMappingXml = $root->addChild('many-to-one');
-            } elseif ($associationMapping['type'] == ClassMetadataInfo::ONE_TO_MANY) {
+            } elseif ($associationMapping['type'] === ClassMetadataInfo::ONE_TO_MANY) {
                 $associationMappingXml = $root->addChild('one-to-many');
-            } elseif ($associationMapping['type'] == ClassMetadataInfo::MANY_TO_MANY) {
+            } elseif ($associationMapping['type'] === ClassMetadataInfo::MANY_TO_MANY) {
                 $associationMappingXml = $root->addChild('many-to-many');
             }
 
@@ -299,7 +308,7 @@ class XmlExporter extends AbstractExporter
             }
 
             if (count($cascade) === 5) {
-                $cascade  = ['cascade-all'];
+                $cascade = ['cascade-all'];
             }
 
             if ($cascade) {
@@ -349,6 +358,7 @@ class XmlExporter extends AbstractExporter
                     }
                 }
             }
+
             if (isset($associationMapping['joinColumns'])) {
                 $joinColumnsXml = $associationMappingXml->addChild('join-columns');
 
@@ -370,6 +380,7 @@ class XmlExporter extends AbstractExporter
                     }
                 }
             }
+
             if (isset($associationMapping['orderBy'])) {
                 $orderByXml = $associationMappingXml->addChild('order-by');
 
@@ -381,7 +392,7 @@ class XmlExporter extends AbstractExporter
             }
         }
 
-        if (isset($metadata->lifecycleCallbacks) && count($metadata->lifecycleCallbacks)>0) {
+        if (isset($metadata->lifecycleCallbacks) && count($metadata->lifecycleCallbacks) > 0) {
             $lifecycleCallbacksXml = $root->addChild('lifecycle-callbacks');
 
             foreach ($metadata->lifecycleCallbacks as $name => $methods) {
@@ -395,16 +406,15 @@ class XmlExporter extends AbstractExporter
 
         $this->processEntityListeners($metadata, $root);
 
-        return $this->_asXml($xml);
+        return $this->asXml($xml);
     }
 
     /**
      * Exports (nested) option elements.
      *
-     * @param SimpleXMLElement $parentXml
-     * @param array            $options
+     * @param mixed[] $options
      */
-    private function exportTableOptions(SimpleXMLElement $parentXml, array $options) : void
+    private function exportTableOptions(SimpleXMLElement $parentXml, array $options): void
     {
         foreach ($options as $name => $option) {
             $isArray   = is_array($option);
@@ -422,13 +432,8 @@ class XmlExporter extends AbstractExporter
 
     /**
      * Export sequence information (if available/configured) into the current identifier XML node
-     *
-     * @param SimpleXMLElement  $identifierXmlNode
-     * @param ClassMetadataInfo $metadata
-     *
-     * @return void
      */
-    private function exportSequenceInformation(SimpleXMLElement $identifierXmlNode, ClassMetadataInfo $metadata) : void
+    private function exportSequenceInformation(SimpleXMLElement $identifierXmlNode, ClassMetadataInfo $metadata): void
     {
         $sequenceDefinition = $metadata->sequenceGeneratorDefinition;
 
@@ -443,9 +448,9 @@ class XmlExporter extends AbstractExporter
         $sequenceGeneratorXml->addAttribute('initial-value', $sequenceDefinition['initialValue']);
     }
 
-    private function _asXml(SimpleXMLElement $simpleXml) : string
+    private function asXml(SimpleXMLElement $simpleXml): string
     {
-        $dom = new \DOMDocument('1.0', 'UTF-8');
+        $dom = new DOMDocument('1.0', 'UTF-8');
         $dom->loadXML($simpleXml->asXML());
         $dom->formatOutput = true;
 
@@ -454,18 +459,24 @@ class XmlExporter extends AbstractExporter
 
     private function processEntityListeners(ClassMetadataInfo $metadata, SimpleXMLElement $root): void
     {
-        if (0 === \count($metadata->entityListeners)) {
+        if (count($metadata->entityListeners) === 0) {
             return;
         }
 
-        $entityListenersXml = $root->addChild('entity-listeners');
+        $entityListenersXml    = $root->addChild('entity-listeners');
         $entityListenersXmlMap = [];
 
         $this->generateEntityListenerXml($metadata, $entityListenersXmlMap, $entityListenersXml);
     }
 
-    private function generateEntityListenerXml(ClassMetadataInfo $metadata, array $entityListenersXmlMap, SimpleXMLElement $entityListenersXml): void
-    {
+    /**
+     * @param mixed[] $entityListenersXmlMap
+     */
+    private function generateEntityListenerXml(
+        ClassMetadataInfo $metadata,
+        array $entityListenersXmlMap,
+        SimpleXMLElement $entityListenersXml
+    ): void {
         foreach ($metadata->entityListeners as $event => $entityListenerConfig) {
             foreach ($entityListenerConfig as $entityListener) {
                 $entityListenerXml = $this->addClassToMapIfExists(
@@ -481,8 +492,15 @@ class XmlExporter extends AbstractExporter
         }
     }
 
-    private function addClassToMapIfExists(array $entityListenersXmlMap, array $entityListener, SimpleXMLElement $entityListenersXml): SimpleXMLElement
-    {
+    /**
+     * @param mixed[] $entityListenersXmlMap
+     * @param mixed[] $entityListener
+     */
+    private function addClassToMapIfExists(
+        array $entityListenersXmlMap,
+        array $entityListener,
+        SimpleXMLElement $entityListenersXml
+    ): SimpleXMLElement {
         if (isset($entityListenersXmlMap[$entityListener['class']])) {
             return $entityListenersXmlMap[$entityListener['class']];
         }
