@@ -1,4 +1,5 @@
 <?php
+
 /*
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -20,50 +21,43 @@
 namespace Doctrine\ORM\Tools\Pagination;
 
 use ArrayIterator;
+use Countable;
+use Doctrine\Common\Collections\Collection;
 use Doctrine\ORM\NoResultException;
 use Doctrine\ORM\Query;
+use Doctrine\ORM\Query\Parameter;
 use Doctrine\ORM\Query\Parser;
 use Doctrine\ORM\Query\ResultSetMapping;
 use Doctrine\ORM\QueryBuilder;
+use IteratorAggregate;
+
+use function array_key_exists;
 use function array_map;
 use function array_sum;
+use function count;
 
 /**
  * The paginator can handle various complex scenarios with DQL.
  *
- * @author Pablo Díez <pablodip@gmail.com>
- * @author Benjamin Eberlei <kontakt@beberlei.de>
- * @license New BSD
- *
  * @template T
  */
-class Paginator implements \Countable, \IteratorAggregate
+class Paginator implements Countable, IteratorAggregate
 {
-    /**
-     * @var Query
-     */
+    /** @var Query */
     private $query;
 
-    /**
-     * @var bool
-     */
+    /** @var bool */
     private $fetchJoinCollection;
 
-    /**
-     * @var bool|null
-     */
+    /** @var bool|null */
     private $useOutputWalkers;
 
-    /**
-     * @var int
-     */
+    /** @var int */
     private $count;
 
     /**
-     * Constructor.
-     *
      * @param Query|QueryBuilder $query               A Doctrine ORM query or query builder.
-     * @param boolean            $fetchJoinCollection Whether the query joins a collection (true by default).
+     * @param bool               $fetchJoinCollection Whether the query joins a collection (true by default).
      */
     public function __construct($query, $fetchJoinCollection = true)
     {
@@ -71,7 +65,7 @@ class Paginator implements \Countable, \IteratorAggregate
             $query = $query->getQuery();
         }
 
-        $this->query = $query;
+        $this->query               = $query;
         $this->fetchJoinCollection = (bool) $fetchJoinCollection;
     }
 
@@ -88,7 +82,7 @@ class Paginator implements \Countable, \IteratorAggregate
     /**
      * Returns whether the query joins a collection.
      *
-     * @return boolean Whether the query joins a collection.
+     * @return bool Whether the query joins a collection.
      */
     public function getFetchJoinCollection()
     {
@@ -138,7 +132,7 @@ class Paginator implements \Countable, \IteratorAggregate
     /**
      * {@inheritdoc}
      *
-     * @return ArrayIterator<mixed, T>
+     * @psalm-return ArrayIterator<array-key, T>
      */
     public function getIterator()
     {
@@ -180,8 +174,7 @@ class Paginator implements \Countable, \IteratorAggregate
                 ->setMaxResults($length)
                 ->setFirstResult($offset)
                 ->setCacheable($this->query->isCacheable())
-                ->getResult($this->query->getHydrationMode())
-            ;
+                ->getResult($this->query->getHydrationMode());
         }
 
         return new ArrayIterator($result);
@@ -227,7 +220,6 @@ class Paginator implements \Countable, \IteratorAggregate
     /**
      * Appends a custom tree walker to the tree walkers hint.
      *
-     * @param Query  $query
      * @param string $walkerClass
      */
     private function appendTreeWalker(Query $query, $walkerClass)
@@ -251,7 +243,7 @@ class Paginator implements \Countable, \IteratorAggregate
     {
         $countQuery = $this->cloneQuery($this->query);
 
-        if ( ! $countQuery->hasHint(CountWalker::HINT_DISTINCT)) {
+        if (! $countQuery->hasHint(CountWalker::HINT_DISTINCT)) {
             $countQuery->setHint(CountWalker::HINT_DISTINCT, true);
         }
 
@@ -277,13 +269,13 @@ class Paginator implements \Countable, \IteratorAggregate
     {
         $parser            = new Parser($query);
         $parameterMappings = $parser->parse()->getParameterMappings();
-        /* @var $parameters \Doctrine\Common\Collections\Collection|\Doctrine\ORM\Query\Parameter[] */
-        $parameters        = $query->getParameters();
+        /** @var Collection|Parameter[] $parameters */
+        $parameters = $query->getParameters();
 
         foreach ($parameters as $key => $parameter) {
             $parameterName = $parameter->getName();
 
-            if ( ! (isset($parameterMappings[$parameterName]) || array_key_exists($parameterName, $parameterMappings))) {
+            if (! (isset($parameterMappings[$parameterName]) || array_key_exists($parameterName, $parameterMappings))) {
                 unset($parameters[$key]);
             }
         }
