@@ -2,9 +2,8 @@
 
 namespace Doctrine\ORM\Utility;
 
-use Doctrine\Persistence\Mapping\ClassMetadata;
 use Doctrine\ORM\EntityManagerInterface;
-use function interface_exists;
+use Doctrine\Persistence\Mapping\ClassMetadata;
 
 /**
  * @internal This class exists only to avoid code duplication, do not reuse it externally
@@ -18,21 +17,25 @@ final class HierarchyDiscriminatorResolver
     /**
      * This method is needed to make INSTANCEOF work correctly with inheritance: if the class at hand has inheritance,
      * it extracts all the discriminators from the child classes and returns them
+     *
+     * @return null[]
+     *
+     * @psalm-return array<array-key, null>
      */
     public static function resolveDiscriminatorsForClass(
         ClassMetadata $rootClassMetadata,
         EntityManagerInterface $entityManager
     ): array {
-        $hierarchyClasses = $rootClassMetadata->subClasses;
+        $hierarchyClasses   = $rootClassMetadata->subClasses;
         $hierarchyClasses[] = $rootClassMetadata->name;
 
         $discriminators = [];
 
         foreach ($hierarchyClasses as $class) {
-            $currentMetadata = $entityManager->getClassMetadata($class);
+            $currentMetadata      = $entityManager->getClassMetadata($class);
             $currentDiscriminator = $currentMetadata->discriminatorValue;
 
-            if (null !== $currentDiscriminator) {
+            if ($currentDiscriminator !== null) {
                 $discriminators[$currentDiscriminator] = null;
             }
         }
@@ -40,5 +43,3 @@ final class HierarchyDiscriminatorResolver
         return $discriminators;
     }
 }
-
-interface_exists(ClassMetadata::class);
