@@ -1,8 +1,9 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Performance\Mock;
 
-use Doctrine\ORM\Query;
 use Doctrine\ORM\UnitOfWork;
 use Doctrine\Tests\ORM\Performance\PersisterMock;
 
@@ -11,9 +12,7 @@ use Doctrine\Tests\ORM\Performance\PersisterMock;
  */
 class NonProxyLoadingUnitOfWork extends UnitOfWork
 {
-    /**
-     * @var PersisterMock
-     */
+    /** @var PersisterMock */
     private $entityPersister;
 
     public function __construct()
