@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Mocks;
 
 use Doctrine\ORM\Cache\CacheEntry;
@@ -8,22 +10,28 @@ use Doctrine\ORM\Cache\CollectionCacheEntry;
 use Doctrine\ORM\Cache\Lock;
 use Doctrine\ORM\Cache\Region;
 
+use function array_shift;
+
 /**
  * Cache region mock
  */
 class CacheRegionMock implements Region
 {
-    public $calls   = [];
+    /** @var array<string, list<array<string, mixed>>> */
+    public $calls = [];
+
+    /** @var array<string, mixed> */
     public $returns = [];
+
+    /** @var string */
     public $name;
 
     /**
      * Queue a return value for a specific method invocation
      *
-     * @param string $method
      * @param mixed $value
      */
-    public function addReturn($method, $value)
+    public function addReturn(string $method, $value): void
     {
         $this->returns[$method][] = $value;
     }
@@ -31,12 +39,11 @@ class CacheRegionMock implements Region
     /**
      * Dequeue a value for a specific method invocation
      *
-     * @param string $method
      * @param mixed $default
      *
      * @return mixed
      */
-    private function getReturn($method, $default)
+    private function getReturn(string $method, $default)
     {
         if (isset($this->returns[$method]) && ! empty($this->returns[$method])) {
             return array_shift($this->returns[$method]);
@@ -108,14 +115,14 @@ class CacheRegionMock implements Region
     /**
      * {@inheritdoc}
      */
-    public function put(CacheKey $key, CacheEntry $entry, Lock $lock = null)
+    public function put(CacheKey $key, CacheEntry $entry, ?Lock $lock = null)
     {
         $this->calls[__FUNCTION__][] = ['key' => $key, 'entry' => $entry];
 
         return $this->getReturn(__FUNCTION__, true);
     }
 
-    public function clear()
+    public function clear(): void
     {
         $this->calls   = [];
         $this->returns = [];
