@@ -1,18 +1,18 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Mocks;
 
 use Doctrine\DBAL\Connection;
 use Doctrine\DBAL\Schema\AbstractSchemaManager;
+use Exception;
 
 /**
  * Mock class for AbstractSchemaManager.
  */
 class SchemaManagerMock extends AbstractSchemaManager
 {
-    /**
-     * @param \Doctrine\DBAL\Connection $conn
-     */
     public function __construct(Connection $conn)
     {
         parent::__construct($conn);
@@ -23,5 +23,6 @@ class SchemaManagerMock extends AbstractSchemaManager
      */
     protected function _getPortableTableColumnDefinition($tableColumn)
     {
+        throw new Exception('not implemented');
     }
 }
