@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\CMS;
 
 /**
@@ -9,20 +11,26 @@ namespace Doctrine\Tests\Models\CMS;
 class CmsPhonenumber
 {
     /**
-     * @Id @Column(length=50)
+     * @var string
+     * @Id
+     * @Column(length=50)
      */
     public $phonenumber;
+
     /**
+     * @var CmsUser
      * @ManyToOne(targetEntity="CmsUser", inversedBy="phonenumbers", cascade={"merge"})
      * @JoinColumn(name="user_id", referencedColumnName="id")
      */
     public $user;
 
-    public function setUser(CmsUser $user) {
+    public function setUser(CmsUser $user): void
+    {
         $this->user = $user;
     }
 
-    public function getUser() {
+    public function getUser(): ?CmsUser
+    {
         return $this->user;
     }
 }
