@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\Cache;
 
 /**
@@ -9,22 +11,23 @@ namespace Doctrine\Tests\Models\Cache;
 class AttractionContactInfo extends AttractionInfo
 {
     /**
+     * @var string
      * @Column(unique=true)
      */
     protected $fone;
 
-    public function __construct($fone, Attraction $attraction)
+    public function __construct(string $fone, Attraction $attraction)
     {
         $this->setAttraction($attraction);
         $this->setFone($fone);
     }
 
-    public function getFone()
+    public function getFone(): string
     {
         return $this->fone;
     }
 
-    public function setFone($fone)
+    public function setFone(string $fone): void
     {
         $this->fone = $fone;
     }
