@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\Cache;
 
 /**
@@ -9,22 +11,23 @@ namespace Doctrine\Tests\Models\Cache;
 class AttractionLocationInfo extends AttractionInfo
 {
     /**
+     * @var string
      * @Column(unique=true)
      */
     protected $address;
 
-    public function __construct($address, Attraction $attraction)
+    public function __construct(string $address, Attraction $attraction)
     {
         $this->setAttraction($attraction);
         $this->setAddress($address);
     }
 
-    public function getAddress()
+    public function getAddress(): string
     {
         return $this->address;
     }
 
-    public function setAddress($address)
+    public function setAddress(string $address): void
     {
         $this->address = $address;
     }
