@@ -1,8 +1,11 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\Cache;
 
 use Doctrine\Common\Collections\ArrayCollection;
+use Doctrine\Common\Collections\Collection;
 
 /**
  * @Entity
@@ -11,11 +14,13 @@ use Doctrine\Common\Collections\ArrayCollection;
 class ComplexAction
 {
     /**
+     * @var string
      * @Column
      */
     public $name;
 
     /**
+     * @var Action
      * @Id
      * @OneToOne(targetEntity="Action", cascade={"persist", "remove"})
      * @JoinColumn(name="action1_name", referencedColumnName="name")
@@ -23,6 +28,7 @@ class ComplexAction
     public $action1;
 
     /**
+     * @var Action
      * @Id
      * @OneToOne(targetEntity="Action", cascade={"persist", "remove"})
      * @JoinColumn(name="action2_name", referencedColumnName="name")
@@ -30,36 +36,31 @@ class ComplexAction
     public $action2;
 
     /**
+     * @psalm-var Collection<int, Token>
      * @OneToMany(targetEntity="Token", cascade={"persist", "remove"}, mappedBy="complexAction")
      */
     public $tokens;
 
-    public function __construct(Action $action1, Action $action2, $name)
+    public function __construct(Action $action1, Action $action2, string $name)
     {
-        $this->name = $name;
+        $this->name    = $name;
         $this->action1 = $action1;
         $this->action2 = $action2;
-        $this->tokens = new ArrayCollection();
+        $this->tokens  = new ArrayCollection();
     }
 
-    public function addToken(Token $token)
+    public function addToken(Token $token): void
     {
-        $this->tokens[] = $token;
+        $this->tokens[]       = $token;
         $token->complexAction = $this;
     }
 
-    /**
-     * @return Action
-     */
-    public function getAction1()
+    public function getAction1(): Action
     {
         return $this->action1;
     }
 
-    /**
-     * @return Action
-     */
-    public function getAction2()
+    public function getAction2(): Action
     {
         return $this->action2;
     }
