@@ -1,7 +1,11 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\Cache;
 
+use DateTime;
+
 /**
  * @Entity
  * @Table("cache_flight")
@@ -10,6 +14,7 @@ namespace Doctrine\Tests\Models\Cache;
 class Flight
 {
     /**
+     * @var City
      * @Id
      * @Cache
      * @ManyToOne(targetEntity="City")
@@ -18,6 +23,7 @@ class Flight
     protected $leavingFrom;
 
     /**
+     * @var City
      * @Id
      * @Cache
      * @ManyToOne(targetEntity="City")
@@ -26,37 +32,34 @@ class Flight
     protected $goingTo;
 
     /**
+     * @var DateTime
      * @Column(type="date")
      */
     protected $departure;
 
-    /**
-     * @param \Doctrine\Tests\Models\Cache\City $leavingFrom
-     * @param \Doctrine\Tests\Models\Cache\City $goingTo
-     */
     public function __construct(City $leavingFrom, City $goingTo)
     {
-        $this->goingTo      = $goingTo;
-        $this->leavingFrom  = $leavingFrom;
-        $this->departure    = new \DateTime();
+        $this->goingTo     = $goingTo;
+        $this->leavingFrom = $leavingFrom;
+        $this->departure   = new DateTime();
     }
 
-    public function getLeavingFrom()
+    public function getLeavingFrom(): City
     {
         return $this->leavingFrom;
     }
 
-    public function getGoingTo()
+    public function getGoingTo(): City
     {
         return $this->goingTo;
     }
 
-    public function getDeparture()
+    public function getDeparture(): DateTime
     {
         return $this->departure;
     }
 
-    public function setDeparture($departure)
+    public function setDeparture(DateTime $departure): void
     {
         $this->departure = $departure;
     }
