@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\CustomType;
 
 use Doctrine\Tests\DbalTypes\CustomIdObject;
@@ -12,20 +14,16 @@ class CustomIdObjectTypeChild
 {
     /**
      * @Id @Column(type="CustomIdObject")
-     *
      * @var CustomIdObject
      */
     public $id;
 
     /**
+     * @var CustomIdObjectTypeParent
      * @ManyToOne(targetEntity="Doctrine\Tests\Models\CustomType\CustomIdObjectTypeParent", inversedBy="children")
      */
     public $parent;
 
-    /**
-     * @param CustomIdObject           $id
-     * @param CustomIdObjectTypeParent $parent
-     */
     public function __construct(CustomIdObject $id, CustomIdObjectTypeParent $parent)
     {
         $this->id     = $id;
