@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\DDC1590;
 
 use Doctrine\Tests\Models\DDC1590\DDC1590Entity;
@@ -11,8 +13,8 @@ use Doctrine\Tests\Models\DDC1590\DDC1590Entity;
 class DDC1590User extends DDC1590Entity
 {
     /**
+     * @var string
      * @Column(type="string", length=255)
      */
     protected $name;
-
 }
