@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\DDC3579;
 
 /**
@@ -13,11 +15,8 @@ namespace Doctrine\Tests\Models\DDC3579;
  */
 class DDC3579Admin extends DDC3579User
 {
-    public static function loadMetadata($metadata)
+    public static function loadMetadata($metadata): void
     {
-        $metadata->setAssociationOverride('groups', [
-            'inversedBy' => 'admins'
-        ]
-        );
+        $metadata->setAssociationOverride('groups', ['inversedBy' => 'admins']);
     }
 }
