@@ -1,7 +1,11 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\DDC964;
 
+use Doctrine\ORM\Mapping\ClassMetadataInfo;
+
 /**
  * @Entity
  * @AttributeOverrides({
@@ -24,21 +28,21 @@ namespace Doctrine\Tests\Models\DDC964;
  */
 class DDC964Guest extends DDC964User
 {
-    public static function loadMetadata(\Doctrine\ORM\Mapping\ClassMetadataInfo $metadata)
+    public static function loadMetadata(ClassMetadataInfo $metadata): void
     {
         $metadata->setAttributeOverride('id', [
             'columnName'    => 'guest_id',
             'type'          => 'integer',
             'length'        => 140,
-        ]
-        );
+        ]);
 
-        $metadata->setAttributeOverride('name',
+        $metadata->setAttributeOverride(
+            'name',
             [
-            'columnName'    => 'guest_name',
-            'nullable'      => false,
-            'unique'        => true,
-            'length'        => 240,
+                'columnName'    => 'guest_name',
+                'nullable'      => false,
+                'unique'        => true,
+                'length'        => 240,
             ]
         );
     }
