@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\DirectoryTree;
 
 /**
@@ -8,16 +10,17 @@ namespace Doctrine\Tests\Models\DirectoryTree;
 class Directory extends AbstractContentItem
 {
     /**
+     * @var string
      * @Column(type="string")
      */
     protected $path;
 
-    public function setPath($path)
+    public function setPath(string $path): void
     {
         $this->path = $path;
     }
 
-    public function getPath()
+    public function getPath(): string
     {
         return $this->path;
     }
