@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\Forum;
 
 /**
@@ -8,6 +10,7 @@ namespace Doctrine\Tests\Models\Forum;
 class ForumAdministrator extends ForumUser
 {
     /**
+     * @var int
      * @Column(type="integer", name="access_level")
      */
     public $accessLevel;
