@@ -1,29 +1,37 @@
 <?php
 
+declare(strict_types=1);
+
+use Doctrine\Common\Collections\Collection;
+
 /**
  * @Entity
  * @Table(name="articles")
  */
-class DoctrineGlobal_Article
+class DoctrineGlobalArticle
 {
     /**
+     * @var int
      * @Id
      * @Column(type="integer")
      */
     protected $id;
 
     /**
+     * @var string
      * @Column(type="string")
      */
     protected $headline;
 
     /**
-     * @column(type="text")
+     * @var string
+     * @Column(type="text")
      */
     protected $text;
 
     /**
-     * @ManyToMany(targetEntity="DoctrineGlobal_User")
+     * @psalm-var Collection<int, DoctrineGlobalUser>
+     * @ManyToMany(targetEntity="DoctrineGlobalUser")
      * @JoinTable(name="author_articles",
      *      joinColumns={@JoinColumn(name="article_id", referencedColumnName="id")},
      *      inverseJoinColumns={@JoinColumn(name="author_id", referencedColumnName="id", unique=true)}
@@ -32,7 +40,8 @@ class DoctrineGlobal_Article
     protected $author;
 
     /**
-     * @ManyToMany(targetEntity="DoctrineGlobal_User")
+     * @psalm-var Collection<int, DoctrineGlobalUser>
+     * @ManyToMany(targetEntity="DoctrineGlobalUser")
      * @JoinTable(name="editor_articles",
      *      joinColumns={@JoinColumn(name="article_id", referencedColumnName="id")},
      *      inverseJoinColumns={@JoinColumn(name="editor_id", referencedColumnName="id", unique=true)}
@@ -45,26 +54,23 @@ class DoctrineGlobal_Article
  * @Entity
  * @Table(name="users")
  */
-class DoctrineGlobal_User
+class DoctrineGlobalUser
 {
     /**
      * @Id
      * @Column(type="integer")
-     *
      * @var int
      */
     private $id;
 
     /**
      * @Column(type="string", length=64)
-     *
      * @var string
      */
     private $username;
 
     /**
      * @Column(type="string", length=128)
-     *
      * @var string
      */
     private $email;
