@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\Issue5989;
 
 /**
@@ -10,7 +12,6 @@ class Issue5989Employee extends Issue5989Person
 {
     /**
      * @Column(type="simple_array", nullable=true)
-     *
      * @var array
      */
     public $tags;
