@@ -1,7 +1,11 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\Legacy;
 
+use DateTime;
+
 /**
  * @Entity
  * @Table(name="legacy_users_reference")
@@ -9,13 +13,15 @@ namespace Doctrine\Tests\Models\Legacy;
 class LegacyUserReference
 {
     /**
+     * @var LegacyUser
      * @Id
-     * @ManyToOne(targetEntity="LegacyUser", inversedBy="_references")
+     * @ManyToOne(targetEntity="LegacyUser", inversedBy="references")
      * @JoinColumn(name="iUserIdSource", referencedColumnName="iUserId")
      */
     private $_source;
 
     /**
+     * @var LegacyUser
      * @Id
      * @ManyToOne(targetEntity="LegacyUser")
      * @JoinColumn(name="iUserIdTarget", referencedColumnName="iUserId")
@@ -23,42 +29,44 @@ class LegacyUserReference
     private $_target;
 
     /**
+     * @var string
      * @column(type="string", name="description")
      */
     private $_description;
 
     /**
-     * @column(type="datetime", name="created")
+     * @var DateTime
+     * @Column(type="datetime", name="created")
      */
-    private $_created;
+    private $created;
 
-    public function __construct($source, $target, $description)
+    public function __construct(LegacyUser $source, LegacyUser $target, string $description)
     {
         $source->addReference($this);
         $target->addReference($this);
 
-        $this->_source = $source;
-        $this->_target = $target;
+        $this->_source      = $source;
+        $this->_target      = $target;
         $this->_description = $description;
-        $this->_created = new \DateTime("now");
+        $this->created      = new DateTime('now');
     }
 
-    public function source()
+    public function source(): LegacyUser
     {
         return $this->_source;
     }
 
-    public function target()
+    public function target(): LegacyUser
     {
         return $this->_target;
     }
 
-    public function setDescription($desc)
+    public function setDescription(string $desc): void
     {
         $this->_description = $desc;
     }
 
-    public function getDescription()
+    public function getDescription(): string
     {
         return $this->_description;
     }
