@@ -1,14 +1,15 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\OneToOneSingleTableInheritance;
 
 /** @Entity */
 class Cat extends Pet
 {
     /**
-     * @OneToOne(targetEntity="LitterBox")
-     *
      * @var LitterBox
+     * @OneToOne(targetEntity="LitterBox")
      */
     public $litterBox;
 }
