@@ -1,16 +1,16 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\Pagination;
 
 /**
- * Class User1
- * @package Doctrine\Tests\Models\Pagination
- *
  * @Entity()
  */
 class User1 extends User
 {
     /**
+     * @var string
      * @Column(type="string")
      */
     public $email;
