@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\Quote;
 
 /**
@@ -8,10 +10,9 @@ namespace Doctrine\Tests\Models\Quote;
 class FullAddress extends Address
 {
     /**
+     * @var City
      * @OneToOne(targetEntity=City::class, cascade={"persist"})
      * @JoinColumn(name="`city-id`", referencedColumnName="`city-id`")
-     *
-     * @var City
      */
     public $city;
 }
