@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\Quote;
 
 /**
@@ -8,17 +10,17 @@ namespace Doctrine\Tests\Models\Quote;
  */
 class Phone
 {
-
     /**
+     * @var string
      * @Id
      * @Column(name="`phone-number`")
      */
     public $number;
 
     /**
+     * @var User
      * @ManyToOne(targetEntity="User", inversedBy="phones")
      * @JoinColumn(name="`user-id`", referencedColumnName="`user-id`")
      */
     public $user;
-
 }
