@@ -1,8 +1,11 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\ValueConversionType;
 
 use Doctrine\Common\Collections\ArrayCollection;
+use Doctrine\Common\Collections\Collection;
 
 /**
  * @Entity
@@ -11,12 +14,14 @@ use Doctrine\Common\Collections\ArrayCollection;
 class InversedManyToManyCompositeIdForeignKeyEntity
 {
     /**
+     * @var string
      * @Column(type="rot13")
      * @Id
      */
     public $id1;
 
     /**
+     * @var AuxiliaryEntity
      * @ManyToOne(targetEntity="AuxiliaryEntity")
      * @JoinColumn(name="foreign_id", referencedColumnName="id4")
      * @Id
@@ -24,6 +29,7 @@ class InversedManyToManyCompositeIdForeignKeyEntity
     public $foreignEntity;
 
     /**
+     * @psalm-var Collection<int, OwningManyToManyCompositeIdForeignKeyEntity>
      * @ManyToMany(targetEntity="OwningManyToManyCompositeIdForeignKeyEntity", mappedBy="associatedEntities")
      */
     public $associatedEntities;
