@@ -1,8 +1,11 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\ValueConversionType;
 
 use Doctrine\Common\Collections\ArrayCollection;
+use Doctrine\Common\Collections\Collection;
 
 /**
  * @Entity
@@ -11,12 +14,14 @@ use Doctrine\Common\Collections\ArrayCollection;
 class InversedManyToManyEntity
 {
     /**
+     * @var string
      * @Column(type="rot13")
      * @Id
      */
     public $id1;
 
     /**
+     * @psalm-var Collection<int, OwningManyToManyEntity>
      * @ManyToMany(targetEntity="OwningManyToManyEntity", mappedBy="associatedEntities")
      */
     public $associatedEntities;
