@@ -1,8 +1,11 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\ValueConversionType;
 
 use Doctrine\Common\Collections\ArrayCollection;
+use Doctrine\Common\Collections\Collection;
 
 /**
  * @Entity
@@ -11,12 +14,14 @@ use Doctrine\Common\Collections\ArrayCollection;
 class InversedOneToManyCompositeIdForeignKeyEntity
 {
     /**
+     * @var string
      * @Column(type="rot13")
      * @Id
      */
     public $id1;
 
     /**
+     * @var AuxiliaryEntity
      * @ManyToOne(targetEntity="AuxiliaryEntity")
      * @JoinColumn(name="foreign_id", referencedColumnName="id4")
      * @Id
@@ -24,11 +29,13 @@ class InversedOneToManyCompositeIdForeignKeyEntity
     public $foreignEntity;
 
     /**
+     * @var string
      * @Column(type="string", name="some_property")
      */
     public $someProperty;
 
     /**
+     * @psalm-var Collection<int, OwningManyToOneCompositeIdForeignKeyEntity>
      * @OneToMany(targetEntity="OwningManyToOneCompositeIdForeignKeyEntity", mappedBy="associatedEntity")
      */
     public $associatedEntities;
