@@ -1,8 +1,11 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\ValueConversionType;
 
 use Doctrine\Common\Collections\ArrayCollection;
+use Doctrine\Common\Collections\Collection;
 
 /**
  * @Entity
@@ -11,17 +14,20 @@ use Doctrine\Common\Collections\ArrayCollection;
 class InversedOneToManyEntity
 {
     /**
+     * @var string
      * @Column(type="rot13")
      * @Id
      */
     public $id1;
 
     /**
+     * @psalm-var Collection<int, OwningManyToOneEntity>
      * @OneToMany(targetEntity="OwningManyToOneEntity", mappedBy="associatedEntity")
      */
     public $associatedEntities;
 
     /**
+     * @var string
      * @Column(type="string", name="some_property")
      */
     public $someProperty;
