@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\ValueConversionType;
 
 /**
@@ -9,12 +11,14 @@ namespace Doctrine\Tests\Models\ValueConversionType;
 class InversedOneToOneCompositeIdForeignKeyEntity
 {
     /**
+     * @var string
      * @Column(type="rot13")
      * @Id
      */
     public $id1;
 
     /**
+     * @var AuxiliaryEntity
      * @ManyToOne(targetEntity="AuxiliaryEntity")
      * @JoinColumn(name="foreign_id", referencedColumnName="id4")
      * @Id
@@ -22,11 +26,13 @@ class InversedOneToOneCompositeIdForeignKeyEntity
     public $foreignEntity;
 
     /**
+     * @var string
      * @Column(type="string", name="some_property")
      */
     public $someProperty;
 
     /**
+     * @var OwningOneToOneCompositeIdForeignKeyEntity
      * @OneToOne(targetEntity="OwningOneToOneCompositeIdForeignKeyEntity", mappedBy="associatedEntity")
      */
     public $associatedEntity;
