@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\ValueConversionType;
 
 /**
@@ -9,17 +11,20 @@ namespace Doctrine\Tests\Models\ValueConversionType;
 class InversedOneToOneEntity
 {
     /**
+     * @var string
      * @Column(type="rot13")
      * @Id
      */
     public $id1;
 
     /**
+     * @var string
      * @Column(type="string", name="some_property")
      */
     public $someProperty;
 
     /**
+     * @var OwningOneToOneEntity
      * @OneToOne(targetEntity="OwningOneToOneEntity", mappedBy="associatedEntity")
      */
     public $associatedEntity;
