@@ -1,16 +1,17 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\VersionedOneToOne;
 
 /**
- * @author Rob Caiger <rob@clocal.co.uk>
- *
  * @Entity
  * @Table(name="first_entity")
  */
 class FirstRelatedEntity
 {
     /**
+     * @var SecondRelatedEntity
      * @Id
      * @OneToOne(targetEntity="SecondRelatedEntity", fetch="EAGER")
      * @JoinColumn(name="second_entity_id", referencedColumnName="id")
@@ -18,13 +19,14 @@ class FirstRelatedEntity
     public $secondEntity;
 
     /**
+     * @var string
      * @Column(name="name")
      */
     public $name;
 
     /**
+     * @var int
      * Version column
-     *
      * @Column(type="integer", name="version")
      * @Version
      */
