@@ -1,31 +1,29 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\ORM\Cache;
 
-use Doctrine\ORM\Cache\Logging\CacheLogger;
-use Doctrine\ORM\Cache\Logging\CacheLoggerChain;
 use Doctrine\ORM\Cache\CollectionCacheKey;
 use Doctrine\ORM\Cache\EntityCacheKey;
+use Doctrine\ORM\Cache\Logging\CacheLogger;
+use Doctrine\ORM\Cache\Logging\CacheLoggerChain;
 use Doctrine\ORM\Cache\QueryCacheKey;
-use Doctrine\Tests\Models\Cache\State;
 use Doctrine\Tests\DoctrineTestCase;
+use Doctrine\Tests\Models\Cache\State;
 
 /**
  * @group DDC-2183
  */
 class CacheLoggerChainTest extends DoctrineTestCase
 {
-    /**
-     * @var \Doctrine\ORM\Cache\Logging\CacheLoggerChain
-     */
+    /** @var CacheLoggerChain */
     private $logger;
 
-    /**
-     * @var \PHPUnit_Framework_MockObject_MockObject|\Doctrine\ORM\Cache\Logging\CacheLogger
-     */
+    /** @var PHPUnit_Framework_MockObject_MockObject|CacheLogger */
     private $mock;
 
-    protected function setUp() : void
+    protected function setUp(): void
     {
         parent::setUp();
 
@@ -33,7 +31,7 @@ class CacheLoggerChainTest extends DoctrineTestCase
         $this->mock   = $this->createMock(CacheLogger::class);
     }
 
-    public function testGetAndSetLogger()
+    public function testGetAndSetLogger(): void
     {
         $this->assertEmpty($this->logger->getLoggers());
 
@@ -45,7 +43,7 @@ class CacheLoggerChainTest extends DoctrineTestCase
         $this->assertEquals(['mock' => $this->mock], $this->logger->getLoggers());
     }
 
-    public function testEntityCacheChain()
+    public function testEntityCacheChain(): void
     {
         $name = 'my_entity_region';
         $key  = new EntityCacheKey(State::class, ['id' => 1]);
@@ -69,7 +67,7 @@ class CacheLoggerChainTest extends DoctrineTestCase
         $this->logger->entityCacheMiss($name, $key);
     }
 
-    public function testCollectionCacheChain()
+    public function testCollectionCacheChain(): void
     {
         $name = 'my_collection_region';
         $key  = new CollectionCacheKey(State::class, 'cities', ['id' => 1]);
@@ -93,7 +91,7 @@ class CacheLoggerChainTest extends DoctrineTestCase
         $this->logger->collectionCacheMiss($name, $key);
     }
 
-    public function testQueryCacheChain()
+    public function testQueryCacheChain(): void
     {
         $name = 'my_query_region';
         $key  = new QueryCacheKey('my_query_hash');
