@@ -1,10 +1,13 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\ORM\Cache;
 
 use Doctrine\Common\Collections\ArrayCollection;
 use Doctrine\ORM\Cache\CollectionCacheEntry;
 use Doctrine\ORM\Cache\CollectionCacheKey;
+use Doctrine\ORM\Cache\CollectionHydrator;
 use Doctrine\ORM\Cache\DefaultCollectionHydrator;
 use Doctrine\ORM\Cache\EntityCacheEntry;
 use Doctrine\ORM\Cache\EntityCacheKey;
@@ -19,12 +22,10 @@ use Doctrine\Tests\OrmFunctionalTestCase;
  */
 class DefaultCollectionHydratorTest extends OrmFunctionalTestCase
 {
-    /**
-     * @var \Doctrine\ORM\Cache\CollectionHydrator
-     */
+    /** @var CollectionHydrator */
     private $structure;
 
-    protected function setUp() : void
+    protected function setUp(): void
     {
         $this->enableSecondLevelCache();
         parent::setUp();
@@ -33,31 +34,29 @@ class DefaultCollectionHydratorTest extends OrmFunctionalTestCase
         $this->structure = new DefaultCollectionHydrator($this->_em, $targetPersister);
     }
 
-    public function testImplementsCollectionEntryStructure()
+    public function testImplementsCollectionEntryStructure(): void
     {
         $this->assertInstanceOf(DefaultCollectionHydrator::class, $this->structure);
     }
 
-    public function testLoadCacheCollection()
+    public function testLoadCacheCollection(): void
     {
-        $targetRegion   = $this->_em->getCache()->getEntityCacheRegion(City::class);
-        $entry          = new CollectionCacheEntry(
+        $targetRegion = $this->_em->getCache()->getEntityCacheRegion(City::class);
+        $entry        = new CollectionCacheEntry(
             [
-            new EntityCacheKey(City::class, ['id'=>31]),
-            new EntityCacheKey(City::class, ['id'=>32]),
+                new EntityCacheKey(City::class, ['id' => 31]),
+                new EntityCacheKey(City::class, ['id' => 32]),
             ]
         );
 
-        $targetRegion->put(new EntityCacheKey(City::class, ['id'=>31]), new EntityCacheEntry(City::class, ['id'=>31, 'name'=>'Foo']
-        ));
-        $targetRegion->put(new EntityCacheKey(City::class, ['id'=>32]), new EntityCacheEntry(City::class, ['id'=>32, 'name'=>'Bar']
-        ));
+        $targetRegion->put(new EntityCacheKey(City::class, ['id' => 31]), new EntityCacheEntry(City::class, ['id' => 31, 'name' => 'Foo']));
+        $targetRegion->put(new EntityCacheKey(City::class, ['id' => 32]), new EntityCacheEntry(City::class, ['id' => 32, 'name' => 'Bar']));
 
-        $sourceClass    = $this->_em->getClassMetadata(State::class);
-        $targetClass    = $this->_em->getClassMetadata(City::class);
-        $key            = new CollectionCacheKey($sourceClass->name, 'cities', ['id'=>21]);
-        $collection     = new PersistentCollection($this->_em, $targetClass, new ArrayCollection());
-        $list           = $this->structure->loadCacheEntry($sourceClass, $key, $entry, $collection);
+        $sourceClass = $this->_em->getClassMetadata(State::class);
+        $targetClass = $this->_em->getClassMetadata(City::class);
+        $key         = new CollectionCacheKey($sourceClass->name, 'cities', ['id' => 21]);
+        $collection  = new PersistentCollection($this->_em, $targetClass, new ArrayCollection());
+        $list        = $this->structure->loadCacheEntry($sourceClass, $key, $entry, $collection);
 
         $this->assertNotNull($list);
         $this->assertCount(2, $list);
@@ -78,5 +77,4 @@ class DefaultCollectionHydratorTest extends OrmFunctionalTestCase
         $this->assertEquals(UnitOfWork::STATE_MANAGED, $this->_em->getUnitOfWork()->getEntityState($collection[0]));
         $this->assertEquals(UnitOfWork::STATE_MANAGED, $this->_em->getUnitOfWork()->getEntityState($collection[1]));
     }
-
 }
