@@ -1,10 +1,13 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\ORM\Cache\Persister\Entity;
 
 use Doctrine\Common\Collections\ArrayCollection;
 use Doctrine\Common\Collections\Criteria;
 use Doctrine\ORM\Cache\Persister\CachedPersister;
+use Doctrine\ORM\Cache\Persister\Entity\AbstractEntityPersister;
 use Doctrine\ORM\Cache\Persister\Entity\CachedEntityPersister;
 use Doctrine\ORM\Cache\Region;
 use Doctrine\ORM\EntityManager;
@@ -20,59 +23,39 @@ use Doctrine\Tests\OrmTestCase;
  */
 abstract class AbstractEntityPersisterTest extends OrmTestCase
 {
-    /**
-     * @var \Doctrine\ORM\Cache\Region
-     */
+    /** @var Region */
     protected $region;
 
-    /**
-     * @var \Doctrine\ORM\Persisters\Entity\EntityPersister
-     */
+    /** @var EntityPersister */
     protected $entityPersister;
 
-    /**
-     * @var \Doctrine\ORM\EntityManager
-     */
+    /** @var EntityManager */
     protected $em;
 
-    /**
-     * @param \Doctrine\ORM\EntityManager                     $em
-     * @param \Doctrine\ORM\Persisters\Entity\EntityPersister $persister
-     * @param \Doctrine\ORM\Cache\Region                      $region
-     * @param \Doctrine\ORM\Mapping\ClassMetadata             $metadata
-     *
-     * @return \Doctrine\ORM\Cache\Persister\Entity\AbstractEntityPersister
-     */
-    abstract protected function createPersister(EntityManager $em, EntityPersister $persister, Region $region, ClassMetadata $metadata);
+    abstract protected function createPersister(EntityManager $em, EntityPersister $persister, Region $region, ClassMetadata $metadata): AbstractEntityPersister;
 
-    protected function setUp() : void
+    protected function setUp(): void
     {
         $this->getSharedSecondLevelCacheDriverImpl()->flushAll();
         $this->enableSecondLevelCache();
         parent::setUp();
 
-        $this->em              = $this->_getTestEntityManager();
+        $this->em              = $this->getTestEntityManager();
         $this->region          = $this->createRegion();
         $this->entityPersister = $this->createMock(EntityPersister::class);
     }
 
-    /**
-     * @return \Doctrine\ORM\Cache\Region
-     */
-    protected function createRegion()
+    protected function createRegion(): Region
     {
         return $this->createMock(Region::class);
     }
 
-    /**
-     * @return \Doctrine\ORM\Cache\Persister\AbstractEntityPersister
-     */
-    protected function createPersisterDefault()
+    protected function createPersisterDefault(): AbstractEntityPersister
     {
         return $this->createPersister($this->em, $this->entityPersister, $this->region, $this->em->getClassMetadata(Country::class));
     }
 
-    public function testImplementsEntityPersister()
+    public function testImplementsEntityPersister(): void
     {
         $persister = $this->createPersisterDefault();
 
@@ -81,10 +64,10 @@ abstract class AbstractEntityPersisterTest extends OrmTestCase
         $this->assertInstanceOf(CachedEntityPersister::class, $persister);
     }
 
-    public function testInvokeAddInsert()
+    public function testInvokeAddInsert(): void
     {
         $persister = $this->createPersisterDefault();
-        $entity    = new Country("Foo");
+        $entity    = new Country('Foo');
 
         $this->entityPersister->expects($this->once())
             ->method('addInsert')
@@ -93,10 +76,10 @@ abstract class AbstractEntityPersisterTest extends OrmTestCase
         $this->assertNull($persister->addInsert($entity));
     }
 
-    public function testInvokeGetInserts()
+    public function testInvokeGetInserts(): void
     {
         $persister = $this->createPersisterDefault();
-        $entity    = new Country("Foo");
+        $entity    = new Country('Foo');
 
         $this->entityPersister->expects($this->once())
             ->method('getInserts')
@@ -105,23 +88,28 @@ abstract class AbstractEntityPersisterTest extends OrmTestCase
         $this->assertEquals([$entity], $persister->getInserts());
     }
 
-    public function testInvokeGetSelectSQL()
+    public function testInvokeGetSelectSQL(): void
     {
         $persister = $this->createPersisterDefault();
 
         $this->entityPersister->expects($this->once())
             ->method('getSelectSQL')
-            ->with($this->equalTo(['name'=>'Foo']), $this->equalTo([0]), $this->equalTo(1), $this->equalTo(2), $this->equalTo(3), $this->equalTo(
+            ->with($this->equalTo(['name' => 'Foo']), $this->equalTo([0]), $this->equalTo(1), $this->equalTo(2), $this->equalTo(3), $this->equalTo(
                 [4]
             ))
             ->will($this->returnValue('SELECT * FROM foo WERE name = ?'));
 
         $this->assertEquals('SELECT * FROM foo WERE name = ?', $persister->getSelectSQL(
-            ['name'=>'Foo'], [0], 1, 2, 3, [4]
+            ['name' => 'Foo'],
+            [0],
+            1,
+            2,
+            3,
+            [4]
         ));
     }
 
-    public function testInvokeGetInsertSQL()
+    public function testInvokeGetInsertSQL(): void
     {
         $persister = $this->createPersisterDefault();
 
@@ -132,19 +120,19 @@ abstract class AbstractEntityPersisterTest extends OrmTestCase
         $this->assertEquals('INSERT INTO foo (?)', $persister->getInsertSQL());
     }
 
-    public function testInvokeExpandParameters()
+    public function testInvokeExpandParameters(): void
     {
         $persister = $this->createPersisterDefault();
 
         $this->entityPersister->expects($this->once())
             ->method('expandParameters')
-            ->with($this->equalTo(['name'=>'Foo']))
-            ->will($this->returnValue(['name'=>'Foo']));
+            ->with($this->equalTo(['name' => 'Foo']))
+            ->will($this->returnValue(['name' => 'Foo']));
 
-        $this->assertEquals(['name'=>'Foo'], $persister->expandParameters(['name'=>'Foo']));
+        $this->assertEquals(['name' => 'Foo'], $persister->expandParameters(['name' => 'Foo']));
     }
 
-    public function testInvokeExpandCriteriaParameters()
+    public function testInvokeExpandCriteriaParameters(): void
     {
         $persister = $this->createPersisterDefault();
         $criteria  = new Criteria();
@@ -152,12 +140,12 @@ abstract class AbstractEntityPersisterTest extends OrmTestCase
         $this->entityPersister->expects($this->once())
             ->method('expandCriteriaParameters')
             ->with($this->equalTo($criteria))
-            ->will($this->returnValue(['name'=>'Foo']));
+            ->will($this->returnValue(['name' => 'Foo']));
 
-        $this->assertEquals(['name'=>'Foo'], $persister->expandCriteriaParameters($criteria));
+        $this->assertEquals(['name' => 'Foo'], $persister->expandCriteriaParameters($criteria));
     }
 
-    public function testInvokeSelectConditionStatementSQL()
+    public function testInvokeSelectConditionStatementSQL(): void
     {
         $persister = $this->createPersisterDefault();
 
@@ -169,7 +157,7 @@ abstract class AbstractEntityPersisterTest extends OrmTestCase
         $this->assertEquals('name = 1', $persister->getSelectConditionStatementSQL('id', 1, [], '='));
     }
 
-    public function testInvokeExecuteInserts()
+    public function testInvokeExecuteInserts(): void
     {
         $persister = $this->createPersisterDefault();
 
@@ -180,35 +168,35 @@ abstract class AbstractEntityPersisterTest extends OrmTestCase
         $this->assertEquals(['id' => 1], $persister->executeInserts());
     }
 
-    public function testInvokeUpdate()
+    public function testInvokeUpdate(): void
     {
         $persister = $this->createPersisterDefault();
-        $entity    = new Country("Foo");
+        $entity    = new Country('Foo');
 
         $this->entityPersister->expects($this->once())
             ->method('update')
             ->with($this->equalTo($entity));
 
-        $this->em->getUnitOfWork()->registerManaged($entity, ['id'=>1], ['id'=>1, 'name'=>'Foo']);
+        $this->em->getUnitOfWork()->registerManaged($entity, ['id' => 1], ['id' => 1, 'name' => 'Foo']);
 
         $this->assertNull($persister->update($entity));
     }
 
-    public function testInvokeDelete()
+    public function testInvokeDelete(): void
     {
         $persister = $this->createPersisterDefault();
-        $entity    = new Country("Foo");
+        $entity    = new Country('Foo');
 
         $this->entityPersister->expects($this->once())
             ->method('delete')
             ->with($this->equalTo($entity));
 
-        $this->em->getUnitOfWork()->registerManaged($entity, ['id'=>1], ['id'=>1, 'name'=>'Foo']);
+        $this->em->getUnitOfWork()->registerManaged($entity, ['id' => 1], ['id' => 1, 'name' => 'Foo']);
 
         $this->assertNull($persister->delete($entity));
     }
 
-    public function testInvokeGetOwningTable()
+    public function testInvokeGetOwningTable(): void
     {
         $persister = $this->createPersisterDefault();
 
@@ -220,10 +208,10 @@ abstract class AbstractEntityPersisterTest extends OrmTestCase
         $this->assertEquals('t', $persister->getOwningTable('name'));
     }
 
-    public function testInvokeLoad()
+    public function testInvokeLoad(): void
     {
         $persister = $this->createPersisterDefault();
-        $entity    = new Country("Foo");
+        $entity    = new Country('Foo');
 
         $this->entityPersister->expects($this->once())
             ->method('load')
@@ -237,15 +225,15 @@ abstract class AbstractEntityPersisterTest extends OrmTestCase
         $this->assertEquals($entity, $persister->load(['id' => 1], $entity, [0], [1], 2, 3, [4]));
     }
 
-    public function testInvokeLoadAll()
+    public function testInvokeLoadAll(): void
     {
         $rsm       = new ResultSetMappingBuilder($this->em);
         $persister = $this->createPersisterDefault();
-        $entity    = new Country("Foo");
+        $entity    = new Country('Foo');
 
         $rsm->addEntityResult(Country::class, 'c');
 
-        $this->em->getUnitOfWork()->registerManaged($entity, ['id'=>1], ['id'=>1, 'name'=>'Foo']);
+        $this->em->getUnitOfWork()->registerManaged($entity, ['id' => 1], ['id' => 1, 'name' => 'Foo']);
 
         $this->entityPersister->expects($this->once())
             ->method('loadAll')
@@ -259,10 +247,10 @@ abstract class AbstractEntityPersisterTest extends OrmTestCase
         $this->assertEquals([$entity], $persister->loadAll(['id' => 1], [0], 1, 2));
     }
 
-    public function testInvokeLoadById()
+    public function testInvokeLoadById(): void
     {
         $persister = $this->createPersisterDefault();
-        $entity    = new Country("Foo");
+        $entity    = new Country('Foo');
 
         $this->entityPersister->expects($this->once())
             ->method('loadById')
@@ -272,10 +260,10 @@ abstract class AbstractEntityPersisterTest extends OrmTestCase
         $this->assertEquals($entity, $persister->loadById(['id' => 1], $entity));
     }
 
-    public function testInvokeLoadOneToOneEntity()
+    public function testInvokeLoadOneToOneEntity(): void
     {
         $persister = $this->createPersisterDefault();
-        $entity    = new Country("Foo");
+        $entity    = new Country('Foo');
 
         $this->entityPersister->expects($this->once())
             ->method('loadOneToOneEntity')
@@ -285,27 +273,27 @@ abstract class AbstractEntityPersisterTest extends OrmTestCase
         $this->assertEquals($entity, $persister->loadOneToOneEntity([], 'foo', ['id' => 11]));
     }
 
-    public function testInvokeRefresh()
+    public function testInvokeRefresh(): void
     {
         $persister = $this->createPersisterDefault();
-        $entity    = new Country("Foo");
+        $entity    = new Country('Foo');
 
         $this->entityPersister->expects($this->once())
             ->method('refresh')
             ->with($this->equalTo(['id' => 1]), $this->equalTo($entity), $this->equalTo(0))
             ->will($this->returnValue($entity));
 
-        $this->assertNull($persister->refresh(['id' => 1], $entity), 0);
+        $this->assertNull($persister->refresh(['id' => 1], $entity));
     }
 
-    public function testInvokeLoadCriteria()
+    public function testInvokeLoadCriteria(): void
     {
         $rsm       = new ResultSetMappingBuilder($this->em);
         $persister = $this->createPersisterDefault();
-        $entity    = new Country("Foo");
+        $entity    = new Country('Foo');
         $criteria  = new Criteria();
 
-        $this->em->getUnitOfWork()->registerManaged($entity, ['id'=>1], ['id'=>1, 'name'=>'Foo']);
+        $this->em->getUnitOfWork()->registerManaged($entity, ['id' => 1], ['id' => 1, 'name' => 'Foo']);
         $rsm->addEntityResult(Country::class, 'c');
 
         $this->entityPersister->expects($this->once())
@@ -320,39 +308,39 @@ abstract class AbstractEntityPersisterTest extends OrmTestCase
         $this->assertEquals([$entity], $persister->loadCriteria($criteria));
     }
 
-    public function testInvokeGetManyToManyCollection()
+    public function testInvokeGetManyToManyCollection(): void
     {
         $persister = $this->createPersisterDefault();
-        $entity    = new Country("Foo");
+        $entity    = new Country('Foo');
 
         $this->entityPersister->expects($this->once())
             ->method('getManyToManyCollection')
             ->with($this->equalTo([]), $this->equalTo('Foo'), $this->equalTo(1), $this->equalTo(2))
             ->will($this->returnValue([$entity]));
 
-        $this->assertEquals([$entity], $persister->getManyToManyCollection([], 'Foo', 1 ,2));
+        $this->assertEquals([$entity], $persister->getManyToManyCollection([], 'Foo', 1, 2));
     }
 
-    public function testInvokeGetOneToManyCollection()
+    public function testInvokeGetOneToManyCollection(): void
     {
         $persister = $this->createPersisterDefault();
-        $entity    = new Country("Foo");
+        $entity    = new Country('Foo');
 
         $this->entityPersister->expects($this->once())
             ->method('getOneToManyCollection')
             ->with($this->equalTo([]), $this->equalTo('Foo'), $this->equalTo(1), $this->equalTo(2))
             ->will($this->returnValue([$entity]));
 
-        $this->assertEquals([$entity], $persister->getOneToManyCollection([], 'Foo', 1 ,2));
+        $this->assertEquals([$entity], $persister->getOneToManyCollection([], 'Foo', 1, 2));
     }
 
-    public function testInvokeLoadManyToManyCollection()
+    public function testInvokeLoadManyToManyCollection(): void
     {
         $mapping   = $this->em->getClassMetadata(Country::class);
         $assoc     = ['type' => 1];
         $coll      = new PersistentCollection($this->em, $mapping, new ArrayCollection());
         $persister = $this->createPersisterDefault();
-        $entity    = new Country("Foo");
+        $entity    = new Country('Foo');
 
         $this->entityPersister->expects($this->once())
             ->method('loadManyToManyCollection')
@@ -362,13 +350,13 @@ abstract class AbstractEntityPersisterTest extends OrmTestCase
         $this->assertEquals([$entity], $persister->loadManyToManyCollection($assoc, 'Foo', $coll));
     }
 
-    public function testInvokeLoadOneToManyCollection()
+    public function testInvokeLoadOneToManyCollection(): void
     {
         $mapping   = $this->em->getClassMetadata(Country::class);
         $assoc     = ['type' => 1];
         $coll      = new PersistentCollection($this->em, $mapping, new ArrayCollection());
         $persister = $this->createPersisterDefault();
-        $entity    = new Country("Foo");
+        $entity    = new Country('Foo');
 
         $this->entityPersister->expects($this->once())
             ->method('loadOneToManyCollection')
@@ -378,7 +366,7 @@ abstract class AbstractEntityPersisterTest extends OrmTestCase
         $this->assertEquals([$entity], $persister->loadOneToManyCollection($assoc, 'Foo', $coll));
     }
 
-    public function testInvokeLock()
+    public function testInvokeLock(): void
     {
         $identifier = ['id' => 1];
         $persister  = $this->createPersisterDefault();
@@ -390,9 +378,9 @@ abstract class AbstractEntityPersisterTest extends OrmTestCase
         $this->assertNull($persister->lock($identifier, 1));
     }
 
-    public function testInvokeExists()
+    public function testInvokeExists(): void
     {
-        $entity    = new Country("Foo");
+        $entity    = new Country('Foo');
         $persister = $this->createPersisterDefault();
 
         $this->entityPersister->expects($this->once())
