@@ -1,32 +1,32 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\ORM\Cache;
 
-use Doctrine\ORM\Cache\Logging\StatisticsCacheLogger;
 use Doctrine\ORM\Cache\CollectionCacheKey;
 use Doctrine\ORM\Cache\EntityCacheKey;
+use Doctrine\ORM\Cache\Logging\StatisticsCacheLogger;
 use Doctrine\ORM\Cache\QueryCacheKey;
-use Doctrine\Tests\Models\Cache\State;
 use Doctrine\Tests\DoctrineTestCase;
+use Doctrine\Tests\Models\Cache\State;
 
 /**
  * @group DDC-2183
  */
 class StatisticsCacheLoggerTest extends DoctrineTestCase
 {
-    /**
-     * @var \Doctrine\ORM\Cache\Logging\StatisticsCacheLogger
-     */
+    /** @var StatisticsCacheLogger */
     private $logger;
 
-    protected function setUp() : void
+    protected function setUp(): void
     {
         parent::setUp();
 
         $this->logger = new StatisticsCacheLogger();
     }
 
-    public function testEntityCache()
+    public function testEntityCache(): void
     {
         $name = 'my_entity_region';
         $key  = new EntityCacheKey(State::class, ['id' => 1]);
@@ -43,7 +43,7 @@ class StatisticsCacheLoggerTest extends DoctrineTestCase
         $this->assertEquals(1, $this->logger->getRegionMissCount($name));
     }
 
-    public function testCollectionCache()
+    public function testCollectionCache(): void
     {
         $name = 'my_collection_region';
         $key  = new CollectionCacheKey(State::class, 'cities', ['id' => 1]);
@@ -60,7 +60,7 @@ class StatisticsCacheLoggerTest extends DoctrineTestCase
         $this->assertEquals(1, $this->logger->getRegionMissCount($name));
     }
 
-    public function testQueryCache()
+    public function testQueryCache(): void
     {
         $name = 'my_query_region';
         $key  = new QueryCacheKey('my_query_hash');
@@ -77,15 +77,15 @@ class StatisticsCacheLoggerTest extends DoctrineTestCase
         $this->assertEquals(1, $this->logger->getRegionMissCount($name));
     }
 
-    public function testMultipleCaches()
+    public function testMultipleCaches(): void
     {
         $coolRegion   = 'my_collection_region';
         $entityRegion = 'my_entity_region';
         $queryRegion  = 'my_query_region';
 
-        $coolKey    = new CollectionCacheKey(State::class, 'cities', ['id' => 1]);
-        $entityKey  = new EntityCacheKey(State::class, ['id' => 1]);
-        $queryKey   = new QueryCacheKey('my_query_hash');
+        $coolKey   = new CollectionCacheKey(State::class, 'cities', ['id' => 1]);
+        $entityKey = new EntityCacheKey(State::class, ['id' => 1]);
+        $queryKey  = new QueryCacheKey('my_query_hash');
 
         $this->logger->queryCacheHit($queryRegion, $queryKey);
         $this->logger->queryCachePut($queryRegion, $queryKey);
