@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\ORM;
 
 use Doctrine\ORM\Internal\CommitOrderCalculator;
@@ -15,14 +17,15 @@ use Doctrine\Tests\OrmTestCase;
  */
 class CommitOrderCalculatorTest extends OrmTestCase
 {
+    /** @var CommitOrderCalculator */
     private $_calc;
 
-    protected function setUp() : void
+    protected function setUp(): void
     {
         $this->_calc = new CommitOrderCalculator();
     }
 
-    public function testCommitOrdering1()
+    public function testCommitOrdering1(): void
     {
         $class1 = new ClassMetadata(NodeClass1::class);
         $class2 = new ClassMetadata(NodeClass2::class);
@@ -49,7 +52,7 @@ class CommitOrderCalculatorTest extends OrmTestCase
         $this->assertSame($correctOrder, $sorted);
     }
 
-    public function testCommitOrdering2()
+    public function testCommitOrdering2(): void
     {
         $class1 = new ClassMetadata(NodeClass1::class);
         $class2 = new ClassMetadata(NodeClass2::class);
@@ -68,7 +71,7 @@ class CommitOrderCalculatorTest extends OrmTestCase
         $this->assertSame($correctOrder, $sorted);
     }
 
-    public function testCommitOrdering3()
+    public function testCommitOrdering3(): void
     {
         // this test corresponds to the GH7259Test::testPersistFileBeforeVersion functional test
         $class1 = new ClassMetadata(NodeClass1::class);
@@ -102,8 +105,18 @@ class CommitOrderCalculatorTest extends OrmTestCase
     }
 }
 
-class NodeClass1 {}
-class NodeClass2 {}
-class NodeClass3 {}
-class NodeClass4 {}
-class NodeClass5 {}
+class NodeClass1
+{
+}
+class NodeClass2
+{
+}
+class NodeClass3
+{
+}
+class NodeClass4
+{
+}
+class NodeClass5
+{
+}
