@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\ORM\Decorator;
 
 use Doctrine\ORM\Decorator\EntityManagerDecorator;
@@ -7,13 +9,18 @@ use Doctrine\ORM\EntityManagerInterface;
 use Doctrine\ORM\Query\ResultSetMapping;
 use Doctrine\Tests\VerifyDeprecations;
 use PHPUnit\Framework\TestCase;
+use PHPUnit_Framework_MockObject_MockObject;
+use ReflectionClass;
+use ReflectionMethod;
+
+use function array_fill;
 use function in_array;
 
 class EntityManagerDecoratorTest extends TestCase
 {
     use VerifyDeprecations;
 
-    const VOID_METHODS = [
+    public const VOID_METHODS = [
         'persist',
         'remove',
         'clear',
@@ -28,29 +35,28 @@ class EntityManagerDecoratorTest extends TestCase
         'lock',
     ];
 
-    /**
-     * @var EntityManagerInterface|\PHPUnit_Framework_MockObject_MockObject
-     */
+    /** @var EntityManagerInterface|PHPUnit_Framework_MockObject_MockObject */
     private $wrapped;
 
     /** @before */
-    public function ignoreDeprecationMessagesFromDoctrinePersistence() : void
+    public function ignoreDeprecationMessagesFromDoctrinePersistence(): void
     {
         $this->ignoreDeprecationMessage('The Doctrine\Common\Persistence\ObjectManagerDecorator class is deprecated since doctrine/persistence 1.3 and will be removed in 2.0. Use \Doctrine\Persistence\ObjectManagerDecorator instead.');
     }
 
-    protected function setUp() : void
+    protected function setUp(): void
     {
         $this->wrapped = $this->createMock(EntityManagerInterface::class);
     }
 
-    public function getMethodParameters()
+    /** @psalm-return array<string, mixed[]> */
+    public function getMethodParameters(): array
     {
-        $class = new \ReflectionClass(EntityManagerInterface::class);
+        $class   = new ReflectionClass(EntityManagerInterface::class);
         $methods = [];
 
         foreach ($class->getMethods() as $method) {
-            if ($method->isConstructor() || $method->isStatic() || !$method->isPublic()) {
+            if ($method->isConstructor() || $method->isStatic() || ! $method->isPublic()) {
                 continue;
             }
 
@@ -60,7 +66,10 @@ class EntityManagerDecoratorTest extends TestCase
         return $methods;
     }
 
-    private function getParameters(\ReflectionMethod $method)
+    /**
+     * @return mixed[]
+     */
+    private function getParameters(ReflectionMethod $method): array
     {
         /** Special case EntityManager::createNativeQuery() */
         if ($method->getName() === 'createNativeQuery') {
@@ -75,7 +84,7 @@ class EntityManagerDecoratorTest extends TestCase
             return [$method->getName(), array_fill(0, $method->getNumberOfRequiredParameters(), 'req') ?: []];
         }
 
-        if ($method->getNumberOfParameters() != $method->getNumberOfRequiredParameters()) {
+        if ($method->getNumberOfParameters() !== $method->getNumberOfRequiredParameters()) {
             return [$method->getName(), array_fill(0, $method->getNumberOfParameters(), 'all') ?: []];
         }
 
@@ -85,9 +94,9 @@ class EntityManagerDecoratorTest extends TestCase
     /**
      * @dataProvider getMethodParameters
      */
-    public function testAllMethodCallsAreDelegatedToTheWrappedInstance($method, array $parameters)
+    public function testAllMethodCallsAreDelegatedToTheWrappedInstance($method, array $parameters): void
     {
-        $return = !in_array($method, self::VOID_METHODS) ? 'INNER VALUE FROM ' . $method : null;
+        $return = ! in_array($method, self::VOID_METHODS) ? 'INNER VALUE FROM ' . $method : null;
 
         $this->wrapped->expects($this->once())
             ->method($method)
@@ -101,6 +110,7 @@ class EntityManagerDecoratorTest extends TestCase
 
         if (in_array($method, ['copy', 'merge', 'detach', 'getHydrator'], true)) {
             $this->assertHasDeprecationMessages();
+
             return;
         }
 
