@@ -1,50 +1,61 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\ORM\Functional;
 
 use Doctrine\Common\Collections\ArrayCollection;
+use Doctrine\Common\Collections\Collection;
 use Doctrine\ORM\PersistentCollection;
 use Doctrine\Tests\IterableTester;
 use Doctrine\Tests\OrmFunctionalTestCase;
 
+use function assert;
+use function count;
+use function is_numeric;
+
 /**
  * Functional tests for the Single Table Inheritance mapping strategy.
- *
- * @author robo
  */
 class AdvancedAssociationTest extends OrmFunctionalTestCase
 {
-    protected function setUp() : void
+    protected function setUp(): void
     {
         parent::setUp();
-        try {
-            $this->_schemaTool->createSchema(
-                [
-                $this->_em->getClassMetadata(Phrase::class),
-                $this->_em->getClassMetadata(PhraseType::class),
-                $this->_em->getClassMetadata(Definition::class),
-                $this->_em->getClassMetadata(Lemma::class),
-                $this->_em->getClassMetadata(Type::class)
-                ]
-            );
-        } catch (\Exception $e) {
-            // Swallow all exceptions. We do not test the schema tool here.
-        }
+        $this->_schemaTool->createSchema([
+            $this->_em->getClassMetadata(Phrase::class),
+            $this->_em->getClassMetadata(PhraseType::class),
+            $this->_em->getClassMetadata(Definition::class),
+            $this->_em->getClassMetadata(Lemma::class),
+            $this->_em->getClassMetadata(Type::class),
+        ]);
     }
 
-    public function testIssue()
+    protected function tearDown(): void
+    {
+        parent::tearDown();
+        $this->_schemaTool->dropSchema([
+            $this->_em->getClassMetadata(Phrase::class),
+            $this->_em->getClassMetadata(PhraseType::class),
+            $this->_em->getClassMetadata(Definition::class),
+            $this->_em->getClassMetadata(Lemma::class),
+            $this->_em->getClassMetadata(Type::class),
+        ]);
+    }
+
+    public function testIssue(): void
     {
         //setup
-        $phrase = new Phrase;
+        $phrase = new Phrase();
         $phrase->setPhrase('lalala');
 
-        $type = new PhraseType;
+        $type = new PhraseType();
         $type->setType('nonsense');
         $type->setAbbreviation('non');
 
-        $def1 = new Definition;
+        $def1 = new Definition();
         $def1->setDefinition('def1');
-        $def2 = new Definition;
+        $def2 = new Definition();
         $def2->setDefinition('def2');
 
         $phrase->setType($type);
@@ -65,8 +76,8 @@ class AdvancedAssociationTest extends OrmFunctionalTestCase
         $this->_em->clear();
 
         // test2 - eager load in DQL query
-        $query = $this->_em->createQuery("SELECT p,t FROM Doctrine\Tests\ORM\Functional\Phrase p JOIN p.type t");
-        $res = $query->getResult();
+        $query = $this->_em->createQuery('SELECT p,t FROM Doctrine\Tests\ORM\Functional\Phrase p JOIN p.type t');
+        $res   = $query->getResult();
         $this->assertEquals(1, count($res));
         $this->assertInstanceOf(PhraseType::class, $res[0]->getType());
         $this->assertInstanceOf(PersistentCollection::class, $res[0]->getType()->getPhrases());
@@ -79,8 +90,8 @@ class AdvancedAssociationTest extends OrmFunctionalTestCase
         $this->_em->clear();
 
         // test2 - eager load in DQL query with double-join back and forth
-        $query = $this->_em->createQuery("SELECT p,t,pp FROM Doctrine\Tests\ORM\Functional\Phrase p JOIN p.type t JOIN t.phrases pp");
-        $res = $query->getResult();
+        $query = $this->_em->createQuery('SELECT p,t,pp FROM Doctrine\Tests\ORM\Functional\Phrase p JOIN p.type t JOIN t.phrases pp');
+        $res   = $query->getResult();
         $this->assertEquals(1, count($res));
         $this->assertInstanceOf(PhraseType::class, $res[0]->getType());
         $this->assertInstanceOf(PersistentCollection::class, $res[0]->getType()->getPhrases());
@@ -89,7 +100,7 @@ class AdvancedAssociationTest extends OrmFunctionalTestCase
         $this->_em->clear();
 
         // test3 - lazy-loading one-to-many after find()
-        $phrase3 = $this->_em->find(Phrase::class, $phrase->getId());
+        $phrase3     = $this->_em->find(Phrase::class, $phrase->getId());
         $definitions = $phrase3->getDefinitions();
         $this->assertInstanceOf(PersistentCollection::class, $definitions);
         $this->assertInstanceOf(Definition::class, $definitions[0]);
@@ -97,8 +108,8 @@ class AdvancedAssociationTest extends OrmFunctionalTestCase
         $this->_em->clear();
 
         // test4 - lazy-loading after DQL query
-        $query = $this->_em->createQuery("SELECT p FROM Doctrine\Tests\ORM\Functional\Phrase p");
-        $res = $query->getResult();
+        $query       = $this->_em->createQuery('SELECT p FROM Doctrine\Tests\ORM\Functional\Phrase p');
+        $res         = $query->getResult();
         $definitions = $res[0]->getDefinitions();
 
         $this->assertEquals(1, count($res));
@@ -111,9 +122,9 @@ class AdvancedAssociationTest extends OrmFunctionalTestCase
         IterableTester::assertResultsAreTheSame($query);
     }
 
-    public function testManyToMany()
+    public function testManyToMany(): void
     {
-        $lemma = new Lemma;
+        $lemma = new Lemma();
         $lemma->setLemma('abu');
 
         $type = new Type();
@@ -127,8 +138,8 @@ class AdvancedAssociationTest extends OrmFunctionalTestCase
         $this->_em->flush();
 
         // test5 ManyToMany
-        $query = $this->_em->createQuery("SELECT l FROM Doctrine\Tests\ORM\Functional\Lemma l");
-        $res = $query->getResult();
+        $query = $this->_em->createQuery('SELECT l FROM Doctrine\Tests\ORM\Functional\Lemma l');
+        $res   = $query->getResult();
         $types = $res[0]->getTypes();
 
         $this->assertInstanceOf(Type::class, $types[0]);
@@ -143,79 +154,65 @@ class AdvancedAssociationTest extends OrmFunctionalTestCase
  * @Entity
  * @Table(name="lemma")
  */
-class Lemma {
+class Lemma
+{
+    public const CLASS_NAME = self::class;
 
-	const CLASS_NAME = __CLASS__;
-
-	/**
-	 * @var int
-	 * @Id
-	 * @Column(type="integer", name="lemma_id")
-	 * @GeneratedValue(strategy="AUTO")
-	 */
-	private $id;
-
-	/**
-	 *
-	 * @var string
-	 * @Column(type="string", name="lemma_name", unique=true, length=255)
-	 */
-	private $lemma;
-
-	/**
-	 * @var kateglo\application\utilities\collections\ArrayCollection
-	 * @ManyToMany(targetEntity="Type", mappedBy="lemmas", cascade={"persist"})
-	 */
-	private $types;
-
-	public function __construct() {
-		$this->types = new ArrayCollection();
-	}
-
-
-	/**
-	 *
-	 * @return int
-	 */
-	public function getId(){
-		return $this->id;
-	}
-
-	/**
-	 *
-	 * @param string $lemma
-	 * @return void
-	 */
-	public function setLemma($lemma){
-		$this->lemma = $lemma;
-	}
-
-	/**
-	 *
-	 * @return string
-	 */
-	public function getLemma(){
-		return $this->lemma;
-	}
-
-	/**
-     *
-     * @param kateglo\application\models\Type $type
-     * @return void
+    /**
+     * @var int
+     * @Id
+     * @Column(type="integer", name="lemma_id")
+     * @GeneratedValue(strategy="AUTO")
      */
-	public function addType(Type $type){
-        if (!$this->types->contains($type)) {
+    private $id;
+
+    /**
+     * @var string
+     * @Column(type="string", name="lemma_name", unique=true, length=255)
+     */
+    private $lemma;
+
+    /**
+     * @var kateglo\application\utilities\collections\ArrayCollection
+     * @ManyToMany(targetEntity="Type", mappedBy="lemmas", cascade={"persist"})
+     */
+    private $types;
+
+    public function __construct()
+    {
+        $this->types = new ArrayCollection();
+    }
+
+    public function getId(): int
+    {
+        return $this->id;
+    }
+
+    public function setLemma(string $lemma): void
+    {
+        $this->lemma = $lemma;
+    }
+
+    public function getLemma(): string
+    {
+        return $this->lemma;
+    }
+
+    /**
+     * @param kateglo\application\models\Type $type
+     */
+    public function addType(Type $type): void
+    {
+        if (! $this->types->contains($type)) {
             $this->types[] = $type;
             $type->addLemma($this);
         }
     }
 
     /**
-     *
      * @param kateglo\application\models\Type $type
-     * @return void
      */
-    public function removeType(Type $type)
+    public function removeType(Type $type): void
     {
         $removed = $this->sources->removeElement($type);
         if ($removed !== null) {
@@ -223,11 +220,7 @@ class Lemma {
         }
     }
 
-    /**
-     *
-     * @return kateglo\application\helpers\collections\ArrayCollection
-     */
-    public function getTypes()
+    public function getTypes(): Collection
     {
         return $this->types;
     }
@@ -237,124 +230,96 @@ class Lemma {
  * @Entity
  * @Table(name="type")
  */
-class Type {
+class Type
+{
+    public const CLASS_NAME = self::class;
 
-	const CLASS_NAME = __CLASS__;
+    /**
+     * @var int
+     * @Id
+     * @Column(type="integer", name="type_id")
+     * @GeneratedValue(strategy="AUTO")
+     */
+    private $id;
 
-	/**
-	 *
-	 * @var int
-	 * @Id
-	 * @Column(type="integer", name="type_id")
-	 * @GeneratedValue(strategy="AUTO")
-	 */
-	private $id;
+    /**
+     * @var string
+     * @Column(type="string", name="type_name", unique=true)
+     */
+    private $type;
 
-	/**
-	 *
-	 * @var string
-	 * @Column(type="string", name="type_name", unique=true)
-	 */
-	private $type;
+    /**
+     * @var string
+     * @Column(type="string", name="type_abbreviation", unique=true)
+     */
+    private $abbreviation;
 
-	/**
-	 *
-	 * @var string
-	 * @Column(type="string", name="type_abbreviation", unique=true)
-	 */
-	private $abbreviation;
+    /**
+     * @var kateglo\application\helpers\collections\ArrayCollection
+     * @ManyToMany(targetEntity="Lemma")
+     * @JoinTable(name="lemma_type",
+     *      joinColumns={@JoinColumn(name="type_id", referencedColumnName="type_id")},
+     *      inverseJoinColumns={@JoinColumn(name="lemma_id", referencedColumnName="lemma_id")}
+     * )
+     */
+    private $lemmas;
 
-	/**
-	 * @var kateglo\application\helpers\collections\ArrayCollection
-	 * @ManyToMany(targetEntity="Lemma")
-	 * @JoinTable(name="lemma_type",
-	 * 		joinColumns={@JoinColumn(name="type_id", referencedColumnName="type_id")},
-	 * 		inverseJoinColumns={@JoinColumn(name="lemma_id", referencedColumnName="lemma_id")}
-	 * )
-	 */
-	private $lemmas;
+    public function __construct()
+    {
+        $this->lemmas = new ArrayCollection();
+    }
 
-	public function __construct(){
-		$this->lemmas = new ArrayCollection();
-	}
+    public function getId(): int
+    {
+        return $this->id;
+    }
 
-	/**
-	 *
-	 * @return int
-	 */
-	public function getId(){
-		return $this->id;
-	}
+    public function setType(string $type): void
+    {
+        $this->type = $type;
+    }
 
-	/**
-	 *
-	 * @param string $type
-	 * @return void
-	 */
-	public function setType($type){
-		$this->type = $type;
-	}
+    public function getType(): string
+    {
+        return $this->type;
+    }
 
-	/**
-	 *
-	 * @return string
-	 */
-	public function getType(){
-		return $this->type;
-	}
+    public function setAbbreviation(string $abbreviation): void
+    {
+        $this->abbreviation = $abbreviation;
+    }
 
-	/**
-	 *
-	 * @param string $abbreviation
-	 * @return void
-	 */
-	public function setAbbreviation($abbreviation){
-		$this->abbreviation = $abbreviation;
-	}
+    public function getAbbreviation(): string
+    {
+        return $this->abbreviation;
+    }
 
-	/**
-	 *
-	 * @return string
-	 */
-	public function getAbbreviation(){
-		return $this->abbreviation;
-	}
+    /**
+     * @param kateglo\application\models\Lemma $lemma
+     */
+    public function addLemma(Lemma $lemma): void
+    {
+        if (! $this->lemmas->contains($lemma)) {
+            $this->lemmas[] = $lemma;
+            $lemma->addType($this);
+        }
+    }
 
-	/**
-	 *
-	 * @param kateglo\application\models\Lemma $lemma
-	 * @return void
-	 */
-	public function addLemma(Lemma $lemma)
-	{
-		if (!$this->lemmas->contains($lemma)) {
-			$this->lemmas[] = $lemma;
-			$lemma->addType($this);
-		}
-	}
-
-	/**
-	 *
-	 * @param kateglo\application\models\Lemma $lemma
-	 * @return void
-	 */
-	public function removeLEmma(Lemma $lemma)
-	{
-		$removed = $this->lemmas->removeElement($lemma);
-		if ($removed !== null) {
-			$removed->removeType($this);
-		}
-	}
-
-	/**
-	 *
-	 * @return kateglo\application\helpers\collections\ArrayCollection
-	 */
-	public function getCategories()
-	{
-		return $this->categories;
-	}
+    /**
+     * @param kateglo\application\models\Lemma $lemma
+     */
+    public function removeLEmma(Lemma $lemma): void
+    {
+        $removed = $this->lemmas->removeElement($lemma);
+        if ($removed !== null) {
+            $removed->removeType($this);
+        }
+    }
 
+    public function getCategories(): kateglo\application\helpers\collections\ArrayCollection
+    {
+        return $this->categories;
+    }
 }
 
 
@@ -362,11 +327,12 @@ class Type {
  * @Entity
  * @Table(name="phrase")
  */
-class Phrase {
-
-    const CLASS_NAME = __CLASS__;
+class Phrase
+{
+    public const CLASS_NAME = self::class;
 
     /**
+     * @var int
      * @Id
      * @Column(type="integer", name="phrase_id")
      * @GeneratedValue(strategy="AUTO")
@@ -374,79 +340,62 @@ class Phrase {
     private $id;
 
     /**
+     * @var string
      * @Column(type="string", name="phrase_name", unique=true, length=255)
      */
     private $phrase;
 
     /**
+     * @var PhraseType
      * @ManyToOne(targetEntity="PhraseType")
      * @JoinColumn(name="phrase_type_id", referencedColumnName="phrase_type_id")
      */
     private $type;
 
     /**
+     * @psalm-var Collection<int, Definition>
      * @OneToMany(targetEntity="Definition", mappedBy="phrase", cascade={"persist"})
      */
     private $definitions;
 
-    public function __construct() {
-        $this->definitions = new ArrayCollection;
+    public function __construct()
+    {
+        $this->definitions = new ArrayCollection();
     }
 
-    /**
-     *
-     * @param Definition $definition
-     * @return void
-     */
-    public function addDefinition(Definition $definition){
+    public function addDefinition(Definition $definition): void
+    {
         $this->definitions[] = $definition;
         $definition->setPhrase($this);
     }
 
-    /**
-     * @return int
-     */
-    public function getId(){
+    public function getId(): int
+    {
         return $this->id;
     }
 
-    /**
-     * @param string $phrase
-     * @return void
-     */
-    public function setPhrase($phrase){
+    public function setPhrase(string $phrase): void
+    {
         $this->phrase = $phrase;
     }
 
-    /**
-     * @return string
-     */
-    public function getPhrase(){
+    public function getPhrase(): string
+    {
         return $this->phrase;
     }
 
-    /**
-     *
-     * @param PhraseType $type
-     * @return void
-     */
-    public function setType(PhraseType $type){
+    public function setType(PhraseType $type): void
+    {
         $this->type = $type;
     }
 
-    /**
-     *
-     * @return PhraseType
-     */
-    public function getType(){
+    public function getType(): PhraseType
+    {
         return $this->type;
     }
 
-    /**
-     *
-     * @return ArrayCollection
-     */
-    public function getDefinitions(){
+    public function getDefinitions(): Collection
+    {
         return $this->definitions;
     }
 }
@@ -455,11 +404,12 @@ class Phrase {
  * @Entity
  * @Table(name="phrase_type")
  */
-class PhraseType {
-
-    const CLASS_NAME = __CLASS__;
+class PhraseType
+{
+    public const CLASS_NAME = self::class;
 
     /**
+     * @var int
      * @Id
      * @Column(type="integer", name="phrase_type_id")
      * @GeneratedValue(strategy="AUTO")
@@ -467,88 +417,74 @@ class PhraseType {
     private $id;
 
     /**
+     * @var string
      * @Column(type="string", name="phrase_type_name", unique=true)
      */
     private $type;
 
     /**
+     * @var string
      * @Column(type="string", name="phrase_type_abbreviation", unique=true)
      */
     private $abbreviation;
 
     /**
+     * @psalm-var Collection<int, Phrase>
      * @OneToMany(targetEntity="Phrase", mappedBy="type")
      */
     private $phrases;
 
-    public function __construct() {
-        $this->phrases = new ArrayCollection;
+    public function __construct()
+    {
+        $this->phrases = new ArrayCollection();
     }
 
-    /**
-     * @return int
-     */
-    public function getId(){
+    public function getId(): int
+    {
         return $this->id;
     }
 
-    /**
-     * @param string $type
-     * @return void
-     */
-    public function setType($type){
+    public function setType(string $type): void
+    {
         $this->type = $type;
     }
 
-    /**
-     * @return string
-     */
-    public function getType(){
+    public function getType(): string
+    {
         return $this->type;
     }
 
-    /**
-     * @param string $abbreviation
-     * @return void
-     */
-    public function setAbbreviation($abbreviation){
+    public function setAbbreviation(string $abbreviation): void
+    {
         $this->abbreviation = $abbreviation;
     }
 
-    /**
-     * @return string
-     */
-    public function getAbbreviation(){
+    public function getAbbreviation(): string
+    {
         return $this->abbreviation;
     }
 
-    /**
-     * @param ArrayCollection $phrases
-     * @return void
-     */
-    public function setPhrases($phrases){
+    public function setPhrases(ArrayCollection $phrases): void
+    {
         $this->phrases = $phrases;
     }
 
-    /**
-     *
-     * @return ArrayCollection
-     */
-    public function getPhrases(){
+    public function getPhrases(): Collection
+    {
         return $this->phrases;
     }
-
 }
 
 /**
  * @Entity
  * @Table(name="definition")
  */
-class Definition {
-
-    const CLASS_NAME = __CLASS__;
+class Definition
+{
+    public const CLASS_NAME = self::class;
 
     /**
+     * @var int
      * @Id
      * @Column(type="integer", name="definition_id")
      * @GeneratedValue(strategy="AUTO")
@@ -556,59 +492,50 @@ class Definition {
     private $id;
 
     /**
+     * @var Phrase
      * @ManyToOne(targetEntity="Phrase")
      * @JoinColumn(name="definition_phrase_id", referencedColumnName="phrase_id")
      */
     private $phrase;
 
     /**
+     * @var string
      * @Column(type="text", name="definition_text")
      */
     private $definition;
 
-    /**
-     * @return int
-     */
-    public function getId(){
+    public function getId(): int
+    {
         return $this->id;
     }
 
-    /**
-     * @param Phrase $phrase
-     * @return void
-     */
-    public function setPhrase(Phrase $phrase){
+    public function setPhrase(Phrase $phrase): void
+    {
         $this->phrase = $phrase;
     }
 
-    /**
-     * @return Phrase
-     */
-    public function getPhrase(){
+    public function getPhrase(): Phrase
+    {
         return $this->phrase;
     }
 
-    public function removePhrase() {
+    public function removePhrase(): void
+    {
         if ($this->phrase !== null) {
-            /*@var $phrase kateglo\application\models\Phrase */
             $phrase = $this->phrase;
+            assert($phrase instanceof kateglo\application\models\Phrase);
             $this->phrase = null;
             $phrase->removeDefinition($this);
         }
     }
 
-    /**
-     * @param string $definition
-     * @return void
-     */
-    public function setDefinition($definition){
+    public function setDefinition(string $definition): void
+    {
         $this->definition = $definition;
     }
 
-    /**
-     * @return string
-     */
-    public function getDefinition(){
+    public function getDefinition(): string
+    {
         return $this->definition;
     }
 }
