@@ -1,40 +1,47 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\ORM\Functional;
 
+use Doctrine\DBAL\Platforms\PostgreSqlPlatform;
 use Doctrine\DBAL\Platforms\SQLServerPlatform;
+use Doctrine\DBAL\Schema\AbstractSchemaManager;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\ORM\Mapping\ClassMetadataInfo;
-use Doctrine\DBAL\Platforms\PostgreSqlPlatform;
+
+use function array_change_key_case;
+use function count;
+use function strtolower;
+
+use const CASE_LOWER;
 
 class DatabaseDriverTest extends DatabaseDriverTestCase
 {
-    /**
-     * @var \Doctrine\DBAL\Schema\AbstractSchemaManager
-     */
-    protected $_sm = null;
+    /** @var AbstractSchemaManager */
+    protected $schemaManager = null;
 
-    protected function setUp() : void
+    protected function setUp(): void
     {
         $this->useModelSet('cms');
         parent::setUp();
 
-        $this->_sm = $this->_em->getConnection()->getSchemaManager();
+        $this->schemaManager = $this->_em->getConnection()->getSchemaManager();
     }
 
     /**
      * @group DDC-2059
      */
-    public function testIssue2059()
+    public function testIssue2059(): void
     {
-        if (!$this->_em->getConnection()->getDatabasePlatform()->supportsForeignKeyConstraints()) {
+        if (! $this->_em->getConnection()->getDatabasePlatform()->supportsForeignKeyConstraints()) {
             $this->markTestSkipped('Platform does not support foreign keys.');
         }
 
-        $user = new Table("ddc2059_user");
+        $user = new Table('ddc2059_user');
         $user->addColumn('id', 'integer');
         $user->setPrimaryKey(['id']);
-        $project = new Table("ddc2059_project");
+        $project = new Table('ddc2059_project');
         $project->addColumn('id', 'integer');
         $project->addColumn('user_id', 'integer');
         $project->addColumn('user', 'string');
@@ -47,58 +54,58 @@ class DatabaseDriverTest extends DatabaseDriverTestCase
         $this->assertTrue(isset($metadata['Ddc2059Project']->associationMappings['user2']));
     }
 
-    public function testLoadMetadataFromDatabase()
+    public function testLoadMetadataFromDatabase(): void
     {
-        if (!$this->_em->getConnection()->getDatabasePlatform()->supportsForeignKeyConstraints()) {
+        if (! $this->_em->getConnection()->getDatabasePlatform()->supportsForeignKeyConstraints()) {
             $this->markTestSkipped('Platform does not support foreign keys.');
         }
 
-        $table = new Table("dbdriver_foo");
+        $table = new Table('dbdriver_foo');
         $table->addColumn('id', 'integer');
         $table->setPrimaryKey(['id']);
         $table->addColumn('bar', 'string', ['notnull' => false, 'length' => 200]);
 
-        $this->_sm->dropAndCreateTable($table);
+        $this->schemaManager->dropAndCreateTable($table);
 
-        $metadatas = $this->extractClassMetadata(["DbdriverFoo"]);
+        $metadatas = $this->extractClassMetadata(['DbdriverFoo']);
 
         $this->assertArrayHasKey('DbdriverFoo', $metadatas);
         $metadata = $metadatas['DbdriverFoo'];
 
-        $this->assertArrayHasKey('id',          $metadata->fieldMappings);
-        $this->assertEquals('id',               $metadata->fieldMappings['id']['fieldName']);
-        $this->assertEquals('id',               strtolower($metadata->fieldMappings['id']['columnName']));
-        $this->assertEquals('integer',          (string)$metadata->fieldMappings['id']['type']);
+        $this->assertArrayHasKey('id', $metadata->fieldMappings);
+        $this->assertEquals('id', $metadata->fieldMappings['id']['fieldName']);
+        $this->assertEquals('id', strtolower($metadata->fieldMappings['id']['columnName']));
+        $this->assertEquals('integer', (string) $metadata->fieldMappings['id']['type']);
 
-        $this->assertArrayHasKey('bar',         $metadata->fieldMappings);
-        $this->assertEquals('bar',              $metadata->fieldMappings['bar']['fieldName']);
-        $this->assertEquals('bar',              strtolower($metadata->fieldMappings['bar']['columnName']));
-        $this->assertEquals('string',           (string)$metadata->fieldMappings['bar']['type']);
-        $this->assertEquals(200,                $metadata->fieldMappings['bar']['length']);
+        $this->assertArrayHasKey('bar', $metadata->fieldMappings);
+        $this->assertEquals('bar', $metadata->fieldMappings['bar']['fieldName']);
+        $this->assertEquals('bar', strtolower($metadata->fieldMappings['bar']['columnName']));
+        $this->assertEquals('string', (string) $metadata->fieldMappings['bar']['type']);
+        $this->assertEquals(200, $metadata->fieldMappings['bar']['length']);
         $this->assertTrue($metadata->fieldMappings['bar']['nullable']);
     }
 
-    public function testLoadMetadataWithForeignKeyFromDatabase()
+    public function testLoadMetadataWithForeignKeyFromDatabase(): void
     {
-        if (!$this->_em->getConnection()->getDatabasePlatform()->supportsForeignKeyConstraints()) {
+        if (! $this->_em->getConnection()->getDatabasePlatform()->supportsForeignKeyConstraints()) {
             $this->markTestSkipped('Platform does not support foreign keys.');
         }
 
-        $tableB = new Table("dbdriver_bar");
+        $tableB = new Table('dbdriver_bar');
         $tableB->addColumn('id', 'integer');
         $tableB->setPrimaryKey(['id']);
 
-        $this->_sm->dropAndCreateTable($tableB);
+        $this->schemaManager->dropAndCreateTable($tableB);
 
-        $tableA = new Table("dbdriver_baz");
+        $tableA = new Table('dbdriver_baz');
         $tableA->addColumn('id', 'integer');
         $tableA->setPrimaryKey(['id']);
         $tableA->addColumn('bar_id', 'integer');
         $tableA->addForeignKeyConstraint('dbdriver_bar', ['bar_id'], ['id']);
 
-        $this->_sm->dropAndCreateTable($tableA);
+        $this->schemaManager->dropAndCreateTable($tableA);
 
-        $metadatas = $this->extractClassMetadata(["DbdriverBar", "DbdriverBaz"]);
+        $metadatas = $this->extractClassMetadata(['DbdriverBar', 'DbdriverBaz']);
 
         $this->assertArrayHasKey('DbdriverBaz', $metadatas);
         $bazMetadata = $metadatas['DbdriverBaz'];
@@ -106,19 +113,19 @@ class DatabaseDriverTest extends DatabaseDriverTestCase
         $this->assertArrayNotHasKey('barId', $bazMetadata->fieldMappings, "The foreign Key field should not be inflected as 'barId' field, its an association.");
         $this->assertArrayHasKey('id', $bazMetadata->fieldMappings);
 
-        $bazMetadata->associationMappings = \array_change_key_case($bazMetadata->associationMappings, \CASE_LOWER);
+        $bazMetadata->associationMappings = array_change_key_case($bazMetadata->associationMappings, CASE_LOWER);
 
         $this->assertArrayHasKey('bar', $bazMetadata->associationMappings);
         $this->assertEquals(ClassMetadataInfo::MANY_TO_ONE, $bazMetadata->associationMappings['bar']['type']);
     }
 
-    public function testDetectManyToManyTables()
+    public function testDetectManyToManyTables(): void
     {
-        if (!$this->_em->getConnection()->getDatabasePlatform()->supportsForeignKeyConstraints()) {
+        if (! $this->_em->getConnection()->getDatabasePlatform()->supportsForeignKeyConstraints()) {
             $this->markTestSkipped('Platform does not support foreign keys.');
         }
 
-        $metadatas = $this->extractClassMetadata(["CmsUsers", "CmsGroups", "CmsTags"]);
+        $metadatas = $this->extractClassMetadata(['CmsUsers', 'CmsGroups', 'CmsTags']);
 
         $this->assertArrayHasKey('CmsUsers', $metadatas, 'CmsUsers entity was not detected.');
         $this->assertArrayHasKey('CmsGroups', $metadatas, 'CmsGroups entity was not detected.');
@@ -132,33 +139,33 @@ class DatabaseDriverTest extends DatabaseDriverTestCase
         $this->assertArrayHasKey('user', $metadatas['CmsGroups']->associationMappings);
     }
 
-    public function testIgnoreManyToManyTableWithoutFurtherForeignKeyDetails()
+    public function testIgnoreManyToManyTableWithoutFurtherForeignKeyDetails(): void
     {
-        $tableB = new Table("dbdriver_bar");
+        $tableB = new Table('dbdriver_bar');
         $tableB->addColumn('id', 'integer');
         $tableB->setPrimaryKey(['id']);
 
-        $tableA = new Table("dbdriver_baz");
+        $tableA = new Table('dbdriver_baz');
         $tableA->addColumn('id', 'integer');
         $tableA->setPrimaryKey(['id']);
 
-        $tableMany = new Table("dbdriver_bar_baz");
+        $tableMany = new Table('dbdriver_bar_baz');
         $tableMany->addColumn('bar_id', 'integer');
         $tableMany->addColumn('baz_id', 'integer');
         $tableMany->addForeignKeyConstraint('dbdriver_bar', ['bar_id'], ['id']);
 
         $metadatas = $this->convertToClassMetadata([$tableA, $tableB], [$tableMany]);
 
-        $this->assertEquals(0, count($metadatas['DbdriverBaz']->associationMappings), "no association mappings should be detected.");
+        $this->assertEquals(0, count($metadatas['DbdriverBaz']->associationMappings), 'no association mappings should be detected.');
     }
 
-    public function testLoadMetadataFromDatabaseDetail()
+    public function testLoadMetadataFromDatabaseDetail(): void
     {
-        if ( ! $this->_em->getConnection()->getDatabasePlatform()->supportsForeignKeyConstraints()) {
+        if (! $this->_em->getConnection()->getDatabasePlatform()->supportsForeignKeyConstraints()) {
             $this->markTestSkipped('Platform does not support foreign keys.');
         }
 
-        $table = new Table("dbdriver_foo");
+        $table = new Table('dbdriver_foo');
 
         $table->addColumn('id', 'integer', ['unsigned' => true]);
         $table->setPrimaryKey(['id']);
@@ -169,15 +176,15 @@ class DatabaseDriverTest extends DatabaseDriverTestCase
 
         $table->addColumn('column_index1', 'string');
         $table->addColumn('column_index2', 'string');
-        $table->addIndex(['column_index1','column_index2'], 'index1');
+        $table->addIndex(['column_index1', 'column_index2'], 'index1');
 
         $table->addColumn('column_unique_index1', 'string');
         $table->addColumn('column_unique_index2', 'string');
         $table->addUniqueIndex(['column_unique_index1', 'column_unique_index2'], 'unique_index1');
 
-        $this->_sm->dropAndCreateTable($table);
+        $this->schemaManager->dropAndCreateTable($table);
 
-        $metadatas = $this->extractClassMetadata(["DbdriverFoo"]);
+        $metadatas = $this->extractClassMetadata(['DbdriverFoo']);
 
         $this->assertArrayHasKey('DbdriverFoo', $metadatas);
 
@@ -190,8 +197,10 @@ class DatabaseDriverTest extends DatabaseDriverTestCase
 
         // FIXME: Condition here is fugly.
         // NOTE: PostgreSQL and SQL SERVER do not support UNSIGNED integer
-        if ( ! $this->_em->getConnection()->getDatabasePlatform() instanceof PostgreSqlPlatform AND
-             ! $this->_em->getConnection()->getDatabasePlatform() instanceof SQLServerPlatform) {
+        if (
+            ! $this->_em->getConnection()->getDatabasePlatform() instanceof PostgreSqlPlatform &&
+             ! $this->_em->getConnection()->getDatabasePlatform() instanceof SQLServerPlatform
+        ) {
             $this->assertArrayHasKey('columnUnsigned', $metadata->fieldMappings);
             $this->assertTrue($metadata->fieldMappings['columnUnsigned']['options']['unsigned']);
         }
@@ -206,13 +215,13 @@ class DatabaseDriverTest extends DatabaseDriverTestCase
         $this->assertEquals(4, $metadata->fieldMappings['columnDecimal']['precision']);
         $this->assertEquals(3, $metadata->fieldMappings['columnDecimal']['scale']);
 
-        $this->assertTrue( ! empty($metadata->table['indexes']['index1']['columns']));
+        $this->assertTrue(! empty($metadata->table['indexes']['index1']['columns']));
         $this->assertEquals(
-            ['column_index1','column_index2'],
+            ['column_index1', 'column_index2'],
             $metadata->table['indexes']['index1']['columns']
         );
 
-        $this->assertTrue( ! empty($metadata->table['uniqueConstraints']['unique_index1']['columns']));
+        $this->assertTrue(! empty($metadata->table['uniqueConstraints']['unique_index1']['columns']));
         $this->assertEquals(
             ['column_unique_index1', 'column_unique_index2'],
             $metadata->table['uniqueConstraints']['unique_index1']['columns']
