@@ -1,60 +1,62 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\ORM\Functional;
 
-use Doctrine\Tests\OrmFunctionalTestCase;
-use Doctrine\Tests\Models\Cms\CmsUser;
-use Doctrine\DBAL\Cache\QueryCacheProfile;
 use Doctrine\Common\Cache\ArrayCache;
+use Doctrine\DBAL\Cache\QueryCacheProfile;
+use Doctrine\Tests\Models\Cms\CmsUser;
+use Doctrine\Tests\OrmFunctionalTestCase;
 
 /**
  * @group DDC-1766
  */
 class HydrationCacheTest extends OrmFunctionalTestCase
 {
-    protected function setUp() : void
+    protected function setUp(): void
     {
         $this->useModelSet('cms');
 
         parent::setUp();
 
-        $user = new CmsUser();
-        $user->name = "Benjamin";
-        $user->username = "beberlei";
-        $user->status = 'active';
+        $user           = new CmsUser();
+        $user->name     = 'Benjamin';
+        $user->username = 'beberlei';
+        $user->status   = 'active';
 
         $this->_em->persist($user);
         $this->_em->flush();
         $this->_em->clear();
     }
 
-    public function testHydrationCache()
+    public function testHydrationCache(): void
     {
         $cache = new ArrayCache();
-        $dql = "SELECT u FROM Doctrine\Tests\Models\Cms\CmsUser u";
+        $dql   = 'SELECT u FROM Doctrine\Tests\Models\Cms\CmsUser u';
 
         $users = $this->_em->createQuery($dql)
                       ->setHydrationCacheProfile(new QueryCacheProfile(null, null, $cache))
                       ->getResult();
 
-        $c = $this->getCurrentQueryCount();
+        $c     = $this->getCurrentQueryCount();
         $users = $this->_em->createQuery($dql)
                       ->setHydrationCacheProfile(new QueryCacheProfile(null, null, $cache))
                       ->getResult();
 
-        $this->assertEquals($c, $this->getCurrentQueryCount(), "Should not execute query. Its cached!");
+        $this->assertEquals($c, $this->getCurrentQueryCount(), 'Should not execute query. Its cached!');
 
         $users = $this->_em->createQuery($dql)
                       ->setHydrationCacheProfile(new QueryCacheProfile(null, null, $cache))
                       ->getArrayResult();
 
-        $this->assertEquals($c + 1, $this->getCurrentQueryCount(), "Hydration is part of cache key.");
+        $this->assertEquals($c + 1, $this->getCurrentQueryCount(), 'Hydration is part of cache key.');
 
         $users = $this->_em->createQuery($dql)
                       ->setHydrationCacheProfile(new QueryCacheProfile(null, null, $cache))
                       ->getArrayResult();
 
-        $this->assertEquals($c + 1, $this->getCurrentQueryCount(), "Hydration now cached");
+        $this->assertEquals($c + 1, $this->getCurrentQueryCount(), 'Hydration now cached');
 
         $users = $this->_em->createQuery($dql)
                       ->setHydrationCacheProfile(new QueryCacheProfile(null, 'cachekey', $cache))
@@ -65,14 +67,14 @@ class HydrationCacheTest extends OrmFunctionalTestCase
         $users = $this->_em->createQuery($dql)
                       ->setHydrationCacheProfile(new QueryCacheProfile(null, 'cachekey', $cache))
                       ->getArrayResult();
-        $this->assertEquals($c + 2, $this->getCurrentQueryCount(), "Hydration now cached");
+        $this->assertEquals($c + 2, $this->getCurrentQueryCount(), 'Hydration now cached');
     }
 
-    public function testHydrationParametersSerialization()
+    public function testHydrationParametersSerialization(): void
     {
         $cache = new ArrayCache();
 
-        $dql   = "SELECT u FROM Doctrine\Tests\Models\Cms\CmsUser u WHERE u.id = ?1";
+        $dql   = 'SELECT u FROM Doctrine\Tests\Models\Cms\CmsUser u WHERE u.id = ?1';
         $query = $this->_em->createQuery($dql)
             ->setParameter(1, $userId = 1)
             ->setHydrationCacheProfile(new QueryCacheProfile(null, null, $cache));
@@ -83,7 +85,6 @@ class HydrationCacheTest extends OrmFunctionalTestCase
 
         $query->getResult();
 
-        $this->assertEquals($c, $this->getCurrentQueryCount(), "Should not execute query. Its cached!");
+        $this->assertEquals($c, $this->getCurrentQueryCount(), 'Should not execute query. Its cached!');
     }
 }
-
