@@ -1,19 +1,22 @@
 <?php
+
+declare(strict_types=1);
+
 namespace Doctrine\Tests\ORM\Functional;
 
+use Doctrine\Tests\Models\CompositeKeyInheritance\JoinedChildClass;
 use Doctrine\Tests\Models\CompositeKeyInheritance\JoinedRootClass;
 use Doctrine\Tests\OrmFunctionalTestCase;
-use Doctrine\Tests\Models\CompositeKeyInheritance\JoinedChildClass;
 
 class JoinedTableCompositeKeyTest extends OrmFunctionalTestCase
 {
-    protected function setUp() : void
+    protected function setUp(): void
     {
         $this->useModelSet('compositekeyinheritance');
         parent::setUp();
     }
 
-    public function testInsertWithCompositeKey()
+    public function testInsertWithCompositeKey(): void
     {
         $childEntity = new JoinedChildClass();
         $this->_em->persist($childEntity);
@@ -28,7 +31,7 @@ class JoinedTableCompositeKeyTest extends OrmFunctionalTestCase
     /**
      * @group non-cacheable
      */
-    public function testUpdateWithCompositeKey()
+    public function testUpdateWithCompositeKey(): void
     {
         $childEntity = new JoinedChildClass();
         $this->_em->persist($childEntity);
@@ -36,7 +39,7 @@ class JoinedTableCompositeKeyTest extends OrmFunctionalTestCase
 
         $this->_em->clear();
 
-        $entity = $this->findEntity();
+        $entity            = $this->findEntity();
         $entity->extension = 'ext-new';
         $this->_em->persist($entity);
         $this->_em->flush();
@@ -47,10 +50,7 @@ class JoinedTableCompositeKeyTest extends OrmFunctionalTestCase
         $this->assertEquals($entity, $persistedEntity);
     }
 
-    /**
-     * @return \Doctrine\Tests\Models\CompositeKeyInheritance\JoinedChildClass
-     */
-    private function findEntity()
+    private function findEntity(): JoinedChildClass
     {
         return $this->_em->find(
             JoinedRootClass::class,
