@@ -1,23 +1,35 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\ORM\Functional\Locking;
 
-use Doctrine\Tests\Models\CMS\CmsArticle;
 use Doctrine\DBAL\LockMode;
+use Doctrine\Tests\Models\CMS\CmsArticle;
 use Doctrine\Tests\OrmFunctionalTestCase;
+use GearmanClient;
+
+use function class_exists;
+use function max;
+use function serialize;
 
 /**
  * @group locking_functional
  */
 class GearmanLockTest extends OrmFunctionalTestCase
 {
+    /** @var GearmanClient */
     private $gearman = null;
+
+    /** @var int $maxRunTime */
     private $maxRunTime = 0;
+
+    /** @var int */
     private $articleId;
 
-    protected function setUp() : void
+    protected function setUp(): void
     {
-        if (!class_exists('GearmanClient', false)) {
+        if (! class_exists('GearmanClient', false)) {
             $this->markTestSkipped('pecl/gearman is required for this test to run.');
         }
 
@@ -25,16 +37,16 @@ class GearmanLockTest extends OrmFunctionalTestCase
         parent::setUp();
         $this->tasks = [];
 
-        $this->gearman = new \GearmanClient();
+        $this->gearman = new GearmanClient();
         $this->gearman->addServer(
             $_SERVER['GEARMAN_HOST'] ?? null,
             $_SERVER['GEARMAN_PORT'] ?? 4730
         );
-        $this->gearman->setCompleteCallback([$this, "gearmanTaskCompleted"]);
+        $this->gearman->setCompleteCallback([$this, 'gearmanTaskCompleted']);
 
-        $article = new CmsArticle();
-        $article->text = "my article";
-        $article->topic = "Hello";
+        $article        = new CmsArticle();
+        $article->text  = 'my article';
+        $article->topic = 'Hello';
 
         $this->_em->persist($article);
         $this->_em->flush();
@@ -42,12 +54,12 @@ class GearmanLockTest extends OrmFunctionalTestCase
         $this->articleId = $article->id;
     }
 
-    public function gearmanTaskCompleted($task)
+    public function gearmanTaskCompleted($task): void
     {
         $this->maxRunTime = max($this->maxRunTime, $task->data());
     }
 
-    public function testFindWithLock()
+    public function testFindWithLock(): void
     {
         $this->asyncFindWithLock(CmsArticle::class, $this->articleId, LockMode::PESSIMISTIC_WRITE);
         $this->asyncFindWithLock(CmsArticle::class, $this->articleId, LockMode::PESSIMISTIC_WRITE);
@@ -55,7 +67,7 @@ class GearmanLockTest extends OrmFunctionalTestCase
         $this->assertLockWorked();
     }
 
-    public function testFindWithWriteThenReadLock()
+    public function testFindWithWriteThenReadLock(): void
     {
         $this->asyncFindWithLock(CmsArticle::class, $this->articleId, LockMode::PESSIMISTIC_WRITE);
         $this->asyncFindWithLock(CmsArticle::class, $this->articleId, LockMode::PESSIMISTIC_READ);
@@ -63,7 +75,7 @@ class GearmanLockTest extends OrmFunctionalTestCase
         $this->assertLockWorked();
     }
 
-    public function testFindWithReadThenWriteLock()
+    public function testFindWithReadThenWriteLock(): void
     {
         $this->asyncFindWithLock(CmsArticle::class, $this->articleId, LockMode::PESSIMISTIC_READ);
         $this->asyncFindWithLock(CmsArticle::class, $this->articleId, LockMode::PESSIMISTIC_WRITE);
@@ -71,7 +83,7 @@ class GearmanLockTest extends OrmFunctionalTestCase
         $this->assertLockWorked();
     }
 
-    public function testFindWithOneLock()
+    public function testFindWithOneLock(): void
     {
         $this->asyncFindWithLock(CmsArticle::class, $this->articleId, LockMode::PESSIMISTIC_WRITE);
         $this->asyncFindWithLock(CmsArticle::class, $this->articleId, LockMode::NONE);
@@ -79,7 +91,7 @@ class GearmanLockTest extends OrmFunctionalTestCase
         $this->assertLockDoesNotBlock();
     }
 
-    public function testDqlWithLock()
+    public function testDqlWithLock(): void
     {
         $this->asyncDqlWithLock('SELECT a FROM Doctrine\Tests\Models\CMS\CmsArticle a', [], LockMode::PESSIMISTIC_WRITE);
         $this->asyncFindWithLock(CmsArticle::class, $this->articleId, LockMode::PESSIMISTIC_WRITE);
@@ -87,7 +99,7 @@ class GearmanLockTest extends OrmFunctionalTestCase
         $this->assertLockWorked();
     }
 
-    public function testLock()
+    public function testLock(): void
     {
         $this->asyncFindWithLock(CmsArticle::class, $this->articleId, LockMode::PESSIMISTIC_WRITE);
         $this->asyncLock(CmsArticle::class, $this->articleId, LockMode::PESSIMISTIC_WRITE);
@@ -95,7 +107,7 @@ class GearmanLockTest extends OrmFunctionalTestCase
         $this->assertLockWorked();
     }
 
-    public function testLock2()
+    public function testLock2(): void
     {
         $this->asyncFindWithLock(CmsArticle::class, $this->articleId, LockMode::PESSIMISTIC_WRITE);
         $this->asyncLock(CmsArticle::class, $this->articleId, LockMode::PESSIMISTIC_READ);
@@ -103,7 +115,7 @@ class GearmanLockTest extends OrmFunctionalTestCase
         $this->assertLockWorked();
     }
 
-    public function testLock3()
+    public function testLock3(): void
     {
         $this->asyncFindWithLock(CmsArticle::class, $this->articleId, LockMode::PESSIMISTIC_READ);
         $this->asyncLock(CmsArticle::class, $this->articleId, LockMode::PESSIMISTIC_WRITE);
@@ -111,7 +123,7 @@ class GearmanLockTest extends OrmFunctionalTestCase
         $this->assertLockWorked();
     }
 
-    public function testLock4()
+    public function testLock4(): void
     {
         $this->asyncFindWithLock(CmsArticle::class, $this->articleId, LockMode::NONE);
         $this->asyncLock(CmsArticle::class, $this->articleId, LockMode::PESSIMISTIC_WRITE);
@@ -119,12 +131,12 @@ class GearmanLockTest extends OrmFunctionalTestCase
         $this->assertLockDoesNotBlock();
     }
 
-    protected function assertLockDoesNotBlock()
+    protected function assertLockDoesNotBlock(): void
     {
         $this->assertLockWorked($onlyForSeconds = 1);
     }
 
-    protected function assertLockWorked($forTime = 2, $notLongerThan = null)
+    protected function assertLockWorked($forTime = 2, $notLongerThan = null): void
     {
         if ($notLongerThan === null) {
             $notLongerThan = $forTime + 1;
@@ -132,51 +144,51 @@ class GearmanLockTest extends OrmFunctionalTestCase
 
         $this->gearman->runTasks();
 
-        $this->assertTrue($this->maxRunTime > $forTime,
-            "Because of locking this tests should have run at least " . $forTime . " seconds, ".
-            "but only did for " . $this->maxRunTime . " seconds.");
-        $this->assertTrue($this->maxRunTime < $notLongerThan,
-            "The longest task should not run longer than " . $notLongerThan . " seconds, ".
-            "but did for " . $this->maxRunTime . " seconds."
+        $this->assertTrue(
+            $this->maxRunTime > $forTime,
+            'Because of locking this tests should have run at least ' . $forTime . ' seconds, ' .
+            'but only did for ' . $this->maxRunTime . ' seconds.'
+        );
+        $this->assertTrue(
+            $this->maxRunTime < $notLongerThan,
+            'The longest task should not run longer than ' . $notLongerThan . ' seconds, ' .
+            'but did for ' . $this->maxRunTime . ' seconds.'
         );
     }
 
-    protected function asyncFindWithLock($entityName, $entityId, $lockMode)
+    protected function asyncFindWithLock($entityName, $entityId, $lockMode): void
     {
         $this->startJob('findWithLock', [
             'entityName' => $entityName,
             'entityId' => $entityId,
             'lockMode' => $lockMode,
-        ]
-        );
+        ]);
     }
 
-    protected function asyncDqlWithLock($dql, $params, $lockMode)
+    protected function asyncDqlWithLock($dql, $params, $lockMode): void
     {
         $this->startJob('dqlWithLock', [
             'dql' => $dql,
             'dqlParams' => $params,
             'lockMode' => $lockMode,
-        ]
-        );
+        ]);
     }
 
-    protected function asyncLock($entityName, $entityId, $lockMode)
+    protected function asyncLock($entityName, $entityId, $lockMode): void
     {
         $this->startJob('lock', [
             'entityName' => $entityName,
             'entityId' => $entityId,
             'lockMode' => $lockMode,
-        ]
-        );
+        ]);
     }
 
-    protected function startJob($fn, $fixture)
+    protected function startJob($fn, $fixture): void
     {
         $this->gearman->addTask($fn, serialize(
             [
-            'conn' => $this->_em->getConnection()->getParams(),
-            'fixture' => $fixture
+                'conn' => $this->_em->getConnection()->getParams(),
+                'fixture' => $fixture,
             ]
         ));
 
